@@ -1,8 +1,8 @@
 /**
  * @file ctonedim.h
  *
- * @warning  This module is an experimental part of the %Cantera API and
- *      may be changed or removed without notice.
+ * @deprecated  Deprecated in %Cantera 3.2 and to be removed thereafter.
+ *      The legacy CLib is superseded by the generated CLib.
  */
 
 // This file is part of Cantera. See License.txt in the top-level directory or
@@ -11,6 +11,9 @@
 #ifndef CTC_ONEDIM_H
 #define CTC_ONEDIM_H
 
+#pragma message("warning: The legacy CLib library ctonedim.h is deprecated and " \
+                "will be removed after Cantera 3.2. Use generated CLib instead.")
+
 #include "clib_defs.h"
 
 #ifdef __cplusplus
@@ -65,7 +68,7 @@ extern "C" {
     CANTERA_CAPI int sim1D_setProfile(int i, int dom, int comp,
                                       size_t np, const double* pos, size_t nv, const double* v);
     CANTERA_CAPI int sim1D_setFlatProfile(int i, int dom, int comp, double v);
-    CANTERA_CAPI int sim1D_show(int i, const char* fname);
+    CANTERA_CAPI int sim1D_show(int i);
     CANTERA_CAPI int sim1D_setTimeStep(int i, double stepsize, size_t ns, const int* nsteps);
     CANTERA_CAPI int sim1D_getInitialSoln(int i);
     CANTERA_CAPI int sim1D_solve(int i, int loglevel, int refine_grid);
