@@ -1,8 +1,8 @@
 /**
  * @file ctsurf.h
  *
- * @warning  This module is an experimental part of the %Cantera API and
- *      may be changed or removed without notice.
+ * @deprecated  Deprecated in %Cantera 3.2 and to be removed thereafter.
+ *      The legacy CLib is superseded by the generated CLib.
  */
 
 // This file is part of Cantera. See License.txt in the top-level directory or
@@ -11,6 +11,9 @@
 #ifndef CTC_SURF_H
 #define CTC_SURF_H
 
+#pragma message("warning: The legacy CLib library ctsurf.h is deprecated and " \
+                "will be removed after Cantera 3.2. Use generated CLib instead.")
+
 #include "clib_defs.h"
 
 #ifdef __cplusplus
