@@ -88,6 +88,17 @@ public:
      */
     void addPhases(MultiPhase& mix);
 
+    //! Add a phase to the mixture.
+    /*!
+     *  This function must be called before the init() function is called,
+     *  which serves to freeze the MultiPhase.
+     *
+     *  @param p pointer to the phase object
+     *  @param moles total number of moles of all species in this phase
+     *  @since New in %Cantera 3.2.
+     */
+    void addPhase(shared_ptr<ThermoPhase> p, double moles);
+
     //! Add a phase to the mixture.
     /*!
      *  This function must be called before the init() function is called,
@@ -104,12 +115,16 @@ public:
     }
 
     //! Check that the specified element index is in range.
-    //! Throws an exception if m is greater than nElements()-1
-    void checkElementIndex(size_t m) const;
+    /*!
+     * @since Starting in %Cantera 3.2, returns the input element index, if valid.
+     * @exception Throws an IndexError if m is greater than nElements()-1
+     */
+    size_t checkElementIndex(size_t m) const;
 
     //! Check that an array size is at least nElements().
     //! Throws an exception if mm is less than nElements(). Used before calls
     //! which take an array pointer.
+    //! @deprecated To be removed after %Cantera 3.2. Only used by legacy CLib.
     void checkElementArraySize(size_t mm) const;
 
     //! Returns the name of the global element *m*.
@@ -121,28 +136,46 @@ public:
     //! Returns the index of the element with name @e name.
     /*!
      * @param name   String name of the global element
+     * @deprecated  To be removed after %Cantera 3.2. Use 2-parameter version instead.
      */
     size_t elementIndex(const string& name) const;
 
+    //! Returns the index of the element with name @e name.
+    /*!
+     * @param name  String name of the global element.
+     * @param raise  If `true`, raise exception if the specified element is not found;
+     *      otherwise, return @ref npos.
+     * @since Added the `raise` argument in %Cantera 3.2. If not specified, the default
+     *      behavior if an element is not found in %Cantera 3.2 is to return `npos`.
+     *      After %Cantera 3.2, the default behavior will be to throw an exception.
+     * @exception Throws a CanteraError if the specified element is not found and
+     *      `raise` is `true`.
+     */
+    size_t elementIndex(const string& name, bool raise) const;
+
     //! Number of species, summed over all phases.
     size_t nSpecies() const {
         return m_nsp;
     }
 
     //! Check that the specified species index is in range.
-    //! Throws an exception if k is greater than nSpecies()-1
-    void checkSpeciesIndex(size_t k) const;
+    /*!
+     * @since Starting in %Cantera 3.2, returns the input species index, if valid.
+     * @exception Throws an IndexError if k is greater than nSpecies()-1
+     */
+    size_t checkSpeciesIndex(size_t k) const;
 
     //! Check that an array size is at least nSpecies().
     //! Throws an exception if kk is less than nSpecies(). Used before calls
     //! which take an array pointer.
+    //! @deprecated To be removed after %Cantera 3.2. Only used by legacy CLib.
     void checkSpeciesArraySize(size_t kk) const;
 
     //! Name of species with global index @e kGlob
     /*!
      * @param kGlob   global species index
      */
-    string speciesName(const size_t kGlob) const;
+    string speciesName(size_t kGlob) const;
 
     //! Returns the Number of atoms of global element @e mGlob in
     //! global species @e kGlob.
@@ -175,15 +208,29 @@ public:
     /*!
      *   @param iph  phase Index
      */
-    string phaseName(const size_t iph) const;
+    string phaseName(size_t iph) const;
 
     //! Returns the index, given the phase name
     /*!
      * @param pName Name of the phase
      * @returns the index. A value of -1 means the phase isn't in the object.
+     * @deprecated  To be removed after %Cantera 3.2. Use 2-parameter version instead.
      */
     int phaseIndex(const string& pName) const;
 
+    //! Returns the index, given the phase name
+    /*!
+     * @param pName Name of the phase
+     * @param raise  If `true`, raise exception if the specified phase is not found.
+     * @returns the index. A value of -1 means the phase isn't in the object.
+     * @since Added the `raise` argument in %Cantera 3.2 and changed return type. If
+     *      not specified, the default behavior if a phase is not found in %Cantera 3.2
+     *      is to return @ref npos.
+     * @exception Throws a CanteraError if the specified phase is not found and
+     *      `raise` is `true`.
+     */
+    size_t phaseIndex(const string& pName, bool raise) const;
+
     //! Return the number of moles in phase n.
     /*!
      * @param n  Index of the phase.
@@ -208,12 +255,16 @@ public:
     ThermoPhase& phase(size_t n);
 
     //! Check that the specified phase index is in range
-    //! Throws an exception if m is greater than nPhases()
-    void checkPhaseIndex(size_t m) const;
+    /*!
+     * @since Starting in %Cantera 3.2, returns the input species index, if valid.
+     * @exception Throws an IndexError if m is greater than nPhases()-1
+     */
+    size_t checkPhaseIndex(size_t m) const;
 
     //! Check that an array size is at least nPhases()
     //! Throws an exception if mm is less than nPhases(). Used before calls
     //! which take an array pointer.
+    //! @deprecated To be removed after %Cantera 3.2. Unused
     void checkPhaseArraySize(size_t mm) const;
 
     //! Returns the moles of global species @c k. units = kmol
@@ -575,6 +626,11 @@ private:
     //! Vector of the ThermoPhase pointers.
     vector<ThermoPhase*> m_phase;
 
+    //! Vector of shared ThermoPhase pointers.
+    //! Contains valid phase entries if added by addPhase(shared_ptr<ThermoPhase>) and
+    //! null pointers if a phase is added via addPhase(ThermoPhase*).
+    vector<shared_ptr<ThermoPhase>> m_sharedPhase;
+
     //! Global Stoichiometric Coefficient array
     /*!
      * This is a two dimensional array m_atoms(m, k). The first index is the
