@@ -206,6 +206,11 @@ public:
         return m_lowRate;
     }
 
+    //! Get reaction rate in the low-pressure limit
+    const ArrheniusRate& lowRate() const {
+        return m_lowRate;
+    }
+
     //! Set reaction rate in the low-pressure limit
     void setLowRate(const ArrheniusRate& low);
 
@@ -214,6 +219,11 @@ public:
         return m_highRate;
     }
 
+    //! Get reaction rate in the high-pressure limit
+    const ArrheniusRate& highRate() const {
+        return m_highRate;
+    }
+
     //! Set reaction rate in the high-pressure limit
     void setHighRate(const ArrheniusRate& high);
 
