@@ -162,6 +162,18 @@ public:
         return bool(m_third_body);
     }
 
+    //! Register a function to be called if setRate is used.
+    //! @param id  A unique ID corresponding to the object affected by the callback.
+    //! @param callback  The callback function to be called after setRate is called.
+    //! When the callback becomes invalid (for example, the corresponding object is
+    //! being deleted), the removeSetRateCallback() method must be invoked.
+    //! @since New in %Cantera 3.2
+    void registerSetRateCallback(void* id, const function<void()>& callback);
+
+    //! Remove the setRate callback function associated with the specified object.
+    //! @since New in %Cantera 3.2
+    void removeSetRateCallback(void* id);
+
 protected:
     //! Store the parameters of a Reaction needed to reconstruct an identical
     //! object using the newReaction(AnyMap&, Kinetics&) function. Does not
@@ -183,6 +195,9 @@ protected:
     //! Relative efficiencies of third-body species in enhancing the reaction rate
     //! (if applicable)
     shared_ptr<ThirdBody> m_third_body;
+
+    //! Callback functions that are invoked when the rate is replaced.
+    map<void*, function<void()>> m_setRateCallbacks;
 };
 
 
@@ -253,6 +268,7 @@ protected:
 //! Create a new empty Reaction object
 /*!
  * @param type string identifying type of reaction.
+ * @deprecated  To be removed after %Cantera 3.2.
  */
 unique_ptr<Reaction> newReaction(const string& type);
 
