@@ -19,6 +19,7 @@ enum flow_t { NetFlow, OneWayFlow };
 
 // forward references
 class Path;
+class ReactionPathBuilder;
 
 /**
  *  Nodes in reaction path graphs.
@@ -161,6 +162,15 @@ class ReactionPathDiagram
 public:
     ReactionPathDiagram() = default;
 
+    //! Construct new reaction path diagram.
+    /**
+     *  The method creates a reaction path diagram for the fluxes of `element`
+     *  according to instantaneous net reaction rates.
+     *  @param kin  Shared pointer to Kinetics object.
+     *  @param element_  Element used for the calculation of net reaction rates.
+     */
+    ReactionPathDiagram(shared_ptr<Kinetics> kin, const string& element_);
+
     /**
      * Destructor. Deletes all nodes and paths in the diagram.
      */
@@ -188,6 +198,12 @@ public:
 
     void writeData(std::ostream& s);
 
+    //! Get a (roughly) human-readable representation of the reaction path diagram.
+    /**
+     *  @see writeData
+     */
+    string getData();
+
     /**
      *  Export the reaction path diagram. This method writes to stream
      *  @c s the commands for the 'dot' program in the @c GraphViz
@@ -202,7 +218,19 @@ public:
      */
     void exportToDot(std::ostream& s);
 
+    //! Export string in @c dot format.
+    /**
+     *  Return a string containing the reaction path diagram formatted for use
+     *  by Graphviz's 'dot' program.
+     *  @see exportToDot
+     */
+    string getDot();
+
     void add(ReactionPathDiagram& d);
+
+    //! Add fluxes from other ReactionPathDiagram to this diagram.
+    void add(shared_ptr<ReactionPathDiagram> d);
+
     SpeciesNode* node(size_t k) {
         return m_nodes[k];
     }
@@ -221,6 +249,8 @@ public:
 
     void addNode(size_t k, const string& nm, double x = 0.0);
 
+    //! Include only species and fluxes that are directly connected to a species.
+    //! Set to -1 to include all species.
     void displayOnly(size_t k=npos) {
         m_local = k;
     }
@@ -251,31 +281,63 @@ public:
     }
     vector<size_t> species();
     vector<int> reactions();
+
+    //! Undocumented.
+    /**
+     *  @todo Add documentation.
+     */
     void findMajorPaths(double threshold, size_t lda, double* a);
+
+    //! Set name of the font used.
     void setFont(const string& font) {
         m_font = font;
     }
-    // public attributes
 
-    string title;
-    string bold_color = "blue";
-    string normal_color = "steelblue";
-    string dashed_color = "gray";
-    string element;
-    string m_font = "Helvetica";
+    //! Get the way flows are drawn. Either 'NetFlow' or 'OneWayFlow'
+    const string flowType() const;
+
+    //! Get the way flows are drawn. Either 'NetFlow' or 'OneWayFlow'
+    void setFlowType(const string& fType);
+
+    //! Build the reaction path diagram.
+    /**
+     *  Called automatically by methods which return representations of the diagram,
+     *  for example writeDot().
+     */
+    void build();
+
+    //! Get logging messages generated while building the reaction path diagram.
+    string getLog();
+
+    //! @name Public Attributes
+    //! @{
+
+    string title;  //!< Reaction path diagram title.
+    string bold_color = "blue";  //!< Color for bold lines.
+    string normal_color = "steelblue";  //!< Color for normal-weight lines.
+    string dashed_color = "gray";  //!< Color for dashed lines.
+    string element;  //!< Element used for the construction of a reaction path diagram.
+    string m_font = "Helvetica";  //!< Reaction path diagram font.
+    //! Threshold for the minimum flux relative value that will be plotted.
     double threshold = 0.005;
-    double bold_min = 0.2;
-    double dashed_max = 0.0;
-    double label_min = 0.0;
-    double x_size = -1.0;
-    double y_size = -1.0;
-    string name = "reaction_paths";
-    string dot_options = "center=1;";
+    double bold_min = 0.2;  //!< Minimum relative flux for bold lines.
+    double dashed_max = 0.0;  //!< Maximum relative flux for dashed lines.
+    double label_min = 0.0;  //!< Minimum relative flux for labels.
+    double x_size = -1.0;  //!< Maximum size (x-dimension).
+    double y_size = -1.0;  //!< Maximum size (y-dimension).
+    string name = "reaction_paths";  //!< Name used for dot export.
+    string dot_options = "center=1;";  //!< Options for the 'dot' program.
+    //! The way flows are drawn. Either 'NetFlow' or 'OneWayFlow'
     flow_t flow_type = NetFlow;
-    double scale = -1;
+    //! The scaling factor for the fluxes.
+    //! Set to -1 to normalize by the maximum net flux.
+    double scale = -1;  //!< Scale to use for normalization.
+    //! The arrow width. If < 0, then scale with flux value.
     double arrow_width = -5.0;
-    bool show_details = false;
-    double arrow_hue = 0.6666;
+    bool show_details = false;  //!< Boolean flag to show details.
+    double arrow_hue = 0.6666;  //!< Unused.
+
+    //! @}
 
 protected:
     double m_flxmax = 0.0;
@@ -291,6 +353,11 @@ protected:
     //! Indices of reactions that are included in the diagram
     set<size_t> m_rxns;
     size_t m_local = npos;
+
+    bool m_isBuilt = false;  //!< Boolean indicating whether diagram is built.
+    shared_ptr<Kinetics> m_kin;  //!< Kinetics used by ReactionPathBuilder
+    shared_ptr<ReactionPathBuilder> m_builder;  //!< Shared pointer to ReactionPathBuilder
+    std::stringstream m_log;  //!< Logging stream.
 };
 
 
@@ -334,6 +401,18 @@ protected:
     map<string, size_t> m_enamemap;
 };
 
+
+//! Create a new reaction path diagram.
+/**
+ *  Returns a shared ReactionPathDiagram instance where the fluxes of `element`
+ *  are calculated according to instantaneous net reaction rates.
+ *  @param kin  Shared pointer to Kinetics object.
+ *  @param element  Element used for the calculation of net reaction rates.
+ *  @return shared_ptr<ReactionPathDiagram>
+ */
+shared_ptr<ReactionPathDiagram> newReactionPathDiagram(
+    shared_ptr<Kinetics> kin, const string& element);
+
 }
 
 #endif
