@@ -17,7 +17,7 @@
 #include "oneD/Sim1D.h"
 #include "oneD/Domain1D.h"
 #include "oneD/Boundary1D.h"
-#include "oneD/StFlow.h"
+#include "oneD/Flow1D.h"
 #include "oneD/refine.h"
 
 #endif
