@@ -10,43 +10,69 @@
 #define CT_PLASMAPHASE_H
 
 #include "cantera/thermo/IdealGasPhase.h"
+#include "cantera/thermo/EEDFTwoTermApproximation.h"
 #include "cantera/numerics/eigen_sparse.h"
 
 namespace Cantera
 {
 
-/**
- * Base class for a phase with plasma properties. This class manages the
- * plasma properties such as electron energy distribution function (EEDF).
- * There are two ways to define the electron distribution and electron
- * temperature. The first method uses setElectronTemperature() to set
- * the electron temperature which is used to calculate the electron energy
- * distribution with isotropic-velocity model. The generalized electron
- * energy distribution for isotropic-velocity distribution can be
- * expressed as [1,2],
+class Reaction;
+class ElectronCollisionPlasmaRate;
+
+//! Base class for handling plasma properties, specifically focusing on the
+//! electron energy distribution.
+/*!
+ * This class provides functionality to manage the the electron energy distribution
+ * using two primary methods for defining the electron distribution and electron
+ * temperature.
+ *
+ * The first method utilizes setElectronTemperature(), which sets the electron
+ * temperature and calculates the electron energy distribution assuming an
+ * isotropic-velocity model. Note that all units in PlasmaPhase are in SI, except
+ * for electron energy, which is measured in volts.
+ *
+ * The generalized electron energy distribution for an isotropic-velocity
+ * distribution (as described by Gudmundsson @cite gudmundsson2001 and Khalilpour
+ * and Foroutan @cite khalilpour2020)
+ * is given by:
  *   @f[
  *          f(\epsilon) = c_1 \frac{\sqrt{\epsilon}}{\epsilon_m^{3/2}}
- *          \exp(-c_2 (\frac{\epsilon}{\epsilon_m})^x),
+ *          \exp \left(-c_2 \left(\frac{\epsilon}{\epsilon_m}\right)^x \right),
  *   @f]
- * where @f$ x = 1 @f$ and @f$ x = 2 @f$ correspond to the Maxwellian and
- * Druyvesteyn (default) electron energy distribution, respectively.
- * @f$ \epsilon_m = 3/2 T_e @f$ [eV] (mean electron energy). The second
- * method uses setDiscretizedElectronEnergyDist() to manually set electron
- * energy distribution and calculate electron temperature from mean electron
- * energy, which is calculated as [3],
- *   @f[
- *          \epsilon_m = \int_0^{\infty} \epsilon^{3/2} f(\epsilon) d\epsilon,
- *   @f]
- * which can be calculated using trapezoidal rule,
- *   @f[
- *          \epsilon_m = \sum_i (\epsilon^{5/2}_{i+1} - \epsilon^{5/2}_i)
- *                       (f(\epsilon_{i+1}) + f(\epsilon_i)) / 2,
- *   @f]
- * where @f$ i @f$ is the index of energy levels.
+ * where @f$ x = 1 @f$ corresponds to a Maxwellian distribution and
+ * @f$ x = 2 @f$ corresponds to a Druyvesteyn distribution.
+ * Here, @f$ \epsilon_m = \frac{3}{2} T_e @f$ [V] represents the
+ * mean electron energy.
  *
- * For references, see Gudmundsson @cite gudmundsson2001; Khalilpour and Foroutan
- * @cite khalilpour2020; Hagelaar and Pitchford @cite hagelaar2005, and BOLOS
- * @cite BOLOS.
+ * The total probability distribution integrates to one:
+ *   @f[
+ *           \int_0^{\infty} f(\epsilon) d\epsilon = 1.
+ *   @f]
+ * According to Hagelaar and Pitchford @cite hagelaar2005, the electron energy
+ * probability function can be defined as
+ * @f$ F(\epsilon) = \frac{f(\epsilon)}{\sqrt{\epsilon}} @f$ with units of
+ * [V@f$^{-3/2}@f$]. The generalized form of the electron energy probability
+ * function for isotropic-velocity distributions is:
+ *   @f[
+ *          F(\epsilon) = c_1 \frac{1}{\epsilon_m^{3/2}}
+ *          \exp\left(-c_2 \left(\frac{\epsilon}{\epsilon_m}\right)^x\right),
+ *   @f]
+ * and this form is used to model the isotropic electron energy distribution
+ * in PlasmaPhase.
+ *
+ * The second method allows for manual definition of the electron energy
+ * distribution using setDiscretizedElectronEnergyDist(). In this approach,
+ * the electron temperature is derived from the mean electron energy,
+ * @f$ \epsilon_m @f$, which can be calculated as follows @cite hagelaar2005 :
+ *   @f[
+ *          \epsilon_m = \int_0^{\infty} \epsilon^{3/2} F(\epsilon) d\epsilon.
+ *   @f]
+ * This integral can be approximated using the trapezoidal rule,
+ *   @f[
+ *          \epsilon_m = \sum_i \left(\epsilon_{i+1}^{5/2} - \epsilon_i^{5/2}\right)
+ *                       \frac{F(\epsilon_{i+1}) + F(\epsilon_i)}{2},
+ *   @f]
+ * where @f$ i @f$ is the index of discrete energy levels, or Simpson's rule.
  *
  * @warning  This class is an experimental part of %Cantera and may be
  *           changed or removed without notice.
@@ -71,6 +97,8 @@ public:
      */
     explicit PlasmaPhase(const string& inputFile="", const string& id="");
 
+    ~PlasmaPhase();
+
     string type() const override {
         return "plasma";
     }
@@ -99,13 +127,6 @@ public:
                                           const double* distrb,
                                           size_t length);
 
-    //! Set discretized electron energy distribution.
-    //! @param  distrb The vector of electron energy distribution.
-    //!                Length: #m_nPoints.
-    //! @param  length The length of the vectors, which equals #m_nPoints.
-    void setDiscretizedElectronEnergyDist(const double* distrb,
-                                          size_t length);
-
     //! Get electron energy distribution.
     //! @param  distrb The vector of electron energy distribution.
     //!                Length: #m_nPoints.
@@ -198,6 +219,24 @@ public:
         return m_nPoints;
     }
 
+    //! Number of electron collision cross sections
+    size_t nCollisions() const {
+        return m_collisions.size();
+    }
+
+    //! Get the Reaction object associated with electron collision *i*.
+    //! @since New in %Cantera 3.2.
+    const shared_ptr<Reaction> collision(size_t i) const {
+        return m_collisions[i];
+    }
+
+    //! Get the ElectronCollisionPlasmaRate object associated with electron collision
+    //! *i*.
+    //! @since New in %Cantera 3.2.
+    const shared_ptr<ElectronCollisionPlasmaRate> collisionRate(size_t i) const {
+        return m_collisionRates[i];
+    }
+
     //! Electron Species Index
     size_t electronSpeciesIndex() const {
         return m_electronSpeciesIndex;
@@ -213,7 +252,7 @@ public:
      * enthalpies @f$ \hat h^0_k(T) @f$ are computed by the species
      * thermodynamic property manager.
      *
-     * \see MultiSpeciesThermo
+     * @see MultiSpeciesThermo
      */
     double enthalpy_mole() const override;
 
@@ -256,6 +295,9 @@ public:
     void setParameters(const AnyMap& phaseNode,
                        const AnyMap& rootNode=AnyMap()) override;
 
+    //! Update the electron energy distribution.
+    void updateElectronEnergyDistribution();
+
     //! Electron species name
     string electronSpeciesName() const {
         return speciesName(m_electronSpeciesIndex);
@@ -271,6 +313,70 @@ public:
         return m_levelNum;
     }
 
+    //! Get the indicies for inelastic electron collisions
+    //! @since New in %Cantera 3.2.
+    const vector<size_t>& kInelastic() const {
+        return m_kInelastic;
+    }
+
+    //! Get the indices for elastic electron collisions
+    //! @since New in %Cantera 3.2.
+    const vector<size_t>& kElastic() const {
+        return m_kElastic;
+    }
+
+    //! target of a specific process
+    //! @since New in %Cantera 3.2.
+    size_t targetIndex(size_t i) const {
+        return m_targetSpeciesIndices[i];
+    }
+
+    //! Get the frequency of the applied electric field [Hz]
+    //! @since New in %Cantera 3.2.
+    double electricFieldFrequency() const {
+        return m_electricFieldFrequency;
+    }
+
+    //! Get the applied electric field strength [V/m]
+    double electricField() const {
+        return m_electricField;
+    }
+
+    //! Set the absolute electric field strength [V/m]
+    void setElectricField(double E) {
+        m_electricField = E;
+    }
+
+    //! Calculate the degree of ionization
+    //double ionDegree() const {
+    //    double ne = concentration(m_electronSpeciesIndex); // [kmol/m³]
+    //    double n_total = molarDensity();                   // [kmol/m³]
+    //    return ne / n_total;
+    //}
+
+    //! Get the reduced electric field strength [V·m²]
+    double reducedElectricField() const {
+        return m_electricField / (molarDensity() * Avogadro);
+    }
+
+    //! Set reduced electric field given in [V·m²]
+    void setReducedElectricField(double EN) {
+        m_electricField = EN * molarDensity() * Avogadro; // [V/m]
+    }
+
+    virtual void setSolution(std::weak_ptr<Solution> soln) override;
+
+    /**
+     * The elastic power loss (J/s/m³)
+     *   @f[
+     *     P_k = N_A N_A C_e e \sum_k C_k K_k,
+     *   @f]
+     * where @f$ C_k @f$ and @f$ C_e @f$ are the concentration (kmol/m³) of the
+     * target species and electrons, respectively. @f$ K_k @f$ is the elastic
+     * electron energy loss coefficient (eV-m³/s).
+     */
+    double elasticPowerLoss();
+
 protected:
     void updateThermo() const override;
 
@@ -304,9 +410,6 @@ protected:
      */
     void checkElectronEnergyDistribution() const;
 
-    //! Update electron energy distribution.
-    void updateElectronEnergyDistribution();
-
     //! Set isotropic electron energy distribution
     void setIsotropicElectronEnergyDistribution();
 
@@ -317,8 +420,14 @@ protected:
     //! Electron energy distribution norm
     void normalizeElectronEnergyDistribution();
 
+    //! Update interpolated cross section of a collision
+    bool updateInterpolatedCrossSection(size_t k);
+
+    //! Update electron energy distribution difference
+    void updateElectronEnergyDistDifference();
+
     // Electron energy order in the exponential term
-    double m_isotropicShapeFactor = 2.0;
+    double m_isotropicShapeFactor = 1.0;
 
     //! Number of points of electron energy levels
     size_t m_nPoints = 1001;
@@ -345,7 +454,64 @@ protected:
     //! Flag of normalizing electron energy distribution
     bool m_do_normalizeElectronEnergyDist = true;
 
+    //! Indices of inelastic collisions in m_crossSections
+    vector<size_t> m_kInelastic;
+
+    //! Indices of elastic collisions in m_crossSections
+    vector<size_t> m_kElastic;
+
+    //! electric field [V/m]
+    double m_electricField = 0.0;
+
+    //! electric field freq [Hz]
+    double m_electricFieldFrequency = 0.0;
+
+    //! Cross section data. m_crossSections[i][j], where i is the specific process,
+    //! j is the index of vector. Unit: [m^2]
+    vector<vector<double>> m_crossSections;
+
+    //! Electron energy levels corresponding to the cross section data. m_energyLevels[i][j],
+    //! where i is the specific process, j is the index of vector. Unit: [eV]
+    vector<vector<double>> m_energyLevels;
+
+    //! ionization degree for the electron-electron collisions (tmp is the previous one)
+    //double m_ionDegree = 0.0;
+
+    //! Electron energy distribution Difference dF/dε (V^-5/2)
+    Eigen::ArrayXd m_electronEnergyDistDiff;
+
+    //! Elastic electron energy loss coefficients (eV m3/s)
+    /*! The elastic electron energy loss coefficient for species k is,
+     *   @f[
+     *     K_k = \frac{2 m_e}{m_k} \sqrt{\frac{2 e}{m_e}} \int_0^{\infty} \sigma_k
+     *           \epsilon^2 \left( F_0 + \frac{k_B T}{e}
+     *           \frac{\partial F_0}{\partial \epsilon} \right) d \epsilon,
+     *   @f]
+     * where @f$ m_e @f$ [kg] is the electron mass, @f$ \epsilon @f$ [V] is the
+     * electron energy, @f$ \sigma_k @f$ [m2] is the reaction collision cross section,
+     * @f$ F_0 @f$ [V^(-3/2)] is the normalized electron energy distribution function.
+     */
+    vector<double> m_elasticElectronEnergyLossCoefficients;
+
+    //! Updates the elastic electron energy loss coefficient for collision index i
+    /*! Calculates the elastic energy loss coefficient using the current electron
+        energy distribution and cross sections.
+    */
+    void updateElasticElectronEnergyLossCoefficient(size_t i);
+
+    //! Update elastic electron energy loss coefficients
+    /*! Used by elasticPowerLoss() and other plasma property calculations that
+        depends on #m_elasticElectronEnergyLossCoefficients. This function calls
+        updateInterpolatedCrossSection() before calling
+        updateElasticElectronEnergyLossCoefficient()
+    */
+    void updateElasticElectronEnergyLossCoefficients();
+
 private:
+
+    //! Solver used to calculate the EEDF based on electron collision rates
+    unique_ptr<EEDFTwoTermApproximation> m_eedfSolver = nullptr;
+
     //! Electron energy distribution change variable. Whenever
     //! #m_electronEnergyDist changes, this int is incremented.
     int m_distNum = -1;
@@ -353,6 +519,25 @@ private:
     //! Electron energy level change variable. Whenever
     //! #m_electronEnergyLevels changes, this int is incremented.
     int m_levelNum = -1;
+
+    //! The list of shared pointers of plasma collision reactions
+    vector<shared_ptr<Reaction>> m_collisions;
+
+    //! The list of shared pointers of collision rates
+    vector<shared_ptr<ElectronCollisionPlasmaRate>> m_collisionRates;
+
+    //! The collision-target species indices of #m_collisions
+    vector<size_t> m_targetSpeciesIndices;
+
+    //! The list of whether the interpolated cross sections is ready
+    vector<bool> m_interp_cs_ready;
+
+    //! Set collisions. This function sets the list of collisions and
+    //! the list of target species using #addCollision.
+    void setCollisions();
+
+    //! Add a collision and record the target species
+    void addCollision(shared_ptr<Reaction> collision);
 };
 
 }
