@@ -9,6 +9,9 @@
 #ifndef CT_TRANSPORT_INCL
 #define CT_TRANSPORT_INCL
 
+#pragma message("warning: transport.h is deprecated and will be removed after " \
+                "Cantera 3.2. Use core.h and/or transport/TransportFactory.h instead.")
+
 #include "transport/TransportFactory.h"
 
 #endif
