@@ -25,15 +25,6 @@ public:
     }
 
     void initialize(double t0=0.0) override {}
-
-    //! @deprecated Unused; to be removed after %Cantera 3.1.
-    void insert(ThermoPhase& contents) {
-        warn_deprecated("Reservoir::insert",
-            "Unused; to be removed after Cantera 3.1.");
-        setThermo(contents);
-    }
-
-    using ReactorBase::insert;
 };
 
 }
