@@ -10,15 +10,11 @@ from .utils import *
 from .data import *
 import cantera.interrupts  # Helps with standalone packaging (PyInstaller etc.)
 
-import os
-import sys
 from pathlib import Path
 import warnings
 
 warnings.filterwarnings('default', module='cantera')
-add_directory(Path(__file__).parent / "data")
-add_directory('.')  # Move current working directory to the front of the path
+add_data_directory(Path(__file__).parent / "data")
+add_data_directory('.')  # Move current working directory to the front of the path
 
-# Python interpreter used for converting mechanisms
-if 'PYTHON_CMD' not in os.environ:
-    os.environ['PYTHON_CMD'] = sys.executable
+del warnings, Path, np, os
