@@ -22,23 +22,16 @@ import argparse
 import textwrap
 from email.utils import formatdate
 from pathlib import Path
-
-try:
-    from ruamel import yaml
-except ImportError:
-    import ruamel_yaml as yaml
+from ruamel import yaml
 
 # yaml.version_info is a tuple with the three parts of the version
 yaml_version = yaml.version_info
-# We choose ruamel.yaml 0.15.34 as the minimum version
-# since it is the highest version available in the Ubuntu
-# 18.04 repositories and seems to work. Older versions such as
-# 0.13.14 on CentOS7 and 0.10.23 on Ubuntu 16.04 raise an exception
-# that they are missing the RoundTripRepresenter
-yaml_min_version = (0, 15, 34)
+# We choose ruamel.yaml 0.17.16 as the minimum version since it is the highest version
+# available in the Ubuntu 22.04 repositories.
+yaml_min_version = (0, 17, 16)
 if yaml_version < yaml_min_version:
     raise RuntimeError(
-        "The minimum supported version of ruamel.yaml is 0.15.34. If you "
+        "The minimum supported version of ruamel.yaml is 0.17.16. If you "
         "installed ruamel.yaml from your operating system's package manager, "
         "please install an updated version using pip or conda."
     )
@@ -67,19 +60,6 @@ def FlowList(*args, **kwargs):
     lst.fa.set_flow_style()
     return lst
 
-# Improved float formatting requires Numpy >= 1.14
-if hasattr(np, 'format_float_positional'):
-    def float2string(data):
-        if data == 0:
-            return '0.0'
-        elif 0.01 <= abs(data) < 10000:
-            return np.format_float_positional(data, trim='0')
-        else:
-            return np.format_float_scientific(data, trim='0')
-else:
-    def float2string(data):
-        return repr(data)
-
 def represent_float(self, data):
     if data != data:
         value = '.nan'
@@ -87,8 +67,12 @@ def represent_float(self, data):
         value = '.inf'
     elif data == -self.inf_value:
         value = '-.inf'
+    elif data == 0:
+        value = '0.0'
+    elif 0.01 <= abs(data) < 10000:
+        value = np.format_float_positional(data, trim='0')
     else:
-        value = float2string(data)
+        value = np.format_float_scientific(data, trim='0')
 
     return self.represent_scalar(u'tag:yaml.org,2002:float', value)
 
@@ -1737,11 +1721,12 @@ class Parser:
         # First line contains optional parameters, followed by species declarations
         tokens = lines[0,2].split() or ['']
         self.current_range = [lines[0,0]] * 2
-        if '/' in tokens[0]:
-            surf_name = tokens[0].split('/')[1]
+        if tokens[0].startswith('/'):
+            surf_name = tokens[0].strip('/')
+            tokens = tokens[1:]
         else:
             surf_name = 'surface{}'.format(len(self.surfaces)+1)
-        tokens = tokens[1:]
+
         site_density = None
         for token in tokens[:]:
             if token.upper().startswith('SDEN/'):
@@ -2051,7 +2036,7 @@ class Parser:
             metadata = BlockMap([
                 ("generator", "ck2yaml"),
                 ("input-files", FlowList(self.files)),
-                ("cantera-version", "3.1.0"),
+                ("cantera-version", "3.2.0"),
                 ("date", formatdate(localtime=True)),
             ])
             if desc.strip():
@@ -2267,7 +2252,7 @@ class Parser:
 
 
 def convert(input_file, thermo_file=None, transport_file=None,
-            surface_file=None, phase_name='gas', extra_file=None,
+            surface_file=None, *, phase_name='gas', extra_file=None,
             out_name=None, single_intermediate_temperature=False, quiet=False,
             permissive=None, verbose=False):
     _, surface_names = Parser.convert_mech(
@@ -2276,23 +2261,6 @@ def convert(input_file, thermo_file=None, transport_file=None,
     return surface_names
 
 
-def convert_mech(input_file, thermo_file=None, transport_file=None,
-                 surface_file=None, phase_name='gas', extra_file=None,
-                 out_name=None, single_intermediate_temperature=False, quiet=False,
-                 permissive=None, verbose=False):
-    """
-    .. deprecated:: 3.0
-
-        To be removed after Cantera 3.1; renamed to :func:`convert`.
-    """
-    warnings.warn(
-        "To be removed after Cantera 3.1; renamed to 'convert'")
-    _, surface_names = Parser.convert_mech(
-        input_file, thermo_file, transport_file, surface_file, phase_name, extra_file,
-        out_name, single_intermediate_temperature, quiet, permissive, verbose)
-    return surface_names
-
-
 def main(argv=None):
     """Parse command line arguments and pass them to `Parser.convert_mech`."""
     parser = create_argparser()
