@@ -1,11 +1,11 @@
 # This file is part of Cantera. See License.txt in the top-level directory or
 # at https://cantera.org/license.txt for license and copyright information.
 
-from pathlib import Path
-from ._utils import get_data_directories, add_directory
+from pathlib import Path as _Path
+from ._utils import get_data_directories, add_data_directory
 
 
-def list_data_files(ext=".yaml"):
+def list_data_files(ext: str = ".yaml") -> list[str]:
     """
     Lists input data files. Includes files in subdirectories, except for subdirectories
     of the current working directory.
@@ -15,9 +15,9 @@ def list_data_files(ext=".yaml"):
     :return:
         List of input data files.
     """
-    data_files = set()
+    data_files: set[str] = set()
     for folder in get_data_directories():
-        here = Path(folder)
+        here = _Path(folder)
         if folder == ".":
             data_files.update(f.name for f in here.glob(f"*{ext}"))
         elif here.is_dir():
