@@ -3,23 +3,18 @@
 
 using System.Text.RegularExpressions;
 using Cantera.Interop;
-using Xunit;
 
 namespace Cantera.Tests;
 
 public class ExceptionTest
 {
-    class FooException : Exception { }
+    class FooException : Exception;
 
     [Fact]
     public void CanteraException_Thrown()
     {
-        var handle = LibCantera.soln_newSolution(".yaml", "", "");
-
-        Assert.True(handle.IsInvalid);
-
         // test that an error message is gathered from the native library
-        Assert.Throws<CanteraException>(() => CanteraException.ThrowLatest());
+        Assert.Throws<CanteraException>(() => LibCantera.sol_newSolution(".yaml", "", ""));
     }
 
     [Fact]
