@@ -1,7 +1,7 @@
 // This file is part of Cantera. See License.txt in the top-level directory or
 // at https://cantera.org/license.txt for license and copyright information.
 
-using Xunit;
+[assembly: AssemblyFixture(typeof(Cantera.Tests.ApplicationFixture))]
 
 namespace Cantera.Tests;
 
@@ -12,6 +12,3 @@ public class ApplicationFixture
         Application.DataDirectories.AddAssemblyDirectory();
     }
 }
-
-[CollectionDefinition("Application")]
-public class DatabaseCollection : ICollectionFixture<ApplicationFixture> { }
