@@ -14,12 +14,11 @@ depends on variables other than time by capturing these variables from the
 enclosing scope. Also shows the use of a `PressureController` to create a constant
 pressure reactor with a fixed volume.
 
-Requires: cantera >= 3.0, matplotlib >= 2.0
+Requires: cantera >= 3.2, matplotlib >= 2.0
 
 .. tags:: Python, combustion, reactor network, well-stirred reactor, plotting
 """
 
-import numpy as np
 import matplotlib.pyplot as plt
 import cantera as ct
 
@@ -34,7 +33,7 @@ gas = ct.Solution('gri30.yaml', transport_model=None)
 equiv_ratio = 0.5  # lean combustion
 gas.TP = 300.0, ct.one_atm
 gas.set_equivalence_ratio(equiv_ratio, 'CH4:1.0', 'O2:1.0, N2:3.76')
-inlet = ct.Reservoir(gas)
+inlet = ct.Reservoir(gas, clone=True)
 
 # %%
 # Create the combustor, and fill it initially with a mixture consisting of the
@@ -43,12 +42,12 @@ inlet = ct.Reservoir(gas)
 # initial condition from which to reach a steady-state solution on the reacting
 # branch.
 gas.equilibrate('HP')
-combustor = ct.IdealGasReactor(gas)
+combustor = ct.IdealGasReactor(gas, clone=True)
 combustor.volume = 1.0
 
 # %%
 # Create a reservoir for the exhaust:
-exhaust = ct.Reservoir(gas)
+exhaust = ct.Reservoir(gas, clone=True)
 
 # %%
 # Use a variable mass flow rate to keep the residence time in the reactor
@@ -79,9 +78,9 @@ states = ct.SolutionArray(gas, extra=['tres'])
 residence_time = 0.1  # starting residence time
 while combustor.T > 500:
     sim.initial_time = 0.0  # reset the integrator
-    sim.advance_to_steady_state()
+    sim.solve_steady()
     print('tres = {:.2e}; T = {:.1f}'.format(residence_time, combustor.T))
-    states.append(combustor.thermo.state, tres=residence_time)
+    states.append(combustor.phase.state, tres=residence_time)
     residence_time *= 0.9  # decrease the residence time for the next iteration
 
 # %%
