@@ -6,7 +6,7 @@ The simulation uses n-dodecane as fuel, which is injected close to top dead
 center. Note that this example uses numerous simplifying assumptions and
 thus serves for illustration purposes only.
 
-Requires: cantera >= 3.0, scipy >= 0.19, matplotlib >= 2.0
+Requires: cantera >= 3.2, scipy >= 0.19, matplotlib >= 2.0
 
 .. tags:: Python, combustion, thermodynamics, internal combustion engine,
           thermodynamic cycle, reactor network, plotting, pollutant formation
@@ -17,6 +17,10 @@ import numpy as np
 
 import matplotlib.pyplot as plt
 
+# Workaround to support both Numpy 1.x and 2.4.0+
+# TODO: Replace when dropping Numpy 1.x support
+trapezoid = getattr(np, "trapezoid", None) or np.trapz
+
 #########################################################################
 # Input Parameters
 #########################################################################
@@ -99,14 +103,14 @@ gas = ct.Solution(reaction_mechanism, phase_name)
 
 # define initial state and set up reactor
 gas.TPX = T_inlet, p_inlet, comp_inlet
-cyl = ct.IdealGasReactor(gas)
+cyl = ct.IdealGasReactor(gas, clone=True)
 cyl.volume = V_oT
 
 # define inlet state
 gas.TPX = T_inlet, p_inlet, comp_inlet
 # Note: The previous line is technically not needed as the state of the gas object is
 # already set correctly; change if inlet state is different from the reactor state.
-inlet = ct.Reservoir(gas)
+inlet = ct.Reservoir(gas, clone=True)
 
 # inlet valve
 inlet_valve = ct.Valve(inlet, cyl)
@@ -117,7 +121,7 @@ inlet_valve.time_function = (
 
 # define injector state (gaseous!)
 gas.TPX = T_injector, p_injector, comp_injector
-injector = ct.Reservoir(gas)
+injector = ct.Reservoir(gas, clone=True)
 
 # injector is modeled as a mass flow controller
 injector_mfc = ct.MassFlowController(injector, cyl)
@@ -129,7 +133,7 @@ injector_mfc.time_function = (
 
 # define outlet pressure (temperature and composition don't matter)
 gas.TPX = T_ambient, p_outlet, comp_ambient
-outlet = ct.Reservoir(gas)
+outlet = ct.Reservoir(gas, clone=True)
 
 # outlet valve
 outlet_valve = ct.Valve(cyl, outlet)
@@ -140,7 +144,7 @@ outlet_valve.time_function = (
 
 # define ambient pressure (temperature and composition don't matter)
 gas.TPX = T_ambient, p_ambient, comp_ambient
-ambient_air = ct.Reservoir(gas)
+ambient_air = ct.Reservoir(gas, clone=True)
 
 # piston is modeled as a moving wall
 piston = ct.Wall(ambient_air, cyl)
@@ -158,7 +162,7 @@ cyl.set_advance_limit('temperature', delta_T_max)
 
 # set up output data arrays
 states = ct.SolutionArray(
-    cyl.thermo,
+    cyl.phase,
     extra=('t', 'ca', 'V', 'm', 'mdot_in', 'mdot_out', 'dWv_dt'),
 )
 
@@ -171,11 +175,11 @@ while sim.time < t_stop:
     sim.advance(sim.time + dt)
 
     # calculate results to be stored
-    dWv_dt = - (cyl.thermo.P - ambient_air.thermo.P) * A_piston * \
+    dWv_dt = - (cyl.phase.P - ambient_air.phase.P) * A_piston * \
         piston_speed(sim.time)
 
     # append output data
-    states.append(cyl.thermo.state,
+    states.append(cyl.phase.state,
                   t=sim.time, ca=crank_angle(sim.time),
                   V=cyl.volume, m=cyl.mass,
                   mdot_in=inlet_valve.mass_flow_rate,
@@ -252,13 +256,13 @@ plt.show()
 ######################################################################
 
 # heat release
-Q = np.trapz(states.heat_release_rate * states.V, t)
+Q = trapezoid(states.heat_release_rate * states.V, t)
 output_str = '{:45s}{:>4.1f} {}'
 print(output_str.format('Heat release rate per cylinder (estimate):',
                         Q / t[-1] / 1000., 'kW'))
 
 # expansion power
-W = np.trapz(states.dWv_dt, t)
+W = trapezoid(states.dWv_dt, t)
 print(output_str.format('Expansion power per cylinder (estimate):',
                         W / t[-1] / 1000., 'kW'))
 
@@ -268,6 +272,6 @@ print(output_str.format('Efficiency (estimate):', eta * 100., '%'))
 
 # CO emissions
 MW = states.mean_molecular_weight
-CO_emission = np.trapz(MW * states.mdot_out * states('CO').X[:, 0], t)
-CO_emission /= np.trapz(MW * states.mdot_out, t)
+CO_emission = trapezoid(MW * states.mdot_out * states('CO').X[:, 0], t)
+CO_emission /= trapezoid(MW * states.mdot_out, t)
 print(output_str.format('CO emission (estimate):', CO_emission * 1.e6, 'ppm'))
