@@ -6,7 +6,7 @@ This example solves a plug-flow reactor problem of hydrogen-oxygen combustion.
 The PFR is computed by two approaches: The simulation of a Lagrangian fluid
 particle, and the simulation of a chain of reactors.
 
-Requires: cantera >= 3.0, matplotlib >= 2.0
+Requires: cantera >= 3.2, matplotlib >= 2.0
 
 .. tags:: Python, combustion, reactor network, plug flow reactor
 """
@@ -50,7 +50,7 @@ gas1.TPX = T_0, pressure, composition_0
 mass_flow_rate1 = u_0 * gas1.density * area
 
 # create a new reactor
-r1 = ct.IdealGasConstPressureReactor(gas1)
+r1 = ct.IdealGasConstPressureReactor(gas1, clone=True)
 # create a reactor network for performing time integration
 sim1 = ct.ReactorNet([r1])
 
@@ -61,14 +61,14 @@ dt = t_total / n_steps
 t1 = (np.arange(n_steps) + 1) * dt
 z1 = np.zeros_like(t1)
 u1 = np.zeros_like(t1)
-states1 = ct.SolutionArray(r1.thermo)
+states1 = ct.SolutionArray(r1.phase)
 for n1, t_i in enumerate(t1):
     # perform time integration
     sim1.advance(t_i)
     # compute velocity and transform into space
-    u1[n1] = mass_flow_rate1 / area / r1.thermo.density
+    u1[n1] = mass_flow_rate1 / area / r1.phase.density
     z1[n1] = z1[n1 - 1] + u1[n1] * dt
-    states1.append(r1.thermo.state)
+    states1.append(r1.phase.state)
 #####################################################################
 
 
@@ -94,16 +94,16 @@ dz = length / n_steps
 r_vol = area * dz
 
 # create a new reactor
-r2 = ct.IdealGasReactor(gas2)
+r2 = ct.IdealGasReactor(gas2, clone=True)
 r2.volume = r_vol
 
 # create a reservoir to represent the reactor immediately upstream. Note
 # that the gas object is set already to the state of the upstream reactor
-upstream = ct.Reservoir(gas2, name='upstream')
+upstream = ct.Reservoir(gas2, name='upstream', clone=True)
 
 # create a reservoir for the reactor to exhaust into. The composition of
 # this reservoir is irrelevant.
-downstream = ct.Reservoir(gas2, name='downstream')
+downstream = ct.Reservoir(gas2, name='downstream', clone=True)
 
 # The mass flow rate into the reactor will be fixed by using a
 # MassFlowController object.
@@ -115,28 +115,28 @@ m = ct.MassFlowController(upstream, r2, mdot=mass_flow_rate2)
 v = ct.PressureController(r2, downstream, primary=m, K=1e-5)
 
 sim2 = ct.ReactorNet([r2])
+sim2.max_time_step = 1e4
 
 # define time, space, and other information vectors
 z2 = (np.arange(n_steps) + 1) * dz
 t_r2 = np.zeros_like(z2)  # residence time in each reactor
 u2 = np.zeros_like(z2)
 t2 = np.zeros_like(z2)
-states2 = ct.SolutionArray(r2.thermo)
+states2 = ct.SolutionArray(gas2)
 # iterate through the PFR cells
 for n in range(n_steps):
     # Set the state of the reservoir to match that of the previous reactor
-    gas2.TDY = r2.thermo.TDY
+    upstream.phase.TDY = r2.phase.TDY
     upstream.syncState()
     # integrate the reactor forward in time until steady state is reached
     sim2.reinitialize()
     sim2.advance_to_steady_state()
     # compute velocity and transform into time
-    u2[n] = mass_flow_rate2 / area / r2.thermo.density
+    u2[n] = mass_flow_rate2 / area / r2.phase.density
     t_r2[n] = r2.mass / mass_flow_rate2  # residence time in this reactor
     t2[n] = np.sum(t_r2)
     # write output data
-    states2.append(r2.thermo.state)
-
+    states2.append(r2.phase.state)
 #####################################################################
 
 
