@@ -24,12 +24,11 @@ proportional to the pressure difference between the two chambers.
 
 Note that each side uses a *different* reaction mechanism
 
-Requires: cantera >= 2.5.0, matplotlib >= 2.0
+Requires: cantera >= 3.2.0, matplotlib >= 2.0
 
 .. tags:: Python, combustion, reactor network, plotting
 """
 
-import sys
 import cantera as ct
 import matplotlib.pyplot as plt
 plt.rcParams['figure.constrained_layout.use'] = True
@@ -43,9 +42,9 @@ gas1.TPX = 900.0, ct.one_atm, 'H2:2, O2:1, AR:20'
 gas2 = ct.Solution('gri30.yaml')
 gas2.TPX = 900.0, ct.one_atm, 'CO:2, H2O:0.01, O2:5'
 
-r1 = ct.IdealGasReactor(gas1)
+r1 = ct.IdealGasReactor(gas1, clone=True)
 r1.volume = 0.5
-r2 = ct.IdealGasReactor(gas2)
+r2 = ct.IdealGasReactor(gas2, clone=True)
 r2.volume = 0.1
 
 # %%
@@ -55,7 +54,7 @@ def v(t):
     if t < 0.1:
         return 0.0
     else:
-        return (r1.thermo.P - r2.thermo.P) * 1e-4
+        return (r1.phase.P - r2.phase.P) * 1e-4
 
 w = ct.Wall(r1, r2, velocity=v)
 
@@ -63,8 +62,8 @@ net = ct.ReactorNet([r1, r2])
 
 # %%
 # Run the simulation and collect the states of each reactor
-states1 = ct.SolutionArray(r1.thermo, extra=['t', 'volume'])
-states2 = ct.SolutionArray(r2.thermo, extra=['t', 'volume'])
+states1 = ct.SolutionArray(r1.phase, extra=['t', 'volume'])
+states2 = ct.SolutionArray(r2.phase, extra=['t', 'volume'])
 
 fmt = '{:10.3f}  {:10.1f}  {:10.4f}  {:10.4g}  {:10.4g}  {:10.4g}  {:10.4g}'
 print('{:>10}  {:>10}  {:>10}  {:>10}  {:>10}  {:>10}  {:>10}'.format(
@@ -74,10 +73,10 @@ for n in range(200):
     net.advance(time)
     if n % 4 == 3:
         print(fmt.format(time, r1.T, r2.T, r1.volume, r2.volume,
-                         r1.volume + r2.volume, r2.thermo['CO'].X[0]))
+                         r1.volume + r2.volume, r2.phase['CO'].X[0]))
 
-    states1.append(r1.thermo.state, t=1000*time, volume=r1.volume)
-    states2.append(r2.thermo.state, t=1000*time, volume=r2.volume)
+    states1.append(r1.phase.state, t=1000*time, volume=r1.volume)
+    states2.append(r2.phase.state, t=1000*time, volume=r2.volume)
 
 # %%
 # Plot the results
