@@ -8,7 +8,7 @@ platinum catalyst in a packed bed reactor. To avoid needing to solve a DAE syste
 PFR is approximated as a chain of successive WSRs. See :doc:`surf_pfr.py <surf_pfr>` for
 a more advanced implementation that solves the DAE system directly.
 
-Requires: cantera >= 3.0
+Requires: cantera >= 3.2
 
 .. tags:: Python, catalysis, reactor network, surface chemistry, plug flow reactor,
           packed bed reactor
@@ -75,20 +75,20 @@ print('    distance       X_CH4        X_H2        X_CO')
 
 # create a new reactor
 gas.TDY = TDY
-r = ct.IdealGasReactor(gas, energy='off')
+r = ct.IdealGasReactor(gas, energy='off', clone=True)
 r.volume = rvol
 
 # create a reservoir to represent the reactor immediately upstream. Note
 # that the gas object is set already to the state of the upstream reactor
-upstream = ct.Reservoir(gas, name='upstream')
+upstream = ct.Reservoir(gas, name='upstream', clone=True)
 
 # create a reservoir for the reactor to exhaust into. The composition of
 # this reservoir is irrelevant.
-downstream = ct.Reservoir(gas, name='downstream')
+downstream = ct.Reservoir(gas, name='downstream', clone=True)
 
 # Add the reacting surface to the reactor. The area is set to the desired
 # catalyst area in the reactor.
-rsurf = ct.ReactorSurface(surf, r, A=cat_area)
+rsurf = ct.ReactorSurface(surf, r, A=cat_area, clone=True)
 
 # The mass flow rate into the reactor will be fixed by using a
 # MassFlowController object.
@@ -105,7 +105,7 @@ output_data = []
 
 for n in range(NReactors):
     # Set the state of the reservoir to match that of the previous reactor
-    gas.TDY = r.thermo.TDY
+    gas.TDY = r.phase.TDY
     upstream.syncState()
     sim.reinitialize()
     sim.advance_to_steady_state()
@@ -113,13 +113,13 @@ for n in range(NReactors):
 
     if n % 10 == 0:
         print('  {0:10f}  {1:10f}  {2:10f}  {3:10f}'.format(
-            dist, *r.thermo['CH4', 'H2', 'CO'].X))
+            dist, *r.phase['CH4', 'H2', 'CO'].X))
 
     # write the gas mole fractions and surface coverages vs. distance
     output_data.append(
-        [dist, r.T - 273.15, r.thermo.P / ct.one_atm]
-        + list(r.thermo.X)  # use r.thermo.X not gas.X
-        + list(rsurf.kinetics.coverages)  # use rsurf.kinetics.coverages not surf.coverages
+        [dist, r.T - 273.15, r.phase.P / ct.one_atm]
+        + list(r.phase.X)  # use r.phase.X not gas.X
+        + list(rsurf.phase.coverages)  # use rsurf.phase.coverages not surf.coverages
     )
 
 with open(output_filename, 'w', newline="") as outfile:
