@@ -1298,18 +1298,19 @@ def setup_python_env(env):
         import json
         import site
         import sys
+        import setuptools
         vars = get_config_vars()
         vars["plat"] = get_platform()
         vars["numpy_include"] = numpy.get_include()
         vars["site_packages"] = [d for d in site.getsitepackages() if d.endswith("-packages")]
         vars["user_site_packages"] = site.getusersitepackages()
         vars["abiflags"] = getattr(sys, "abiflags", "")
+        vars["setuptools_version"] = setuptools.__version__
         print(json.dumps(vars))
         """)
         _python_info = json.loads(get_command_output(env["python_cmd"], "-c", script))
 
     info = _python_info
-    module_ext = info["EXT_SUFFIX"]
     inc = info["INCLUDEPY"]
     pylib = info.get("LDLIBRARY")
     prefix = info["prefix"]
@@ -1325,22 +1326,14 @@ def setup_python_env(env):
     add_system_include(env, (inc, numpy_include), 'prepend')
     env.Prepend(LIBS=env['cantera_shared_libs'])
 
-    # Fix the module extension for Windows from the sysconfig library.
-    # See https://github.com/python/cpython/pull/22088 and
-    # https://bugs.python.org/issue39825
-    if (py_version_full < parse_version("3.8.7")
-        and env["OS"] == "Windows"
-        and module_ext == ".pyd"
-    ):
-        module_ext = f".cp{py_version_nodot}-{info['plat'].replace('-', '_')}.pyd"
-
-    env["py_module_ext"] = module_ext
+    env["py_module_ext"] = info["EXT_SUFFIX"]
     env["py_version_nodot"] = py_version_nodot
     env["py_version_short"] = info["py_version_short"]
     env["py_plat"] = plat
     env["py_base"] = info["installed_base"]
     env["site_packages"] = info["site_packages"]
     env["user_site_packages"] = info["user_site_packages"]
+    env["setuptools_version"] = parse_version(info["setuptools_version"])
     if env["OS"] != "Windows":
         env["py_libpath"] = [info["LIBPL"], info["LIBDIR"]]
         py_lib = "python" + info["py_version_short"] + info["abiflags"]
@@ -1350,13 +1343,6 @@ def setup_python_env(env):
     env["py_libs"] = [py_lib] + [lib[2:] for lib in info.get("LIBS", "").split()
                                  if lib.startswith("-l")]
 
-    # Don't print deprecation warnings for internal Python changes.
-    # Only applies to Python 3.8. The field that is deprecated in Python 3.8
-    # and causes the warnings to appear will be removed in Python 3.9 so no
-    # further warnings should be issued.
-    if env["HAS_CLANG"] and py_version_short == parse_version("3.8"):
-        env.Append(CXXFLAGS='-Wno-deprecated-declarations')
-
     if env['OS'] == 'Darwin':
         env.Append(LINKFLAGS='-undefined dynamic_lookup')
     elif env['OS'] == 'Windows':
@@ -1492,12 +1478,7 @@ def check_for_python(
                 from ruamel import yaml
                 versions["ruamel.yaml"] = yaml.__version__
             except ImportError as ru_err:
-                try:
-                    import ruamel_yaml as yaml
-                    versions["ruamel.yaml"] = yaml.__version__
-                except ImportError as ru_err_2:
-                    err += str(ru_err) + "\\n"
-                    err += str(ru_err_2) + "\\n"
+                err += str(ru_err) + "\\n"
         """)
     if check_for_pytest:
         script += check_module("pytest")
@@ -1748,9 +1729,9 @@ def check_sundials(conf: "SConfigure", sundials_version: str) -> Dict[str, Union
               compatible version of SUNDIALS was found in the system directories.
             * ``"sundials_version"``: String with the parsed version of SUNDIALS with
               periods between the version components.
-            * ``"sundials_blas_lapack"``: Boolean or integer indicating whether SUNDIALS was built
-              with BLAS/LAPACK support. Always ``False`` if ``"system_sundials"`` is
-              ``"n"``.
+            * ``"has_sundials_lapack"``: Boolean or integer indicating whether SUNDIALS
+              was built with BLAS/LAPACK support. Always ``False`` if
+              ``"system_sundials"`` is ``"n"``.
 
     Raises:
         ``config_error``: If the user specified ``system_sundials==y`` but a compatible
@@ -1759,17 +1740,40 @@ def check_sundials(conf: "SConfigure", sundials_version: str) -> Dict[str, Union
     sundials_ver = parse_version(
         ".".join(sundials_version.strip().replace('"', "").split())
     )
+    bundled_sundials = {
+        "system_sundials": "n", "sundials_version": "", "has_sundials_lapack": 0}
     should_exit_with_error = conf.env["system_sundials"] == "y"
-    if sundials_ver < parse_version("3.0") or sundials_ver >= parse_version("8.0"):
+
+    if sundials_ver < parse_version("5.0") or sundials_ver >= parse_version("8.0"):
         if should_exit_with_error:
-            config_error(f"Sundials version must be >=3.0,<8.0. Found {sundials_ver}.")
-        return {"system_sundials": "n", "sundials_version": "", "has_sundials_lapack": 0}
+            config_error(f"Sundials version must be >=5.0,<8.0. Found {sundials_ver}.")
+        return bundled_sundials
     elif sundials_ver > parse_version("7.2.0"):
         logger.warning(f"Sundials version {sundials_ver} has not been tested.")
 
+    if sundials_ver >= parse_version("7.0.0"):
+        _, uses_mpi = run_preprocessor(
+            conf, ['"sundials/sundials_config.h"'], "SUNDIALS_MPI_ENABLED")
+        mpi_header = conf.CheckCXXHeader('mpi.h', '""')
+        if uses_mpi == "1" and not mpi_header:
+            if should_exit_with_error:
+                config_error(
+                    f"System installation of Sundials version {sundials_ver} has MPI "
+                    "support enabled,\nbut the required 'mpi.h' header file cannot be "
+                    "found. To resolve this issue,\nchoose one of the following "
+                    "options when running the 'scons build' command:\n"
+                    "- Add 'CC=mpicc CXX=mpicxx' (as well as 'FORTRAN=mpifort', if "
+                    "applicable)\n  to use MPI compiler wrappers, or\n"
+                    "- Remove 'system_sundials=y' to disable the system Sundials "
+                    "installation.")
+            logger.warning(
+                f"System installation of Sundials version {sundials_ver} has MPI "
+                "support enabled,\nbut the 'mpi.h' header file cannot be found. "
+                "Using private Sundials version instead.")
+            return bundled_sundials
+
     cvode_checks = {
-        SpecifierSet(">=3.0,<4.0"): ("CVodeCreate(CV_BDF, CV_NEWTON);", ["sundials_cvodes"]),
-        SpecifierSet(">=4.0,<6.0"): ("CVodeCreate(CV_BDF);", ["sundials_cvodes"]),
+        SpecifierSet(">=5.0,<6.0"): ("CVodeCreate(CV_BDF);", ["sundials_cvodes"]),
         SpecifierSet(">=6.0,<7.0"): (
             "SUNContext ctx; SUNContext_Create(0, &ctx);", ["sundials_cvodes"]
         ),
@@ -1793,7 +1797,7 @@ def check_sundials(conf: "SConfigure", sundials_version: str) -> Dict[str, Union
                         "Could not link to the Sundials library. Did you set the "
                         "include/library paths?"
                     )
-                return {"system_sundials": "n", "sundials_version": "", "has_sundials_lapack": 0}
+                return bundled_sundials
             break
 
     logger.info(f"Using system installation of Sundials version {sundials_ver}.")
