@@ -99,6 +99,10 @@ bool isBool(const string& val) {
     return (val == "true" || val == "True" || val == "false" || val == "False");
 }
 
+bool dunder(const string& s) {
+    return ba::starts_with(s, "__") && ba::ends_with(s, "__");
+}
+
 enum class Type : char {
     Unknown = 0,
     Integer = 1,
@@ -109,6 +113,12 @@ enum class Type : char {
     Sequence = 32
 };
 
+// Map items of type `Exclude` are skipped in any iteration / output
+struct Exclude {};
+bool operator==(const Exclude& lhs, const Exclude& rhs) {
+    return true;
+}
+
 Type operator|(Type lhs, Type rhs)
 {
     return Type(static_cast<char>(lhs) | static_cast<char>(rhs));
@@ -125,7 +135,10 @@ Type elementTypes(const YAML::Node& node)
             types = types | Type::Sequence;
         } else if (el.IsScalar()) {
             string nodestr = el.as<string>();
-            if (isInt(nodestr)) {
+            if (el.Tag() == "!") {
+                // Prevent implicit conversion of quoted strings to numeric types
+                types = types | Type::String;
+            } else if (isInt(nodestr)) {
                 types = types | Type::Integer;
             } else if (isFloat(nodestr)) {
                 types = types | Type::Double;
@@ -164,7 +177,7 @@ string formatDouble(double x, long int precision)
     size_t last;
     string s0;
     if (useExp) {
-        s0 = fmt::format(fmt::format("{:.{}e}", x, precision));
+        s0 = fmt::format(fmt::runtime(fmt::format("{:.{}e}", x, precision)));
         // last digit of significand
         last = s0.size() - 5;
         if (s0[last + 1] == 'e') {
@@ -195,7 +208,7 @@ string formatDouble(double x, long int precision)
     if (s0[last - 1] == '0') {
         s1 = s0; // Recycle original string
     } else if (useExp) {
-        s1 = fmt::format(fmt::format("{:.{}e}", x, precision - 2));
+        s1 = fmt::format(fmt::runtime(fmt::format("{:.{}e}", x, precision - 2)));
     } else {
         s1 = fmt::format("{:.{}f}", x, precision - log10x - 2);
     }
@@ -246,6 +259,9 @@ struct convert<Cantera::AnyMap> {
 
     static bool decode(const Node& node, Cantera::AnyMap& target) {
         target.setLoc(node.Mark().line, node.Mark().column);
+        if (node.Style() == YAML::EmitterStyle::Flow) {
+            target.setFlowStyle();
+        }
         if (node.IsSequence()) {
             // Convert a top-level list to a map with the key "items"
             target["items"] = node.as<AnyValue>();
@@ -280,13 +296,18 @@ YAML::Emitter& operator<<(YAML::Emitter& out, const AnyMap& rhs)
         out << YAML::Flow;
         out << YAML::BeginMap;
         size_t width = 15;
-        for (const auto& [name, value] : rhs.ordered()) {
+        for (const auto& [name, value] : rhs.ordered(true)) {
             string valueStr;
             bool foundType = true;
+            bool needsQuotes = false;
             if (value.is<double>()) {
                 valueStr = formatDouble(value.asDouble(), getPrecision(value));
             } else if (value.is<string>()) {
                 valueStr = value.asString();
+                if (isFloat(valueStr)) {
+                    // Quote strings that look like numbers to preserve their type
+                    needsQuotes = true;
+                }
             } else if (value.is<long int>()) {
                 valueStr = fmt::format("{}", value.asInt());
             } else if (value.is<bool>()) {
@@ -303,6 +324,9 @@ YAML::Emitter& operator<<(YAML::Emitter& out, const AnyMap& rhs)
                     width = 15;
                 }
                 out << name;
+                if (needsQuotes) {
+                    out << YAML::SingleQuoted;
+                }
                 out << valueStr;
                 width += name.size() + valueStr.size() + 4;
             } else {
@@ -315,7 +339,7 @@ YAML::Emitter& operator<<(YAML::Emitter& out, const AnyMap& rhs)
         }
     } else {
         out << YAML::BeginMap;
-        for (const auto& [key, value] : rhs.ordered()) {
+        for (const auto& [key, value] : rhs.ordered(true)) {
             out << key;
             out << value;
         }
@@ -326,35 +350,18 @@ YAML::Emitter& operator<<(YAML::Emitter& out, const AnyMap& rhs)
 
 //! Write YAML strings spanning multiple lines if input includes endline '\n'
 void emitString(YAML::Emitter& out, const string& str0) {
-    size_t endline = str0.rfind('\n');
-    if (endline == string::npos) {
+    if (str0.rfind('\n') == string::npos) {
+        if (isFloat(str0)) {
+            out << YAML::SingleQuoted;
+        }
         out << str0;
         return;
     }
 
-    // Remove trailing line break
-    string str1 = str0;
-    if (endline == str1.size() - 1) {
-        str1.erase(endline, 1);
-        endline = str1.rfind('\n');
-    }
-
-    // Deblank lines (remove whitespace surrounding line breaks)
-    while (endline != string::npos) {
-        size_t len = 1;
-        while (str1[endline + len] == ' ') {
-            len++; // account for whitespace after line break
-        }
-        while (str1[endline - 1] == ' ') {
-            len++; // account for whitespace before line break
-            endline--;
-        }
-        if (len > 1) {
-            // remove surrounding whitespace
-            str1.replace(endline, len, "\n");
-        }
-        endline = str1.rfind('\n', endline - 1);
-    }
+    // Remove leading and trailing whitespace
+    size_t left = str0.find_first_not_of("\n\t ");
+    size_t right = str0.find_last_not_of("\n\t ");
+    string str1 = str0.substr(left, right - left + 1);
     out << YAML::Literal << str1;
 }
 
@@ -380,6 +387,30 @@ void emitFlowVector(YAML::Emitter& out, const vector<double>& v, long int precis
     out << YAML::EndSeq;
 }
 
+//! Write a vector in YAML "flow" style, wrapping lines to avoid exceeding the
+//! preferred maximum line length (set by `max_line_length`). Specialized for
+//! `vector<string>` to quote strings that look like numeric values
+void emitFlowVector(YAML::Emitter& out, const vector<string>& v)
+{
+    out << YAML::Flow;
+    out << YAML::BeginSeq;
+    size_t width = 15; // wild guess, but no better value is available
+    for (const string& x : v) {
+        // Wrap to the next line if this item would exceed the target line length
+        if (width + x.size() > max_line_length) {
+            out << YAML::Newline;
+            width = 15;
+        }
+        if (isFloat(x)) {
+            out << SingleQuoted;
+            width += 2;
+        }
+        out << x;
+        width += x.size() + 2;
+    }
+    out << YAML::EndSeq;
+}
+
 //! Write a vector in YAML "flow" style, wrapping lines to avoid exceeding the
 //! preferred maximum line length (set by `max_line_length`).
 template <typename T>
@@ -571,6 +602,18 @@ std::unordered_map<string, vector<string>> AnyMap::s_tailFields;
 
 // Methods of class AnyBase
 
+AnyBase& AnyBase::operator=(const AnyBase& other)
+{
+    m_metadata = other.m_metadata;
+    // Copy location information only if it's been set from an input file. Otherwise,
+    // the ordering information at the destination is more important to preserve.
+    if (other.m_line != -1 && other.m_column >= 0) {
+        m_line = other.m_line;
+        m_column = other.m_column;
+    }
+    return *this;
+}
+
 void AnyBase::setLoc(int line, int column)
 {
     m_line = line;
@@ -767,19 +810,19 @@ bool operator!=(const string& lhs, const AnyValue& rhs)
 // Specialization for "Quantity"
 
 void AnyValue::setQuantity(double value, const string& units, bool is_act_energy) {
-    m_value = Quantity{AnyValue(value), Units(units), is_act_energy};
+    m_value = Quantity{AnyValue(value), Units(units), is_act_energy, {}};
     m_equals = eq_comparer<Quantity>;
 }
 
 void AnyValue::setQuantity(double value, const Units& units) {
-    m_value = Quantity{AnyValue(value), units, false};
+    m_value = Quantity{AnyValue(value), units, false, {}};
     m_equals = eq_comparer<Quantity>;
 }
 
 void AnyValue::setQuantity(const vector<double>& values, const string& units) {
     AnyValue v;
     v = values;
-    m_value = Quantity{v, Units(units), false};
+    m_value = Quantity{v, Units(units), false, {}};
     m_equals = eq_comparer<Quantity>;
 }
 
@@ -973,6 +1016,13 @@ AnyValue& AnyValue::operator=(AnyMap&& value) {
     return *this;
 }
 
+AnyValue AnyValue::exclude() {
+    AnyValue v;
+    v.m_value = Exclude();
+    v.m_equals = eq_comparer<Exclude>;
+    return v;
+}
+
 std::unordered_map<string, const AnyMap*> AnyValue::asMap(const string& name) const
 {
     std::unordered_map<string, const AnyMap*> mapped;
@@ -1417,12 +1467,17 @@ const AnyValue& AnyMap::at(const string& key) const
 
 bool AnyMap::empty() const
 {
-    return m_data.size() == 0;
+    // Iterate to check for non-hidden, non-excluded elements
+    for ([[maybe_unused]] const auto& item : *this) {
+        return false;
+    }
+    return true;
 }
 
 bool AnyMap::hasKey(const string& key) const
 {
-    return (m_data.find(key) != m_data.end());
+    auto iter = m_data.find(key);
+    return (iter != m_data.end() && !iter->second.is<Exclude>());
 }
 
 void AnyMap::erase(const string& key)
@@ -1437,13 +1492,18 @@ void AnyMap::clear()
 
 void AnyMap::update(const AnyMap& other, bool keepExisting)
 {
-    for (const auto& [key, value] : other) {
-        if (!keepExisting || !hasKey(key)) {
+    for (const auto& [key, value] : other.ordered()) {
+        if (!keepExisting || m_data.count(key) == 0) {
             (*this)[key] = value;
         }
     }
 }
 
+void AnyMap::exclude(const string& key)
+{
+    m_data[key] = AnyValue::exclude();
+}
+
 string AnyMap::keys_str() const
 {
     fmt::memory_buffer b;
@@ -1564,9 +1624,7 @@ AnyMap::Iterator::Iterator(
 {
     m_iter = start;
     m_stop = stop;
-    while (m_iter != m_stop
-           && ba::starts_with(m_iter->first, "__")
-           && ba::ends_with(m_iter->first, "__")) {
+    while (m_iter != m_stop && (dunder(m_iter->first) || m_iter->second.is<Exclude>())) {
         ++m_iter;
     }
 }
@@ -1574,20 +1632,20 @@ AnyMap::Iterator::Iterator(
 AnyMap::Iterator& AnyMap::Iterator::operator++()
 {
     ++m_iter;
-    while (m_iter != m_stop
-           && ba::starts_with(m_iter->first, "__")
-           && ba::ends_with(m_iter->first, "__")) {
+    while (m_iter != m_stop && (dunder(m_iter->first) || m_iter->second.is<Exclude>())) {
         ++m_iter;
     }
     return *this;
 }
 
 
-AnyMap::OrderedProxy::OrderedProxy(const AnyMap& data)
+AnyMap::OrderedProxy::OrderedProxy(const AnyMap& data, bool withUnits)
     : m_data(&data)
 {
     // Units always come first
-    if (m_data->hasKey("__units__") && m_data->at("__units__").as<AnyMap>().size()) {
+    if (withUnits && m_data->hasKey("__units__")
+        && m_data->at("__units__").as<AnyMap>().size())
+    {
         m_units = make_unique<pair<const string, AnyValue>>(
             "units", m_data->at("__units__"));
         m_units->second.setFlowStyle();
@@ -1667,6 +1725,16 @@ AnyMap::OrderedIterator::OrderedIterator(
     m_stop = stop;
 }
 
+size_t AnyMap::size() const
+{
+    size_t n = 0;
+    // Iterate to count only non-hidden, non-excluded elements
+    for ([[maybe_unused]] const auto& item : *this) {
+        n++;
+    }
+    return n;
+}
+
 bool AnyMap::operator==(const AnyMap& other) const
 {
     // First, make sure that 'other' has all of the non-hidden keys that are in
@@ -1687,7 +1755,7 @@ bool AnyMap::operator==(const AnyMap& other) const
 
 bool AnyMap::operator!=(const AnyMap& other) const
 {
-    return m_data != other.m_data;
+    return !(*this == other);
 }
 
 void AnyMap::applyUnits()
@@ -1724,7 +1792,7 @@ void AnyMap::setUnits(const UnitSystem& units)
 }
 
 void AnyMap::setFlowStyle(bool flow) {
-    (*this)["__flow__"] = flow;
+    m_data["__flow__"] = flow;
 }
 
 bool AnyMap::addOrderingRules(const string& objectType,
@@ -1733,7 +1801,8 @@ bool AnyMap::addOrderingRules(const string& objectType,
     std::unique_lock<std::mutex> lock(yaml_field_order_mutex);
     for (const auto& spec : specs) {
         if (spec.at(0) == "head") {
-            s_headFields[objectType].push_back(spec.at(1));
+            s_headFields[objectType].insert(s_headFields[objectType].begin(),
+                                            spec.at(1));
         } else if (spec.at(0) == "tail") {
             s_tailFields[objectType].push_back(spec.at(1));
         } else {
@@ -1764,6 +1833,7 @@ AnyMap AnyMap::fromYamlString(const string& yaml) {
         throw InputFileError("AnyMap::fromYamlString", fake, err.msg);
     }
     amap.setMetadata("file-contents", AnyValue(yaml));
+    amap.setLoc(0, 0);
     amap.applyUnits();
     return amap;
 }
@@ -1817,6 +1887,7 @@ AnyMap AnyMap::fromYamlFile(const string& name, const string& parent_name)
         throw;
     }
     cache_item["__file__"] = fullName;
+    cache_item.setLoc(0, 0);
 
     if (cache_item.hasKey("deprecated")) {
         warn_deprecated(fullName, cache_item["deprecated"].asString());
