@@ -33,6 +33,15 @@ void setLogger(Logger* logwriter)
     }
 }
 
+void setLogger(unique_ptr<Logger> logwriter)
+{
+    try {
+        app()->setLogger(std::move(logwriter));
+    } catch (const std::bad_alloc&) {
+        logwriter->error("bad alloc thrown by app()");
+    }
+}
+
 void writelog_direct(const string& msg)
 {
     app()->writelog(msg);
@@ -157,6 +166,13 @@ string gitCommit()
 }
 
 void addDirectory(const string& dir)
+{
+    warn_deprecated("addDirectory",
+                    "To be removed after Cantera 3.2. Renamed to addDataDirectory.");
+    app()->addDataDirectory(dir);
+}
+
+void addDataDirectory(const string& dir)
 {
     app()->addDataDirectory(dir);
 }
