@@ -32,11 +32,13 @@ typedef Cabinet<ThermoPhase> ThermoCabinet;
 typedef Cabinet<Kinetics> KineticsCabinet;
 typedef Cabinet<Transport> TransportCabinet;
 typedef Cabinet<Solution> SolutionCabinet;
+typedef Cabinet<Reaction> ReactionCabinet;
 
 template<> ThermoCabinet* ThermoCabinet::s_storage = 0;
 template<> KineticsCabinet* KineticsCabinet::s_storage = 0;
 template<> TransportCabinet* TransportCabinet::s_storage = 0;
 template<> SolutionCabinet* SolutionCabinet::s_storage = 0;
+template<> ReactionCabinet* ReactionCabinet::s_storage = 0;
 
 /**
  * Exported functions.
@@ -234,10 +236,7 @@ extern "C" {
     {
         try {
             auto soln = SolutionCabinet::at(n);
-            if (a < 0 || a >= static_cast<int>(soln->nAdjacent())) {
-                throw CanteraError("soln_adjacentName", "Invalid index {}.", a);
-            }
-            return static_cast<int>(copyString(soln->adjacent(a)->name(), nm, lennm));
+            return static_cast<int>(copyString(soln->adjacentName(a), nm, lennm));
         } catch (...) {
             return handleAllExceptions(-1, ERR);
         }
@@ -322,7 +321,7 @@ extern "C" {
     size_t thermo_elementIndex(int n, const char* nm)
     {
         try {
-             size_t k = ThermoCabinet::at(n)->elementIndex(nm);
+             size_t k = ThermoCabinet::at(n)->elementIndex(nm, false);
              if (k == npos) {
                 throw CanteraError("thermo_elementIndex",
                                    "No such element {}.", nm);
@@ -336,7 +335,7 @@ extern "C" {
     size_t thermo_speciesIndex(int n, const char* nm)
     {
         try {
-             size_t k = ThermoCabinet::at(n)->speciesIndex(nm);
+             size_t k = ThermoCabinet::at(n)->speciesIndex(nm, false);
              if (k == npos) {
                 throw CanteraError("thermo_speciesIndex",
                                    "No such species {}.", nm);
@@ -1180,7 +1179,7 @@ extern "C" {
     size_t kin_phaseIndex(int n, const char* ph)
     {
         try {
-            size_t k = KineticsCabinet::at(n)->phaseIndex(ph);
+            size_t k = KineticsCabinet::at(n)->phaseIndex(ph, false);
             if (k == npos) {
                 throw CanteraError("kin_phaseIndex",
                                    "No such phase {}.", ph);
@@ -1191,15 +1190,6 @@ extern "C" {
         }
     }
 
-    size_t kin_reactionPhaseIndex(int n)
-    {
-        try {
-            return KineticsCabinet::at(n)->reactionPhaseIndex();
-        } catch (...) {
-            return handleAllExceptions(npos, npos);
-        }
-    }
-
     double kin_reactantStoichCoeff(int n, int k, int i)
     {
         try {
@@ -1660,6 +1650,20 @@ extern "C" {
         }
     }
 
+    int ct_suppress_deprecation_warnings(int suppress)
+    {
+        try {
+            if (suppress != 0) {
+                suppress_deprecation_warnings();
+            } else {
+                make_deprecation_warnings_fatal();
+            }
+            return 0;
+        } catch (...) {
+            return handleAllExceptions(-1, ERR);
+        }
+    }
+
     int ct_use_legacy_rate_constants(int legacy)
     {
         try {
@@ -1683,10 +1687,9 @@ extern "C" {
 
     int ct_setLogCallback(LogCallback writer)
     {
-        static unique_ptr<Logger> logwriter;
         try {
-            logwriter = make_unique<ExternalLogger>(writer);
-            setLogger(logwriter.get());
+            auto logwriter = make_unique<ExternalLogger>(writer);
+            setLogger(std::move(logwriter));
             return 0;
         } catch (...) {
             return handleAllExceptions(-1, ERR);
