@@ -10,10 +10,9 @@
 #include "cantera/equil/ChemEquil.h"
 #include "cantera/base/stringUtils.h"
 #include "cantera/equil/MultiPhaseEquil.h"
-
-using namespace std;
-
-#include <cstdio>
+#include "cantera/thermo/ThermoPhase.h"
+#include "cantera/base/utilities.h"
+#include "cantera/base/global.h"
 
 namespace Cantera
 {
@@ -41,27 +40,12 @@ int _equilflag(const char* xy)
     return -1;
 }
 
-ChemEquil::ChemEquil() : m_skip(npos), m_elementTotalSum(1.0),
-    m_p0(OneAtm), m_eloc(npos),
-    m_elemFracCutoff(1.0E-100),
-    m_doResPerturb(false)
-{}
-
-ChemEquil::ChemEquil(thermo_t& s) :
-    m_skip(npos),
-    m_elementTotalSum(1.0),
-    m_p0(OneAtm), m_eloc(npos),
-    m_elemFracCutoff(1.0E-100),
-    m_doResPerturb(false)
+ChemEquil::ChemEquil(ThermoPhase& s)
 {
     initialize(s);
 }
 
-ChemEquil::~ChemEquil()
-{
-}
-
-void ChemEquil::initialize(thermo_t& s)
+void ChemEquil::initialize(ThermoPhase& s)
 {
     // store a pointer to s and some of its properties locally.
     m_phase = &s;
@@ -129,8 +113,8 @@ void ChemEquil::initialize(thermo_t& s)
     }
 }
 
-void ChemEquil::setToEquilState(thermo_t& s,
-                                const vector_fp& lambda_RT, doublereal t)
+void ChemEquil::setToEquilState(ThermoPhase& s,
+                                const vector<double>& lambda_RT, double t)
 {
     // Construct the chemical potentials by summing element potentials
     fill(m_mu_RT.begin(), m_mu_RT.end(), 0.0);
@@ -150,7 +134,7 @@ void ChemEquil::setToEquilState(thermo_t& s,
     update(s);
 }
 
-void ChemEquil::update(const thermo_t& s)
+void ChemEquil::update(const ThermoPhase& s)
 {
     // get the mole fractions, temperature, and density
     s.getMoleFractions(m_molefractions.data());
@@ -179,8 +163,7 @@ void ChemEquil::update(const thermo_t& s)
     }
 }
 
-int ChemEquil::setInitialMoles(thermo_t& s, vector_fp& elMoleGoal,
-                               int loglevel)
+int ChemEquil::setInitialMoles(ThermoPhase& s, vector<double>& elMoleGoal, int loglevel)
 {
     MultiPhase mp;
     mp.addPhase(&s, 1.0);
@@ -215,12 +198,12 @@ int ChemEquil::setInitialMoles(thermo_t& s, vector_fp& elMoleGoal,
     return 0;
 }
 
-int ChemEquil::estimateElementPotentials(thermo_t& s, vector_fp& lambda_RT,
-        vector_fp& elMolesGoal, int loglevel)
+int ChemEquil::estimateElementPotentials(ThermoPhase& s, vector<double>& lambda_RT,
+        vector<double>& elMolesGoal, int loglevel)
 {
-    vector_fp b(m_mm, -999.0);
-    vector_fp mu_RT(m_kk, 0.0);
-    vector_fp xMF_est(m_kk, 0.0);
+    vector<double> b(m_mm, -999.0);
+    vector<double> mu_RT(m_kk, 0.0);
+    vector<double> xMF_est(m_kk, 0.0);
 
     s.getMoleFractions(xMF_est.data());
     for (size_t n = 0; n < s.nSpecies(); n++) {
@@ -233,7 +216,7 @@ int ChemEquil::estimateElementPotentials(thermo_t& s, vector_fp& lambda_RT,
     mp.addPhase(&s, 1.0);
     mp.init();
     int usedZeroedSpecies = 0;
-    vector_fp formRxnMatrix;
+    vector<double> formRxnMatrix;
     m_nComponents = BasisOptimize(&usedZeroedSpecies, false,
                                   &mp, m_orderVectorSpecies,
                                   m_orderVectorElements, formRxnMatrix);
@@ -274,8 +257,10 @@ int ChemEquil::estimateElementPotentials(thermo_t& s, vector_fp& lambda_RT,
         b[m] = mu_RT[m_component[m]];
     }
 
-    int info = solve(aa, b.data());
-    if (info) {
+    int info;
+    try {
+        info = solve(aa, b.data());
+    } catch (CanteraError&) {
         info = -2;
     }
     for (size_t m = 0; m < m_nComponents; m++) {
@@ -305,21 +290,21 @@ int ChemEquil::estimateElementPotentials(thermo_t& s, vector_fp& lambda_RT,
     return info;
 }
 
-int ChemEquil::equilibrate(thermo_t& s, const char* XY, int loglevel)
+int ChemEquil::equilibrate(ThermoPhase& s, const char* XY, int loglevel)
 {
     initialize(s);
     update(s);
-    vector_fp elMolesGoal = m_elementmolefracs;
+    vector<double> elMolesGoal = m_elementmolefracs;
     return equilibrate(s, XY, elMolesGoal, loglevel-1);
 }
 
-int ChemEquil::equilibrate(thermo_t& s, const char* XYstr,
-                           vector_fp& elMolesGoal, int loglevel)
+int ChemEquil::equilibrate(ThermoPhase& s, const char* XYstr,
+                           vector<double>& elMolesGoal, int loglevel)
 {
     int fail = 0;
     bool tempFixed = true;
     int XY = _equilflag(XYstr);
-    vector_fp state;
+    vector<double> state;
     s.saveState(state);
     m_loglevel = loglevel;
 
@@ -389,8 +374,8 @@ int ChemEquil::equilibrate(thermo_t& s, const char* XYstr,
     size_t mm = m_mm;
     size_t nvar = mm + 1;
     DenseMatrix jac(nvar, nvar); // Jacobian
-    vector_fp x(nvar, -102.0); // solution vector
-    vector_fp res_trial(nvar, 0.0); // residual
+    vector<double> x(nvar, -102.0); // solution vector
+    vector<double> res_trial(nvar, 0.0); // residual
 
     // Replace one of the element abundance fraction equations with the
     // specified property calculation.
@@ -412,7 +397,7 @@ int ChemEquil::equilibrate(thermo_t& s, const char* XYstr,
     // start with a composition with everything non-zero. Note that since we
     // have already save the target element moles, changing the composition at
     // this point only affects the starting point, not the final solution.
-    vector_fp xmm(m_kk, 0.0);
+    vector<double> xmm(m_kk, 0.0);
     for (size_t k = 0; k < m_kk; k++) {
         xmm[k] = s.moleFraction(k) + 1.0E-32;
     }
@@ -422,20 +407,20 @@ int ChemEquil::equilibrate(thermo_t& s, const char* XYstr,
     // mole fractions.
     update(s);
 
-    doublereal tmaxPhase = s.maxTemp();
-    doublereal tminPhase = s.minTemp();
+    double tmaxPhase = s.maxTemp();
+    double tminPhase = s.minTemp();
     // loop to estimate T
     if (!tempFixed) {
-        doublereal tmin = std::max(s.temperature(), tminPhase);
+        double tmin = std::max(s.temperature(), tminPhase);
         if (tmin > tmaxPhase) {
             tmin = tmaxPhase - 20;
         }
-        doublereal tmax = std::min(tmin + 10., tmaxPhase);
+        double tmax = std::min(tmin + 10., tmaxPhase);
         if (tmax < tminPhase) {
             tmax = tminPhase + 20;
         }
 
-        doublereal slope, phigh, plow, pval, dt;
+        double slope, phigh, plow, pval, dt;
 
         // first get the property values at the upper and lower temperature
         // limits. Since p1 (h, s, or u) is monotonic in T, these values
@@ -450,7 +435,7 @@ int ChemEquil::equilibrate(thermo_t& s, const char* XYstr,
         plow = m_p1(s);
 
         // start with T at the midpoint of the range
-        doublereal t0 = 0.5*(tmin + tmax);
+        double t0 = 0.5*(tmin + tmax);
         s.setTemperature(t0);
 
         // loop up to 5 times
@@ -522,8 +507,8 @@ int ChemEquil::equilibrate(thermo_t& s, const char* XYstr,
     // Setting the max and min values for x[]. Also, if element abundance vector
     // is zero, setting x[] to -1000. This effectively zeroes out all species
     // containing that element.
-    vector_fp above(nvar);
-    vector_fp below(nvar);
+    vector<double> above(nvar);
+    vector<double> below(nvar);
     for (size_t m = 0; m < mm; m++) {
         above[m] = 200.0;
         below[m] = -2000.0;
@@ -537,9 +522,9 @@ int ChemEquil::equilibrate(thermo_t& s, const char* XYstr,
     above[mm] = log(s.maxTemp() + 25.0);
     below[mm] = log(s.minTemp() - 25.0);
 
-    vector_fp grad(nvar, 0.0); // gradient of f = F*F/2
-    vector_fp oldx(nvar, 0.0); // old solution
-    vector_fp oldresid(nvar, 0.0);
+    vector<double> grad(nvar, 0.0); // gradient of f = F*F/2
+    vector<double> oldx(nvar, 0.0); // old solution
+    vector<double> oldresid(nvar, 0.0);
 
     for (int iter = 0; iter < options.maxIterations; iter++) {
         // check for convergence.
@@ -686,9 +671,9 @@ int ChemEquil::equilibrate(thermo_t& s, const char* XYstr,
 }
 
 
-int ChemEquil::dampStep(thermo_t& mix, vector_fp& oldx,
-                        double oldf, vector_fp& grad, vector_fp& step, vector_fp& x,
-                        double& f, vector_fp& elmols, double xval, double yval)
+int ChemEquil::dampStep(ThermoPhase& mix, vector<double>& oldx, double oldf,
+                        vector<double>& grad, vector<double>& step, vector<double>& x,
+                        double& f, vector<double>& elmols, double xval, double yval)
 {
     // Carry out a delta damping approach on the dimensionless element
     // potentials.
@@ -725,14 +710,14 @@ int ChemEquil::dampStep(thermo_t& mix, vector_fp& oldx,
     return 1;
 }
 
-void ChemEquil::equilResidual(thermo_t& s, const vector_fp& x,
-                              const vector_fp& elmFracGoal, vector_fp& resid,
-                              doublereal xval, doublereal yval, int loglevel)
+void ChemEquil::equilResidual(ThermoPhase& s, const vector<double>& x,
+                              const vector<double>& elmFracGoal, vector<double>& resid,
+                              double xval, double yval, int loglevel)
 {
     setToEquilState(s, x, exp(x[m_mm]));
 
     // residuals are the total element moles
-    vector_fp& elmFrac = m_elementmolefracs;
+    vector<double>& elmFrac = m_elementmolefracs;
     for (size_t n = 0; n < m_mm; n++) {
         size_t m = m_orderVectorElements[n];
         // drive element potential for absent elements to -1000
@@ -771,16 +756,16 @@ void ChemEquil::equilResidual(thermo_t& s, const vector_fp& x,
     }
 }
 
-void ChemEquil::equilJacobian(thermo_t& s, vector_fp& x,
-                              const vector_fp& elmols, DenseMatrix& jac,
-                              doublereal xval, doublereal yval, int loglevel)
+void ChemEquil::equilJacobian(ThermoPhase& s, vector<double>& x,
+                              const vector<double>& elmols, DenseMatrix& jac,
+                              double xval, double yval, int loglevel)
 {
-    vector_fp& r0 = m_jwork1;
-    vector_fp& r1 = m_jwork2;
+    vector<double>& r0 = m_jwork1;
+    vector<double>& r1 = m_jwork2;
     size_t len = x.size();
     r0.resize(len);
     r1.resize(len);
-    doublereal atol = 1.e-10;
+    double atol = 1.e-10;
 
     equilResidual(s, x, elmols, r0, xval, yval, loglevel-1);
 
@@ -804,16 +789,16 @@ void ChemEquil::equilJacobian(thermo_t& s, vector_fp& x,
     m_doResPerturb = false;
 }
 
-double ChemEquil::calcEmoles(thermo_t& s, vector_fp& x, const double& n_t,
-                             const vector_fp& Xmol_i_calc,
-                             vector_fp& eMolesCalc, vector_fp& n_i_calc,
+double ChemEquil::calcEmoles(ThermoPhase& s, vector<double>& x, const double& n_t,
+                             const vector<double>& Xmol_i_calc,
+                             vector<double>& eMolesCalc, vector<double>& n_i_calc,
                              double pressureConst)
 {
     double n_t_calc = 0.0;
 
     // Calculate the activity coefficients of the solution, at the previous
     // solution state.
-    vector_fp actCoeff(m_kk, 1.0);
+    vector<double> actCoeff(m_kk, 1.0);
     s.setMoleFractions(Xmol_i_calc.data());
     s.setPressure(pressureConst);
     s.getActivityCoefficients(actCoeff.data());
@@ -840,37 +825,37 @@ double ChemEquil::calcEmoles(thermo_t& s, vector_fp& x, const double& n_t,
     return n_t_calc;
 }
 
-int ChemEquil::estimateEP_Brinkley(thermo_t& s, vector_fp& x,
-                                   vector_fp& elMoles)
+int ChemEquil::estimateEP_Brinkley(ThermoPhase& s, vector<double>& x,
+                                   vector<double>& elMoles)
 {
     // Before we do anything, we will save the state of the solution. Then, if
     // things go drastically wrong, we will restore the saved state.
-    vector_fp state;
+    vector<double> state;
     s.saveState(state);
     bool modifiedMatrix = false;
     size_t neq = m_mm+1;
     int retn = 1;
     DenseMatrix a1(neq, neq, 0.0);
-    vector_fp b(neq, 0.0);
-    vector_fp n_i(m_kk,0.0);
-    vector_fp n_i_calc(m_kk,0.0);
-    vector_fp actCoeff(m_kk, 1.0);
+    vector<double> b(neq, 0.0);
+    vector<double> n_i(m_kk,0.0);
+    vector<double> n_i_calc(m_kk,0.0);
+    vector<double> actCoeff(m_kk, 1.0);
     double beta = 1.0;
 
     s.getMoleFractions(n_i.data());
     double pressureConst = s.pressure();
-    vector_fp Xmol_i_calc = n_i;
+    vector<double> Xmol_i_calc = n_i;
 
-    vector_fp x_old(m_mm+1, 0.0);
-    vector_fp resid(m_mm+1, 0.0);
-    vector_int lumpSum(m_mm+1, 0);
+    vector<double> x_old(m_mm+1, 0.0);
+    vector<double> resid(m_mm+1, 0.0);
+    vector<int> lumpSum(m_mm+1, 0);
 
     // Get the nondimensional Gibbs functions for the species at their standard
     // states of solution at the current T and P of the solution.
     s.getGibbs_RT(m_muSS_RT.data());
 
-    vector_fp eMolesCalc(m_mm, 0.0);
-    vector_fp eMolesFix(m_mm, 0.0);
+    vector<double> eMolesCalc(m_mm, 0.0);
+    vector<double> eMolesFix(m_mm, 0.0);
     double elMolesTotal = 0.0;
     for (size_t m = 0; m < m_mm; m++) {
         elMolesTotal += elMoles[m];
@@ -1023,7 +1008,7 @@ int ChemEquil::estimateEP_Brinkley(thermo_t& s, vector_fp& x,
             //
             // The way around rank-deficiency is to lump-sum the corresponding
             // row of the matrix. Note, lump-summing seems to work very well in
-            // terms of its stability properties, i.e., it heads in the right
+            // terms of its stability properties, that is, it heads in the right
             // direction, albeit with lousy convergence rates.
             //
             // NOTE: This probably should be extended to a full blown Gauss-
@@ -1041,10 +1026,8 @@ int ChemEquil::estimateEP_Brinkley(thermo_t& s, vector_fp& x,
             for (size_t m = 0; m < m_mm; m++) {
                 size_t kMSp = npos;
                 size_t kMSp2 = npos;
-                int nSpeciesWithElem = 0;
                 for (size_t k = 0; k < m_kk; k++) {
                     if (n_i_calc[k] > nCutoff && fabs(nAtoms(k,m)) > 0.001) {
-                        nSpeciesWithElem++;
                         if (kMSp != npos) {
                             kMSp2 = k;
                             double factor = fabs(nAtoms(kMSp,m) / nAtoms(kMSp2,m));
@@ -1311,7 +1294,7 @@ int ChemEquil::estimateEP_Brinkley(thermo_t& s, vector_fp& x,
 }
 
 
-void ChemEquil::adjustEloc(thermo_t& s, vector_fp& elMolesGoal)
+void ChemEquil::adjustEloc(ThermoPhase& s, vector<double>& elMolesGoal)
 {
     if (m_eloc == npos) {
         return;
