@@ -754,9 +754,13 @@ size_t vcs_VolPhase::nElemConstraints() const
     return m_numElemConstraints;
 }
 
-string vcs_VolPhase::elementName(const size_t e) const
+string vcs_VolPhase::elementName(size_t e) const
 {
-    return m_elementNames[e];
+
+    if (e < m_elementNames.size()) {
+        return m_elementNames[e];
+    }
+    throw IndexError("vcs_VolPhase::elementName", "element", e, m_elementNames.size());
 }
 
 //! This function decides whether a phase has charged species or not.
