@@ -36,8 +36,7 @@ void Group::validate()
     }
 }
 
-std::ostream& Group::fmt(std::ostream& s,
-                         const std::vector<std::string>& esymbols) const
+std::ostream& Group::fmt(std::ostream& s, const vector<string>& esymbols) const
 {
     s << "(";
     bool first = true;
