@@ -6,6 +6,7 @@
 // This file is part of Cantera. See License.txt in the top-level directory or
 // at https://cantera.org/license.txt for license and copyright information.
 
+#include "cantera/base/ctexceptions.h"
 #include "cantera/kinetics/ReactionPath.h"
 #include "cantera/kinetics/Reaction.h"
 #include "cantera/thermo/ThermoPhase.h"
@@ -78,6 +79,17 @@ void Path::writeLabel(ostream& s, double threshold)
     }
 }
 
+ReactionPathDiagram::ReactionPathDiagram(
+    shared_ptr<Kinetics> kin, const string& element_) : element(element_), m_kin(kin)
+{
+    if (!m_kin) {
+        throw CanteraError("ReactionPathDiagram::ReactionPathDiagram",
+                           "Kinetics object must not be empty.");
+    }
+    m_builder = make_shared<ReactionPathBuilder>();
+    m_builder->init(m_log, *m_kin.get());
+}
+
 ReactionPathDiagram::~ReactionPathDiagram()
 {
     // delete the nodes
@@ -125,6 +137,11 @@ void ReactionPathDiagram::add(ReactionPathDiagram& d)
     }
 }
 
+void ReactionPathDiagram::add(shared_ptr<ReactionPathDiagram> d)
+{
+    add(*d.get());
+}
+
 void ReactionPathDiagram::findMajorPaths(double athreshold, size_t lda, double* a)
 {
     double netmax = 0.0;
@@ -148,6 +165,57 @@ void ReactionPathDiagram::findMajorPaths(double athreshold, size_t lda, double*
     }
 }
 
+const string ReactionPathDiagram::flowType() const
+{
+    if (flow_type == OneWayFlow) {
+        return "OneWayFlow";
+    }
+    return "NetFlow";
+}
+
+void ReactionPathDiagram::setFlowType(const string& fType)
+{
+    if (fType == "OneWayFlow") {
+        flow_type = OneWayFlow;
+    } else if (fType == "NetFlow") {
+        flow_type = NetFlow;
+    } else {
+        throw CanteraError("ReactionPathDiagram::setFlowType",
+                           "Unknown flow type '{}'", fType);
+    }
+}
+
+void ReactionPathDiagram::build()
+{
+    m_builder->build(*m_kin.get(), element, m_log, *this, true);
+    m_isBuilt = true;
+}
+
+string ReactionPathDiagram::getDot()
+{
+    if (!m_isBuilt) {
+        build();
+    }
+    std::stringstream out;
+    exportToDot(out);
+    return out.str();
+}
+
+string ReactionPathDiagram::getData()
+{
+    if (!m_isBuilt) {
+        build();
+    }
+    std::stringstream out;
+    writeData(out);
+    return out.str();
+}
+
+string ReactionPathDiagram::getLog()
+{
+    return m_log.str();
+}
+
 void ReactionPathDiagram::writeData(ostream& s)
 {
     s << title << endl;
@@ -519,12 +587,12 @@ void ReactionPathBuilder::findElements(Kinetics& kin)
         // iterate over the phases
         for (size_t ip = 0; ip < kin.nPhases(); ip++) {
             ThermoPhase* p = &kin.thermo(ip);
-            size_t mlocal = p->elementIndex(m_elementSymbols[m]);
-            for (size_t kp = 0; kp < p->nSpecies(); kp++) {
-                if (mlocal != npos) {
+            size_t mlocal = p->elementIndex(m_elementSymbols[m], false);
+            if (mlocal != npos) {
+                for (size_t kp = 0; kp < p->nSpecies(); kp++) {
                     m_atoms(k, m) = p->nAtoms(kp, mlocal);
+                    k++;
                 }
-                k++;
             }
         }
     }
@@ -791,4 +859,11 @@ int ReactionPathBuilder::build(Kinetics& s, const string& element,
     return 1;
 }
 
+shared_ptr<ReactionPathDiagram> newReactionPathDiagram(
+    shared_ptr<Kinetics> kin, const string& element)
+{
+    return shared_ptr<ReactionPathDiagram>(
+        new ReactionPathDiagram(kin, element));
+}
+
 }
