@@ -233,7 +233,7 @@ int BandMatrix::factor()
     long int nu = static_cast<long int>(nSuperDiagonals());
     long int nl = static_cast<long int>(nSubDiagonals());
     long int smu = nu + nl;
-    #if CT_SUNDIALS_VERSION >= 60
+    #if SUNDIALS_VERSION_MAJOR >= 6
         m_info = SUNDlsMat_bandGBTRF(m_lu_col_ptrs.data(),
                                      static_cast<long int>(nColumns()),
                                      nu, nl, smu, m_ipiv->data.data());
@@ -273,7 +273,7 @@ int BandMatrix::solve(double* b, size_t nrhs, size_t ldb)
     long int nl = static_cast<long int>(nSubDiagonals());
     long int smu = nu + nl;
     double** a = m_lu_col_ptrs.data();
-    #if CT_SUNDIALS_VERSION >= 60
+    #if SUNDIALS_VERSION_MAJOR >= 6
         SUNDlsMat_bandGBTRS(a, static_cast<long int>(nColumns()), smu, nl,
                             m_ipiv->data.data(), b);
     #else
@@ -290,32 +290,6 @@ int BandMatrix::solve(double* b, size_t nrhs, size_t ldb)
     return m_info;
 }
 
-vector<double>::iterator BandMatrix::begin()
-{
-    warn_deprecated("BandMatrix::begin", "To be removed after Cantera 3.0.");
-    m_factored = false;
-    return data.begin();
-}
-
-vector<double>::iterator BandMatrix::end()
-{
-    warn_deprecated("BandMatrix::end", "To be removed after Cantera 3.0.");
-    m_factored = false;
-    return data.end();
-}
-
-vector<double>::const_iterator BandMatrix::begin() const
-{
-    warn_deprecated("BandMatrix::begin", "To be removed after Cantera 3.0.");
-    return data.begin();
-}
-
-vector<double>::const_iterator BandMatrix::end() const
-{
-    warn_deprecated("BandMatrix::end", "To be removed after Cantera 3.0.");
-    return data.end();
-}
-
 ostream& operator<<(ostream& s, const BandMatrix& m)
 {
     for (size_t i = 0; i < m.nRows(); i++) {
