@@ -3,18 +3,19 @@
 
 // commonly-included system headers
 #include <cmath>
-#include <cstdio>
 #include <fstream>
 #include <iostream>
 #include <sstream>
 #include <cstdlib>
 #include <vector>
 #include <map>
+#include <set>
 #include <string>
 #include <algorithm>
 #include <memory>
+#include <functional>
+#include <any>
 
 #include <boost/algorithm/string.hpp>
-#include "cantera/base/fmt.h"
 
 #endif
