@@ -119,6 +119,8 @@ void SingleSpeciesTP::getPartialMolarVolumes(double* vbar) const
 
 void SingleSpeciesTP::getPureGibbs(double* gpure) const
 {
+    warn_deprecated("SingleSpeciesTP::getPureGibbs",
+        "To be removed after Cantera 3.2. Use getStandardChemPotentials instead.");
     getGibbs_RT(gpure);
     gpure[0] *= RT();
 }
@@ -160,76 +162,6 @@ void SingleSpeciesTP::getCp_R_ref(double* cpr) const
     cpr[0] = m_cp0_R;
 }
 
-// ------------------ Setting the State ------------------------
-
-void SingleSpeciesTP::setState_HP(double h, double p, double tol)
-{
-    double dt;
-    setPressure(p);
-    for (int n = 0; n < 50; n++) {
-        dt = clip((h - enthalpy_mass())/cp_mass(), -100.0, 100.0);
-        setState_TP(temperature() + dt, p);
-        if (fabs(dt / temperature()) < tol) {
-            return;
-        }
-    }
-    throw CanteraError("SingleSpeciesTP::setState_HP",
-                       "no convergence. dt = {}", dt);
-}
-
-void SingleSpeciesTP::setState_UV(double u, double v, double tol)
-{
-    double dt;
-    if (v == 0.0) {
-        setDensity(1.0E100);
-    } else {
-        setDensity(1.0/v);
-    }
-    for (int n = 0; n < 50; n++) {
-        dt = clip((u - intEnergy_mass())/cv_mass(), -100.0, 100.0);
-        setTemperature(temperature() + dt);
-        if (fabs(dt / temperature()) < tol) {
-            return;
-        }
-    }
-    throw CanteraError("SingleSpeciesTP::setState_UV",
-                       "no convergence. dt = {}\nu = {} v = {}", dt, u, v);
-}
-
-void SingleSpeciesTP::setState_SP(double s, double p, double tol)
-{
-    double dt;
-    setPressure(p);
-    for (int n = 0; n < 50; n++) {
-        dt = clip((s - entropy_mass())*temperature()/cp_mass(), -100.0, 100.0);
-        setState_TP(temperature() + dt, p);
-        if (fabs(dt / temperature()) < tol) {
-            return;
-        }
-    }
-    throw CanteraError("SingleSpeciesTP::setState_SP",
-                       "no convergence. dt = {}", dt);
-}
-
-void SingleSpeciesTP::setState_SV(double s, double v, double tol)
-{
-    double dt;
-    if (v == 0.0) {
-        setDensity(1.0E100);
-    } else {
-        setDensity(1.0/v);
-    }
-    for (int n = 0; n < 50; n++) {
-        dt = clip((s - entropy_mass())*temperature()/cv_mass(), -100.0, 100.0);
-        setTemperature(temperature() + dt);
-        if (fabs(dt / temperature()) < tol) {
-            return;
-        }
-    }
-    throw CanteraError("SingleSpeciesTP::setState_SV",
-                       "no convergence. dt = {}", dt);
-}
-
 bool SingleSpeciesTP::addSpecies(shared_ptr<Species> spec)
 {
     if (m_kk != 0) {
