@@ -154,7 +154,7 @@ void StoichSubstance::getSpeciesParameters(const string& name,
                                            AnyMap& speciesNode) const
 {
     SingleSpeciesTP::getSpeciesParameters(name, speciesNode);
-    size_t k = speciesIndex(name);
+    size_t k = speciesIndex(name, true);
     const auto S = species(k);
     auto& eosNode = speciesNode["equation-of-state"].getMapWhere(
         "model", "constant-volume", true);
