@@ -113,6 +113,8 @@ double WaterPropsIAPWS::density(double temperature, double pressure,
 
 double WaterPropsIAPWS::density_const(double pressure, int phase, double rhoguess) const
 {
+    warn_deprecated("WaterPropsIAPWS::density_const",
+        "To be removed after Cantera 3.1.");
     double temperature = T_c / tau;
     double deltaGuess = 0.0;
     double deltaSave = delta;
@@ -263,36 +265,9 @@ void WaterPropsIAPWS::corr(double temperature, double pressure,
     delGRT = gibbsLiqRT - gibbsGasRT;
 }
 
-void WaterPropsIAPWS::corr1(double temperature, double pressure,
-    double& densLiq, double& densGas, double& pcorr)
-{
-    densLiq = density(temperature, pressure, WATER_LIQUID, densLiq);
-    if (densLiq <= 0.0) {
-        throw CanteraError("WaterPropsIAPWS::corr1",
-            "Error occurred trying to find liquid density at (T,P) = {}  {}",
-            temperature, pressure);
-    }
-    setState_TD(temperature, densLiq);
-    double prL = m_phi.phiR();
-
-    densGas = density(temperature, pressure, WATER_GAS, densGas);
-    if (densGas <= 0.0) {
-        throw CanteraError("WaterPropsIAPWS::corr1",
-            "Error occurred trying to find gas density at (T,P) = {}  {}",
-            temperature, pressure);
-    }
-    setState_TD(temperature, densGas);
-    double prG = m_phi.phiR();
-    double rhs = (prL - prG) + log(densLiq/densGas);
-    rhs /= (1.0/densGas - 1.0/densLiq);
-    pcorr = rhs * R_water * temperature;
-}
-
 double WaterPropsIAPWS::psat(double temperature, int waterState)
 {
-    static int method = 1;
     double densLiq = -1.0, densGas = -1.0, delGRT = 0.0;
-    double dp, pcorr;
     if (temperature >= T_c) {
         densGas = density(temperature, P_c, WATER_SUPERCRIT);
         setState_TD(temperature, densGas);
@@ -300,22 +275,11 @@ double WaterPropsIAPWS::psat(double temperature, int waterState)
     }
     double p = psat_est(temperature);
     for (int i = 0; i < 30; i++) {
-        if (method == 1) {
-            corr(temperature, p, densLiq, densGas, delGRT);
-            double delV = 1.0/densLiq - 1.0/densGas;
-            dp = - delGRT * R_water * temperature / delV;
-        } else {
-            corr1(temperature, p, densLiq, densGas, pcorr);
-            dp = pcorr - p;
-        }
-        p += dp;
-
-        if ((method == 1) && delGRT < 1.0E-8) {
+        corr(temperature, p, densLiq, densGas, delGRT);
+        double delV = 1.0/densLiq - 1.0/densGas;
+        p -= delGRT * R_water * temperature / delV;
+        if (delGRT < 1.0E-8) {
             break;
-        } else {
-            if (fabs(dp/p) < 1.0E-9) {
-                break;
-            }
         }
     }
     // Put the fluid in the desired end condition
@@ -372,6 +336,8 @@ int WaterPropsIAPWS::phaseState(bool checkState) const
 
 double WaterPropsIAPWS::densSpinodalWater() const
 {
+    warn_deprecated("WaterPropsIAPWS::densSpinodalWater",
+        "To be removed after Cantera 3.1.");
     double temperature = T_c/tau;
     double delta_save = delta;
     // return the critical density if we are above or even just a little below
@@ -460,6 +426,8 @@ double WaterPropsIAPWS::densSpinodalWater() const
 
 double WaterPropsIAPWS::densSpinodalSteam() const
 {
+    warn_deprecated("WaterPropsIAPWS::densSpinodalSteam",
+        "To be removed after Cantera 3.1.");
     double temperature = T_c/tau;
     double delta_save = delta;
     // return the critical density if we are above or even just a little below
