@@ -1,5 +1,5 @@
-//! @file Sub.cpp
-/*
+/**
+ * @file Sub.cpp
  * The Substance class
  * D. Goodwin, Caltech Nov. 1996
  */
@@ -11,28 +11,15 @@
 #include "cantera/base/stringUtils.h"
 #include "cantera/base/global.h"
 
-using std::string;
 using namespace Cantera;
 
 namespace {
 // these correspond to ordering withing propertyFlag::type
-std::string propertySymbols[] = {"H", "S", "U", "V", "P", "T"};
+string propertySymbols[] = {"H", "S", "U", "V", "P", "T"};
 }
 
 namespace tpx
 {
-Substance::Substance() :
-    T(Undef),
-    Rho(Undef),
-    Tslast(Undef),
-    Rhf(Undef),
-    Rhv(Undef),
-    Pst(Undef),
-    m_energy_offset(0.0),
-    m_entropy_offset(0.0),
-    kbr(0)
-{
-}
 
 void Substance::setStdState(double h0, double s0, double t0, double p0)
 {
@@ -294,7 +281,7 @@ double Substance::Tsat(double p)
 {
     double Tsave = T;
     if (p <= 0. || p > Pcrit()) {
-        // @TODO: this check should also fail below the triple point pressure
+        // @todo: this check should also fail below the triple point pressure
         // (calculated as Ps() for Tmin() as it is not available as a numerical
         // parameter). A bug causing low-temperature TP setters to fail for
         // Heptane (GitHub issue #605) prevents this at the moment.
@@ -721,7 +708,7 @@ void Substance::set_xy(propertyFlag::type ifx, propertyFlag::type ify,
         Set(PropertyPair::TV, t_here, v_here);
         LoopCount++;
         if (LoopCount > 200) {
-            std::string msg = fmt::format("No convergence. {} = {}, {} = {}",
+            string msg = fmt::format("No convergence. {} = {}, {} = {}",
                 propertySymbols[ifx], X, propertySymbols[ify], Y);
             if (t_here == Tmin()) {
                 msg += fmt::format("\nAt temperature limit (Tmin = {})", Tmin());
