@@ -13,19 +13,10 @@
 
 namespace Cantera
 {
-DustyGasTransport::DustyGasTransport(ThermoPhase* thermo) :
-    Transport(thermo)
-{
-}
-
-void DustyGasTransport::setThermo(ThermoPhase& thermo)
-{
-    Transport::setThermo(thermo);
-    m_gastran->setThermo(thermo);
-}
 
 void DustyGasTransport::initialize(ThermoPhase* phase, Transport* gastr)
 {
+    Transport::init(phase);
     // constant mixture attributes
     m_thermo = phase;
     m_nsp = m_thermo->nSpecies();
@@ -171,11 +162,7 @@ void DustyGasTransport::updateMultiDiffCoeffs()
     eval_H_matrix();
 
     // invert H
-    int ierr = invert(m_multidiff);
-    if (ierr != 0) {
-        throw CanteraError("DustyGasTransport::updateMultiDiffCoeffs",
-                           "invert returned ierr = {}", ierr);
-    }
+    invert(m_multidiff);
 }
 
 void DustyGasTransport::getMultiDiffCoeffs(const size_t ld, double* const d)
