@@ -19,7 +19,7 @@ double MMCollisionInt::delta[8] = {0.0, 0.25, 0.50, 0.75, 1.0,
                                    1.5, 2.0, 2.5
                                   };
 
-double quadInterp(double x0, double* x, double* y)
+double MMCollisionInt::quadInterp(double x0, double* x, double* y)
 {
     double dx21 = x[1] - x[0];
     double dx32 = x[2] - x[1];
@@ -213,24 +213,16 @@ double MMCollisionInt::cstar_table[39*8] = {
     0.94444, 0.94444,0.94444,0.94444,0.94444,0.94444,0.94444,0.94444
 };
 
-void MMCollisionInt::init(double tsmin, double tsmax, int log_level)
+void MMCollisionInt::init(double tstar_min, double tstar_max)
 {
-    if (log_level == -7) {
-        log_level = 0;
-    } else {
-        warn_deprecated("MMCollisionInt::init", "The log_level parameter "
-            "is deprecated and will be removed after Cantera 3.1.");
-    }
-    m_loglevel = log_level;
-    debuglog("Collision Integral Polynomial Fits\n", m_loglevel > 0);
     m_nmin = -1;
     m_nmax = -1;
 
     for (int n = 0; n < 37; n++) {
-        if (tsmin > tstar[n+1]) {
+        if (tstar_min > tstar[n+1]) {
             m_nmin = n;
         }
-        if (tsmax > tstar[n+1]) {
+        if (tstar_max > tstar[n+1]) {
             m_nmax = n+1;
         }
     }
@@ -238,63 +230,23 @@ void MMCollisionInt::init(double tsmin, double tsmax, int log_level)
         m_nmin = 0;
         m_nmax = 36;
     }
-    if (m_loglevel > 0) {
-        writelogf("T*_min = %g\n", tstar[m_nmin + 1]);
-        writelogf("T*_max = %g\n", tstar[m_nmax + 1]);
-    }
     m_logTemp.resize(37);
-    double e22 = 0.0, ea = 0.0, eb = 0.0, ec = 0.0;
-
-    if (m_loglevel > 0) {
-        writelog("Collision integral fits at each tabulated T* vs. delta*.\n"
-                 "These polynomial fits are used to interpolate between "
-                 "columns (delta*)\n in the Monchick and Mason tables."
-                 " They are only used for nonzero delta*.\n");
-        if (log_level < 4) {
-            writelog("polynomial coefficients not printed (log_level < 4)\n");
-        }
-    }
 
     for (int i = 0; i < 37; i++) {
         m_logTemp[i] = log(tstar[i+1]);
         vector<double> c(DeltaDegree+1);
 
-        double rmserr = fitDelta(0, i, DeltaDegree, c.data());
-        if (log_level > 3) {
-            writelogf("\ndelta* fit at T* = %.6g\n", tstar[i+1]);
-            writelog("omega22 = [" + vec2str(c) + "]\n");
-        }
+        fitDelta(0, i, DeltaDegree, c.data());
         m_o22poly.push_back(c);
-        e22 = std::max(e22, rmserr);
 
-        rmserr = fitDelta(1, i, DeltaDegree, c.data());
+        fitDelta(1, i, DeltaDegree, c.data());
         m_apoly.push_back(c);
-        if (log_level > 3) {
-            writelog("A* = [" + vec2str(c) + "]\n");
-        }
-        ea = std::max(ea, rmserr);
 
-        rmserr = fitDelta(2, i, DeltaDegree, c.data());
+        fitDelta(2, i, DeltaDegree, c.data());
         m_bpoly.push_back(c);
-        if (log_level > 3) {
-            writelog("B* = [" + vec2str(c) + "]\n");
-        }
-        eb = std::max(eb, rmserr);
 
-        rmserr = fitDelta(3, i, DeltaDegree, c.data());
+        fitDelta(3, i, DeltaDegree, c.data());
         m_cpoly.push_back(c);
-        if (log_level > 3) {
-            writelog("C* = [" + vec2str(c) + "]\n");
-        }
-        ec = std::max(ec, rmserr);
-
-        if (log_level > 0) {
-            writelogf("max RMS errors in fits vs. delta*:\n"
-                      "      omega_22 =     %12.6g \n"
-                      "      A*       =     %12.6g \n"
-                      "      B*       =     %12.6g \n"
-                      "      C*       =     %12.6g \n", e22, ea, eb, ec);
-        }
     }
 }
 
@@ -318,7 +270,7 @@ double MMCollisionInt::fitDelta(int table, int ntstar, int degree, double* c)
     default:
         return 0.0;
     }
-    w[0] = -1.0;
+    w[0] = -1.0; // to activate weight values of unity
     return polyfit(8, degree, delta, begin, w.data(), c);
 }
 
@@ -430,12 +382,7 @@ void MMCollisionInt::fit_omega22(int degree, double deltastar, double* o22)
         }
     }
     w[0]= -1.0;
-    double rmserr = polyfit(n, degree, logT, values.data(), w.data(), o22);
-    if (m_loglevel > 0 && rmserr > 0.01) {
-        warn_user("MMCollisionInt::fit_omega22",
-            "RMS error = {:12.6g} in omega_22 fit "
-            "with delta* = {:12.6g}", rmserr, deltastar);
-    }
+    polyfit(n, degree, logT, values.data(), w.data(), o22);
 }
 
 void MMCollisionInt::fit(int degree, double deltastar, double* a, double* b, double* c)
@@ -452,7 +399,7 @@ void MMCollisionInt::fit(int degree, double deltastar, double* a, double* b, dou
         }
     }
     w[0]= -1.0;
-    double rmserr = polyfit(n, degree, logT, values.data(), w.data(), a);
+    polyfit(n, degree, logT, values.data(), w.data(), a);
 
     for (int i = 0; i < n; i++) {
         if (deltastar == 0.0) {
@@ -462,7 +409,7 @@ void MMCollisionInt::fit(int degree, double deltastar, double* a, double* b, dou
         }
     }
     w[0]= -1.0;
-    rmserr = polyfit(n, degree, logT, values.data(), w.data(), b);
+    polyfit(n, degree, logT, values.data(), w.data(), b);
 
     for (int i = 0; i < n; i++) {
         if (deltastar == 0.0) {
@@ -472,28 +419,7 @@ void MMCollisionInt::fit(int degree, double deltastar, double* a, double* b, dou
         }
     }
     w[0]= -1.0;
-    rmserr = polyfit(n, degree, logT, values.data(), w.data(), c);
-    if (m_loglevel > 2) {
-        writelogf("\nT* fit at delta* = %.6g\n", deltastar);
-
-        writelog("astar = [" + vec2str(vector<double>(a, a+degree+1))+ "]\n");
-        if (rmserr > 0.01) {
-            warn_user("MMCollisionInt::fit",
-                "RMS error = {:12.6g} for A* fit", rmserr);
-        }
-
-        writelog("bstar = [" + vec2str(vector<double>(b, b+degree+1))+ "]\n");
-        if (rmserr > 0.01) {
-            warn_user("MMCollisionInt::fit",
-                "RMS error = {:12.6g} for B* fit", rmserr);
-        }
-
-        writelog("cstar = [" + vec2str(vector<double>(c, c+degree+1))+ "]\n");
-        if (rmserr > 0.01) {
-            warn_user("MMCollisionInt::fit",
-                "RMS error = {:12.6g} for C* fit", rmserr);
-        }
-    }
+    polyfit(n, degree, logT, values.data(), w.data(), c);
 }
 
 } // namespace
