@@ -286,6 +286,17 @@ TEST(AnyMap, conversion_to_anyvalue)
     EXPECT_EQ(n.at("strings").asVector<AnyValue>()[0].asString(), "foo");
 }
 
+TEST(AnyMap, conversion_from_quoted)
+{
+    AnyMap m = AnyMap::fromYamlString(
+        "{top: '99', mixed: [5.1, '122599', '3.140'], uniform: ['99', 100.1']}");
+    EXPECT_TRUE(m["top"].is<string>());
+    EXPECT_FALSE(m["top"].is<int>());
+    EXPECT_THROW(m["mixed"].asVector<double>(), InputFileError);
+    EXPECT_DOUBLE_EQ(m["mixed"].asVector<AnyValue>()[0].asDouble(), 5.1);
+    EXPECT_THROW(m["uniform"].asVector<double>(), InputFileError);
+}
+
 TEST(AnyMap, read_subnormal)
 {
     AnyMap m = AnyMap::fromYamlString(
@@ -304,6 +315,7 @@ TEST(AnyMap, iterators)
 {
     AnyMap m = AnyMap::fromYamlString(
         "{a: 1, b: two, c: 3.01, d: {foo: 1, bar: 2}}");
+
     vector<string> keys;
     for (const auto& [key, value] : m) {
         keys.push_back(key);
@@ -336,6 +348,26 @@ TEST(AnyMap, null_values)
     }
 }
 
+TEST(AnyMap, sizes) {
+    AnyMap m = AnyMap::fromYamlString("{__hidden__: 3}");
+    m.exclude("baz");
+    m.setFlowStyle();
+    EXPECT_TRUE(m.empty());
+    EXPECT_EQ(m.size(), 0U);
+}
+
+TEST(AnyMap, error_loc) {
+    AnyMap m = AnyMap::fromYamlString("{spam: 4, eggs: 12}");
+    try {
+        m.at("fake");
+        FAIL();
+    } catch (CanteraError& err) {
+        EXPECT_THAT(err.what(), testing::HasSubstr("Error on line 1"));
+        // Column marker lines up with opening brace
+        EXPECT_THAT(err.what(), testing::HasSubstr("\n          ^"));
+    }
+}
+
 TEST(AnyMap, loadYaml)
 {
     AnyMap m = AnyMap::fromYamlString(
@@ -450,10 +482,14 @@ TEST(AnyMap, definedKeyOrdering)
     m["two"] = 2;
     m["three"] = 3;
     m["four"] = 4;
+    m["five"] = 5;
+    m["six"] = 6;
     m["__type__"] = "Test";
 
     AnyMap::addOrderingRules("Test", {
         {"head", "three"},
+        {"head", "five"},
+        {"tail", "six"},
         {"tail", "one"}
     });
 
@@ -467,4 +503,6 @@ TEST(AnyMap, definedKeyOrdering)
     EXPECT_LT(loc["four"], loc["one"]);
     EXPECT_LT(loc["one"], loc["half"]);
     EXPECT_LT(loc["zero"], loc["half"]);
+    EXPECT_LT(loc["three"], loc["five"]);
+    EXPECT_LT(loc["six"], loc["one"]);
 }
