@@ -105,8 +105,7 @@ TEST_F(KineticsFromScratch, add_three_body_reaction1)
 
     reac = parseCompString("O:2, M:1");
     prod = parseCompString("O2:1, M:1");
-    ASSERT_THROW(make_shared<Reaction>(reac, prod, rate, tbody), CanteraError);
-
+    ASSERT_THROW(auto R = make_shared<Reaction>(reac, prod, rate, tbody), CanteraError);
 }
 
 TEST_F(KineticsFromScratch, add_three_body_reaction2)
@@ -263,7 +262,7 @@ TEST_F(KineticsFromScratch, multiple_third_bodies9)
 
     reac = parseCompString("H2:1, O2:1");
     prod = parseCompString("H2:1, O2:1");
-    ASSERT_THROW(make_shared<Reaction>(reac, prod, rate, tbody), CanteraError);
+    ASSERT_THROW(auto R = make_shared<Reaction>(reac, prod, rate, tbody), CanteraError);
 }
 
 TEST_F(KineticsFromScratch, add_two_temperature_plasma)
@@ -327,6 +326,9 @@ TEST_F(KineticsFromScratch, third_body_composition)
     Composition prod = R->products;
     EXPECT_EQ(prod.count("H2O"), (size_t) 0);
     EXPECT_EQ(reac.count("M"), (size_t) 0);
+
+    ASSERT_THROW(kin.kineticsSpeciesName(200), IndexError);
+    ASSERT_THROW(kin.kineticsSpeciesIndex("spam"), CanteraError);
 }
 
 TEST_F(KineticsFromScratch, add_falloff_reaction1)
@@ -486,7 +488,7 @@ TEST_F(KineticsFromScratch, negative_A_error)
     Composition reac = parseCompString("O:1 H2:1");
     Composition prod = parseCompString("H:1 OH:1");
     auto rate = make_shared<ArrheniusRate>(-3.87e1, 2.7, 6260.0 / GasConst_cal_mol_K);
-    ASSERT_THROW(make_shared<Reaction>(reac, prod, rate), CanteraError);
+    ASSERT_THROW(auto R = make_shared<Reaction>(reac, prod, rate), CanteraError);
 }
 
 TEST_F(KineticsFromScratch, allow_negative_A)
@@ -567,6 +569,38 @@ TEST_F(KineticsFromScratch, invalid_nonreactant_order)
     ASSERT_EQ((size_t) 0, kin.nReactions());
 }
 
+TEST_F(KineticsFromScratch, unbalanced_neutral)
+{
+    Composition reac = parseCompString("O:1 H2:1");
+    Composition prod = parseCompString("H:1 H2O:1");
+    auto rate = make_shared<ArrheniusRate>(1.0, 0.0, 0.0);
+    auto R = make_shared<Reaction>(reac, prod, rate);
+    ASSERT_THROW(kin.addReaction(R), CanteraError);
+    ASSERT_EQ((size_t) 0, kin.nReactions());
+}
+
+TEST(KineticsFromScratch2, unbalanced_positive_ion)
+{
+    auto soln = newSolution("kineticsfromscratch.yaml", "ions");
+    Composition reac = parseCompString("H3O+:1");
+    Composition prod = parseCompString("H2O:1 H:1");
+    auto rate = make_shared<ArrheniusRate>(1.0, 0.0, 0.0);
+    auto R = make_shared<Reaction>(reac, prod, rate);
+    ASSERT_THROW(soln->kinetics()->addReaction(R), CanteraError);
+    ASSERT_EQ((size_t) 0, soln->kinetics()->nReactions());
+}
+
+TEST(KineticsFromScratch2, unbalanced_negative_ion)
+{
+    auto soln = newSolution("kineticsfromscratch.yaml", "ions");
+    Composition reac = parseCompString("O2-:1");
+    Composition prod = parseCompString("O2:1 E:2");
+    auto rate = make_shared<ArrheniusRate>(1.0, 0.0, 0.0);
+    auto R = make_shared<Reaction>(reac, prod, rate);
+    ASSERT_THROW(soln->kinetics()->addReaction(R), CanteraError);
+    ASSERT_EQ((size_t) 0, soln->kinetics()->nReactions());
+}
+
 class InterfaceKineticsFromScratch : public testing::Test
 {
 public:
