@@ -26,6 +26,10 @@ class TestModels:
     def yml(self, yml_file):
         return load_yaml(yml_file)
 
+    def test_invalid(self):
+        with pytest.raises(TypeError):
+            ct.Solution(None)
+
     def test_load_thermo_models(self, yml, yml_file):
         for ph in yml['phases']:
             ph_name = ph['name']
@@ -247,6 +251,12 @@ class TestSolutionArray:
         with pytest.raises(IndexError):
             arr_trunc[10]
 
+    def test_invalid(self):
+        with pytest.raises(TypeError):
+            ct.SolutionArray(None)
+        with pytest.raises(TypeError):
+            ct.SolutionArray("gri30.yaml")
+
     def test_from_state_numpy(self, gas):
         states = np.array([[list(gas.state)] * 5] * 3)
         arr = ct.SolutionArray(gas, states=states)
@@ -308,6 +318,34 @@ class TestSolutionArray:
         arr = ct.SolutionArray(gas, shape=1)
         assert arr.net_production_rates.size == gas.n_species
 
+    def test_pickle_solutionarray(self):
+        sol = ct.Solution("gri30.yaml")
+        solarr = ct.SolutionArray(sol, 10)
+        # Fill with some data
+        T = np.linspace(300, 2000, 10)
+        P = np.linspace(1e5, 5e5, 10)
+        X = np.zeros((10, sol.n_species))
+        X[:, sol.species_index("H2")] = 0.7
+        X[:, sol.species_index("O2")] = 0.3
+        solarr.TPX = T, P, X
+
+        outfile = self.test_work_path / "solarr.pkl"
+        with open(outfile, "wb") as f:
+            pickle.dump(solarr, f)
+
+        with open(outfile, "rb") as f:
+            solarr_loaded = pickle.load(f)
+
+        # Compare all fields
+        assert solarr.shape == solarr_loaded.shape
+        assert solarr.T == approx(solarr_loaded.T)
+        assert solarr.P == approx(solarr_loaded.P)
+        assert solarr.X == approx(solarr_loaded.X)
+        # Check all state vectors
+        for orig, loaded in zip(solarr, solarr_loaded):
+            assert orig.T == approx(loaded.T)
+            assert orig.P == approx(loaded.P)
+            assert orig.X == approx(loaded.X)
 
 @pytest.fixture(scope='class')
 def setup_solution_array_info_tests(request):
@@ -350,79 +388,79 @@ class TestSolutionArrayInfo:
 
     def test_short(self):
         arr = ct.SolutionArray(self.gas, 5)
-        self.check(arr, arr.info(rows=10, width=self.width), 5)
+        self.check(arr, arr.info(rows=10, width=self.width, display=False), 5)
 
     def test_long(self):
         arr = ct.SolutionArray(self.gas, 20, extra={"spam": "eggs"})
-        self.check(arr, arr.info(rows=10, width=self.width), 11)
+        self.check(arr, arr.info(rows=10, width=self.width, display=False), 11)
 
     def test_scientific(self):
         arr = ct.SolutionArray(self.gas, 20)
         arr.set_equivalence_ratio(np.linspace(.5, 1.5, 20), "H2", "O2:1,N2:10")
         arr.equilibrate("HP")
-        self.check(arr, arr.info(rows=7, width=self.width), 8)
+        self.check(arr, arr.info(rows=7, width=self.width, display=False), 8)
 
     def test_plus_minus_i(self):
         arr = ct.SolutionArray(self.gas, 20,
                                extra={"foo": 10 * np.arange(-10, 10, dtype=int)})
-        self.check(arr, arr.info(rows=12, width=self.width), 13)
+        self.check(arr, arr.info(rows=12, width=self.width, display=False), 13)
 
     def test_plus_minus_f(self):
         arr = ct.SolutionArray(self.gas, 20, extra={"foo": "bar", "spam": "eggs"})
-        self.check(arr, arr.info(rows=9), 10)
+        self.check(arr, arr.info(rows=9, display=False), 10)
         arr.foo = np.linspace(-1, 1.5, 20)
-        self.check(arr, arr.info(rows=12, width=self.width), 13)
+        self.check(arr, arr.info(rows=12, width=self.width, display=False), 13)
 
     def test_plus_minus_e(self):
         arr = ct.SolutionArray(self.gas, 20, extra={"foo": "bar", "spam": "eggs"})
-        self.check(arr, arr.info(rows=9, width=100), 10)
+        self.check(arr, arr.info(rows=9, width=100, display=False), 10)
         arr.foo = np.linspace(-1e6, 1.5e6, 20)
-        self.check(arr, arr.info(rows=12, width=self.width), 13)
+        self.check(arr, arr.info(rows=12, width=self.width, display=False), 13)
 
     def test_strings(self):
         arr = ct.SolutionArray(self.gas, 26, extra={"foo": "bar", "spam": "eggs"})
         arr.spam = ["abcdefghijklmnopqrstuvwxyz"[:ix+1] for ix in range(26)]
-        self.check(arr, arr.info(rows=12, width=self.width), 13)
+        self.check(arr, arr.info(rows=12, width=self.width, display=False), 13)
 
     def test_double_vector(self):
         arr = ct.SolutionArray(self.gas, 15, extra={"spam": "eggs"})
         arr.spam = [[1.1, 2.2, 3.3] for _ in range(15)]
-        self.check(arr, arr.info(rows=12, width=self.width), 13)
+        self.check(arr, arr.info(rows=12, width=self.width, display=False), 13)
 
     def test_integer_vector(self):
         arr = ct.SolutionArray(self.gas, 15, extra={"spam": "eggs"})
         arr.spam = [np.array([1, 2, 3], dtype=int) for _ in range(15)]
-        self.check(arr, arr.info(rows=12, width=self.width), 13)
+        self.check(arr, arr.info(rows=12, width=self.width, display=False), 13)
 
     def test_string_vector(self):
         arr = ct.SolutionArray(self.gas, 15, extra={"spam": "eggs"})
         arr.spam = [["foo", "bar"] for _ in range(15)]
-        self.check(arr, arr.info(rows=12, width=self.width), 13)
+        self.check(arr, arr.info(rows=12, width=self.width, display=False), 13)
 
     def test_select_species(self):
         arr = ct.SolutionArray(self.gas, 5)
         arr2 = arr("H2")
-        lines = arr2.info(width=self.width).split("\n")
+        lines = arr2.info(width=self.width, display=False).split("\n")
         assert lines[0].split() == ["T", "D", "H2"]
 
     def test_select_rows(self):
         arr = ct.SolutionArray(self.gas, 25)
         ix = [2, 5, 6, 9, 15, 3]
         arr2 = arr[ix]
-        self.check(arr2, arr2.info(width=self.width), 6)
-        lines = arr2.info(width=self.width).split("\n")[1:-2]
+        self.check(arr2, arr2.info(width=self.width, display=False), 6)
+        lines = arr2.info(width=self.width, display=False).split("\n")[1:-2]
         loc = [int(line.split()[0]) for line in lines]
         assert loc == ix
 
     def test_water_simple(self):
         w = ct.Water()
         arr = ct.SolutionArray(w, 10)
-        self.check(arr, arr.info(rows=12, width=self.width), 10)
+        self.check(arr, arr.info(rows=12, width=self.width, display=False), 10)
 
     def test_water_extra(self):
         w = ct.Water()
         arr = ct.SolutionArray(w, 15, extra={"spam": np.arange(15, dtype=int)})
-        self.check(arr, arr.info(rows=7, width=self.width), 8)
+        self.check(arr, arr.info(rows=7, width=self.width, display=False), 8)
 
 @pytest.fixture(scope='class')
 def setup_solution_array_io_tests(request):
@@ -475,13 +513,24 @@ class TestSolutionArrayIO:
         assert states[0].P == gas.P
         assert states[0].Y == approx(gas.Y)
 
+    def test_append_scrambled_input(self):
+        gas = ct.Solution("h2o2.yaml")
+        gas.TP = 300, ct.one_atm
+        gas.set_unnormalized_mass_fractions(np.full(gas.n_species, 0.3))
+        states = ct.SolutionArray(gas)
+        states.append(Y=gas.Y, P=gas.P, normalize=False, T=gas.T)
+        assert states[0].T == gas.T
+        assert states[0].P == gas.P
+        assert states[0].Y == approx(gas.Y)
+
     @pytest.mark.skipif("native" not in ct.hdf_support(),
                         reason="Cantera compiled without HDF support")
-    def test_import_no_norm_data(self):
+    def test_import_no_norm_data_h5(self):
         outfile = self.test_work_path / "solutionarray_no_norm.h5"
         outfile.unlink(missing_ok=True)
 
         gas = ct.Solution("h2o2.yaml")
+        gas.transport_model = "multicomponent"
         gas.set_unnormalized_mole_fractions(np.full(gas.n_species, 0.3))
         states = ct.SolutionArray(gas, 5)
         states.save(outfile, "group0")
@@ -492,6 +541,25 @@ class TestSolutionArrayIO:
         assert states.T == approx(b.T)
         assert states.P == approx(b.P)
         assert states.X == approx(b.X)
+        assert gas_new.transport_model == "multicomponent"
+
+    def test_import_no_norm_data_yaml(self):
+        outfile = self.test_work_path / "solutionarray_no_norm.yaml"
+        outfile.unlink(missing_ok=True)
+
+        gas = ct.Solution("h2o2.yaml")
+        gas.transport_model = "multicomponent"
+        gas.set_unnormalized_mole_fractions(np.full(gas.n_species, 0.3))
+        states = ct.SolutionArray(gas, 5)
+        states.save(outfile, "group0")
+
+        gas_new = ct.Solution("h2o2.yaml")
+        b = ct.SolutionArray(gas_new)
+        b.restore(outfile, "group0") #, normalize=False)
+        assert states.T == approx(b.T)
+        assert states.P == approx(b.P)
+        assert states.X == approx(b.X)
+        assert gas_new.transport_model == "multicomponent"
 
     def check_arrays(self, a, b, rtol=1e-8):
         assert a.T == approx(b.T, rel=rtol)
@@ -1111,6 +1179,13 @@ class TestSolutionSerialization:
         assert 'kinetics' not in data
         assert 'transport' not in data
 
+    def test_input_data_rate_multipliers(self):
+        gas = ct.Solution("h2o2.yaml", transport_model=None)
+        gas.set_multiplier(0.25, 3)
+        gas.set_multiplier(0.5, 5)
+        multipliers = {"default": 1.0, "3": 0.25, "5": 0.5}
+        assert gas.input_data["rate-multipliers"] == multipliers
+
     def test_yaml_simple(self):
         gas = ct.Solution('h2o2.yaml')
         gas.TPX = 500, ct.one_atm, 'H2: 1.0, O2: 1.0'
@@ -1229,6 +1304,19 @@ class TestSolutionSerialization:
         with pytest.raises(ct.CanteraError, match="different definitions"):
             gas.write_yaml(self.test_work_path / "h2o2-error.yaml", phases=gas2)
 
+    def test_yaml_rate_multipliers(self):
+        gas = ct.Solution('h2o2.yaml', transport_model=None)
+        gas.set_multiplier(0.0)
+        gas.set_multiplier(2.0, 3)
+        gas.write_yaml(self.test_work_path / "h2o2-multipliers.yaml")
+        generated = ct.Solution(self.test_work_path / "h2o2-multipliers.yaml")
+
+        kf_gen = generated.forward_rate_constants
+        for i in range(gas.n_reactions):
+            if i != 3:
+                assert kf_gen[i] == 0.0
+        assert gas.multiplier(3) == 2.0
+
     def test_yaml_user_data(self):
         gas = ct.Solution("h2o2.yaml")
         extra = {"spam": {"A": 1, "B": 2}, "eggs": [1, 2.3, 4.5]}
@@ -1291,26 +1379,30 @@ class TestSolutionSerialization:
         yaml_gen = generated_file.read_text()
         assert re.search("extra:.*key1.*key2", yaml_gen)
 
-
     def test_duplicate_reactions(self):
-        gas = ct.Solution('h2o2.yaml', transport_model=None)
+        R = [
+            ct.Reaction(equation='H2 + O = OH + H', rate=ct.ArrheniusRate(100, 0, 0)),
+            ct.Reaction(equation='H2 + O = OH + H', rate=ct.ArrheniusRate(50, 0.5, 0)),
+            ct.Reaction(equation='OH + H2 = H + H2O', rate=ct.ArrheniusRate(10, 2, 0)),
+        ]
+        R[2].duplicate = True
 
-        reactions = [gas.reaction(i) for i in range(gas.n_reactions) if i != 25]
-        gas_reduced = ct.Solution(name="gas", thermo="ideal-gas", kinetics="bulk",
-                                  species=gas.species(), reactions=reactions)
-        gas_reduced.write_yaml(self.test_work_path / "h2o2-reduced-duplicates-err.yaml")
+        gas = ct.Solution(thermo='ideal-gas', kinetics='gas',
+                          species=ct.Species.list_from_file('h2o2.yaml'), reactions=R)
+        gas.TPX = 900, 2 * ct.one_atm, 'H2:1.0, O2:1.0'
 
-        with pytest.raises(ct.CanteraError, match="No duplicate found .+ number 24"):
-            test = ct.Solution(self.test_work_path / "h2o2-reduced-duplicates-err.yaml")
+        yaml_file = self.test_work_path / "marking-duplicates.yaml"
+        gas.write_yaml(yaml_file)
+        restored = ct.Solution(yaml_file)
+        assert restored.reaction(0).duplicate is True
+        assert restored.reaction(1).duplicate is True
+        assert restored.reaction(2).duplicate is False
 
-        reactions[24].duplicate = False
-        assert 'duplicate' not in reactions[24].input_data
-        gas_reduced = ct.Solution(name="gas", thermo="ideal-gas", kinetics="bulk",
-                                  species=gas.species(), reactions=reactions)
-        gas_reduced.write_yaml(self.test_work_path / "h2o2-reduced-duplicates-ok.yaml")
-        test = ct.Solution(self.test_work_path / "h2o2-reduced-duplicates-ok.yaml")
-        assert not gas_reduced.reaction(24).duplicate
+        assert gas.forward_rate_constants == approx(restored.forward_rate_constants)
 
+        assert 'duplicate' in restored.reaction(0).input_data
+        restored.reaction(0).duplicate = False
+        assert 'duplicate' not in restored.reaction(0).input_data
 
 class TestSpeciesSerialization:
 
