@@ -31,9 +31,7 @@ class Testck2yaml:
         if extra is not None:
             extra = self.test_data_path / extra
         output = self.test_work_path / (output + "-from-ck.yaml")
-        # In Python >= 3.8, this can be replaced by the missing_ok argument
-        if output.is_file():
-            output.unlink()
+        output.unlink(missing_ok=True)
         ck2yaml.convert(inputFile, thermo_file=thermo,
             transport_file=transport, surface_file=surface, out_name=output,
             extra_file=extra, quiet=quiet, **kwargs)
@@ -637,13 +635,14 @@ class Testck2yaml:
 
     def test_surface_mech3(self):
         # This tests the case where the thermo data for both the gas and surface are
-        # combined in a file separate from the gas and surface definitions.
+        # combined in a file separate from the gas and surface definitions. Also covers
+        # the case where the surface does not have a name specified.
 
         output = self.convert('surface2-gas.inp', thermo='surface2-thermo.dat',
                               surface='surface2.inp', output='surface2')
         captured = self._capsys.readouterr()
         assert "SITE section implicitly ended" in captured.out
-        surf = ct.Interface(output, 'PT_SURFACE')
+        surf = ct.Interface(output, 'surface1')
 
         assert surf.n_species == 6
         assert surf.n_reactions ==  15
@@ -1212,6 +1211,7 @@ class Testcti2yaml:
         self.checkThermo(ctiSurf, yamlSurf, [400, 800, 1600])
         self.checkKinetics(ctiSurf, yamlSurf, [900], [101325])
 
+    @pytest.mark.usefixtures("allow_deprecated")
     def test_sofc(self):
         self.convert("sofc")
         cti_tpb, yaml_tpb = self.checkConversion("sofc", ct.Interface, name="tpb")
@@ -1438,6 +1438,7 @@ class Testctml2yaml:
         self.checkThermo(ctmlSurf, yamlSurf, [400, 800, 1600])
         self.checkKinetics(ctmlSurf, yamlSurf, [500, 1200], [1e4, 3e5])
 
+    @pytest.mark.usefixtures("allow_deprecated")
     def test_sofc(self):
         self.convert("sofc")
         ctml_tpb, yaml_tpb = self.checkConversion("sofc", ct.Interface, name="tpb")
@@ -1621,6 +1622,7 @@ class Testctml2yaml:
         ctmlPhase, yamlPhase = self.checkConversion("pdss_hkft")
         self.checkThermo(ctmlPhase, yamlPhase, [300, 500])
 
+    @pytest.mark.usefixtures("allow_deprecated")
     def test_lattice_solid(self):
         self.convert("Li7Si3_ls")
         ctmlPhase, yamlPhase = self.checkConversion("Li7Si3_ls",
@@ -1734,10 +1736,10 @@ class Testlxcat2yaml:
                      database="test", insert=False,
                      output=outfile)
 
-        # get Solution from the mechanism file
+        # get Solution from the input file
         phase = "isotropic-electron-energy-plasma"
-        mechFile = "lxcat-test-convert.yaml"
-        gas = ct.Solution(self.test_data_path / mechFile,
+        inputFile = "lxcat-test-convert-species.yaml"
+        gas = ct.Solution(self.test_data_path / inputFile,
                            phase=phase, transport_model=None)
 
         # add collisions to the reaction list
@@ -1745,13 +1747,18 @@ class Testlxcat2yaml:
                                               gas, section="collisions")
 
         # verify the data
-        assert len(rxn_list) == 2
-        assert rxn_list[0].equation == "O2 + e => O2(Total-Ionization)+ + 2 e"
+        assert len(rxn_list) == 3
+        assert rxn_list[0].equation == "CO2 + e => CO2 + e"
         assert rxn_list[0].reaction_type == "electron-collision-plasma"
-        assert rxn_list[0].rate.energy_levels == approx([15., 20.])
-        assert rxn_list[0].rate.cross_sections == approx([0.0, 5.5e-22])
+        assert rxn_list[0].rate.energy_levels == approx([0.0, 1.0])
+        assert rxn_list[0].rate.cross_sections == approx([0.0, 1.0e-22])
 
-        assert rxn_list[1].equation == "O2 + e => O2-"
+        assert rxn_list[1].equation == "O2 + e => O2(Total-Ionization)+ + 2 e"
         assert rxn_list[1].reaction_type == "electron-collision-plasma"
-        assert rxn_list[1].rate.energy_levels == approx([0.0, 1.0])
-        assert rxn_list[1].rate.cross_sections == approx([0.0, 1.0e-22])
+        assert rxn_list[1].rate.energy_levels == approx([15., 20.])
+        assert rxn_list[1].rate.cross_sections == approx([0.0, 5.5e-22])
+
+        assert rxn_list[2].equation == "O2 + e => O2-"
+        assert rxn_list[2].reaction_type == "electron-collision-plasma"
+        assert rxn_list[2].rate.energy_levels == approx([0.0, 1.0])
+        assert rxn_list[2].rate.cross_sections == approx([0.0, 1.0e-22])
