@@ -28,12 +28,10 @@ class TestKinetics:
         phase.TPX = 800, 2 * ct.one_atm, [0.1, 1e-4, 1e-5, 0.2, 2e-4, 0.3, 1e-6, 5e-5, 0.4, 0]
         return phase
 
-    @pytest.mark.usefixtures("allow_deprecated")
     def test_counts(self, phase):
         assert phase.n_reactions == 29
         assert phase.n_total_species == 10
         assert phase.n_phases == 1
-        assert phase.reaction_phase_index == 0  # deprecated
 
     def test_is_reversible(self, phase):
         for i in range(phase.n_reactions):
@@ -495,8 +493,7 @@ class TestKineticsRepeatability:
             assert msg in err_msg_list
 
     def test_sticking_coeff_err(self):
-        err_msg = (r"Sticking coefficient is greater than 1 for reaction 'O2 \+ 2 PT\(S\) => 2 O\(S\)'",
-                   "at T = 200.0",
+        err_msg = ("at T = 200.0",
                    "at T = 500.0",
                    "at T = 1000.0",
                    "at T = 2000.0",
@@ -505,9 +502,13 @@ class TestKineticsRepeatability:
                    "Sticking coefficient is greater than 1 for reaction",
                    "StickingRate::validate:")
 
-        for err in err_msg:
-            with pytest.warns(UserWarning, match=err):
-                ct.Interface("sticking_coeff_check.yaml", "Pt_surf")
+        with pytest.warns(UserWarning) as record:
+            ct.Interface("sticking_coeff_check.yaml", "Pt_surf")
+        assert len(record) == 2
+        for msg in err_msg:
+            assert msg in str(record[0].message)
+        assert "reaction 'O2 + 2 PT(S) => 2 O(S)'" in str(record[0].message)
+        assert "reaction 'OH + PT(S) => OH(S)'" in str(record[1].message)
 
 
 def check_raises(yaml, err_msg, line):
@@ -732,13 +733,13 @@ class TestReactionPath:
         gas.TPX = 1300.0, ct.one_atm, 'CH4:0.4, O2:1, N2:3.76'
 
         # Advance the reactor
-        r = ct.IdealGasReactor(gas)
+        r = ct.IdealGasReactor(gas, clone=False)
         net = ct.ReactorNet([r])
         T = r.T
         while T < 1900:
             net.step()
             T = r.T
-        return gas
+        return r.phase
 
     def check_dot(self, gas, diagram, element):
         diagram.label_threshold = 0
@@ -1051,8 +1052,10 @@ class TestLithiumIonBatteryKinetics:
                     return x0
 
         # Phases
-        anode, cathode, metal, electrolyte = ct.import_phases(
-            mech, ["anode", "cathode", "electron", "electrolyte"])
+        anode = ct.Solution(mech, "anode")
+        cathode = ct.Solution(mech, "cathode")
+        metal = ct.Solution(mech, "electron")
+        electrolyte = ct.Solution(mech, "electrolyte")
         anode_int = ct.Interface(
             mech, "edge_anode_electrolyte", adjacent=[anode, metal, electrolyte])
         cathode_int = ct.Interface(
@@ -1315,6 +1318,7 @@ class TestElementaryReaction:
         gas = ct.Solution(thermo='ideal-gas', kinetics='gas',
                           species=species, reactions=[r])
 
+    @pytest.mark.usefixtures("allow_deprecated")  # for class Arrhenius
     def test_modify_elementary(self, gas):
         gas = ct.Solution('h2o2.yaml', transport_model=None)
         gas.TPX = gas.TPX
@@ -1332,9 +1336,18 @@ class TestElementaryReaction:
         gas.modify_reaction(2, R)
         assert A2*T**b2*np.exp(-Ta2/T) == approx(gas.forward_rate_constants[2])
 
+        A3 = 1.9 * A1
+        b3 = b1 + 0.3
+        Ta3 = Ta1 * 2.2
+        R.rate = ct.Arrhenius(A3, b3, Ta3 * ct.gas_constant)
+        gas.modify_reaction(2, R)
+        assert A3*T**b3*np.exp(-Ta3/T) == approx(gas.forward_rate_constants[2])
+
 class TestFalloffReaction:
 
+    @pytest.mark.usefixtures("allow_deprecated")
     def test_negative_A_falloff(self):
+        # TODO: After Cantera 3.2, replace Arrhenius with ArrheniusRate
         species = ct.Species.list_from_file("gri30.yaml")
         low_rate = ct.Arrhenius(2.16e13, -0.23, 0)
         high_rate = ct.Arrhenius(-8.16e12, -0.5, 0)
@@ -1350,15 +1363,15 @@ class TestFalloffReaction:
         with pytest.raises(ct.CanteraError, match='pre-exponential'):
             rate.low_rate = low_rate
 
-        rate.low_rate = ct.Arrhenius(-2.16e13, -0.23, 0)
+        rate.low_rate = ct.ArrheniusRate(-2.16e13, -0.23, 0)
         rxn = ct.Reaction("NH:1, NO:1", "N2O:1, H:1", rate)
         gas = ct.Solution(thermo='ideal-gas', kinetics='gas',
                           species=species, reactions=[rxn])
         assert gas.forward_rate_constants < 0
 
     def test_falloff(self, gas, species):
-        high_rate = ct.Arrhenius(7.4e10, -0.37, 0.0)
-        low_rate = ct.Arrhenius(2.3e12, -0.9, -1700 * 1000 * 4.184)
+        high_rate = ct.ArrheniusRate(7.4e10, -0.37, 0.0)
+        low_rate = ct.ArrheniusRate(2.3e12, -0.9, -1700 * 1000 * 4.184)
         tb = ct.ThirdBody(efficiencies={"AR":0.7, "H2":2.0, "H2O":6.0})
         r = ct.Reaction("OH:2", "H2O2:1",
                         ct.TroeRate(low_rate, high_rate, [0.7346, 94, 1756, 5182]),
@@ -1427,10 +1440,10 @@ class TestPlogReaction:
         species = ct.Species.list_from_file("pdep-test.yaml")
 
         rate = ct.PlogRate([
-            (0.01*ct.one_atm, ct.Arrhenius(1.2124e13, -0.5779, 10872.7*4184)),
-            (1.0*ct.one_atm, ct.Arrhenius(4.9108e28, -4.8507, 24772.8*4184)),
-            (10.0*ct.one_atm, ct.Arrhenius(1.2866e44, -9.0246, 39796.5*4184)),
-            (100.0*ct.one_atm, ct.Arrhenius(5.9632e53, -11.529, 52599.6*4184))
+            (0.01*ct.one_atm, ct.ArrheniusRate(1.2124e13, -0.5779, 10872.7*4184)),
+            (1.0*ct.one_atm, ct.ArrheniusRate(4.9108e28, -4.8507, 24772.8*4184)),
+            (10.0*ct.one_atm, ct.ArrheniusRate(1.2866e44, -9.0246, 39796.5*4184)),
+            (100.0*ct.one_atm, ct.ArrheniusRate(5.9632e53, -11.529, 52599.6*4184))
         ])
         r = ct.Reaction({"R1A":1, "R1B":1}, {"P1":1, "H":1}, rate)
 
@@ -1907,13 +1920,21 @@ class TestStickingCoefficient:
         # M&W toggled on (locally) for reaction 4
         assert k1[4] == approx(k2[4]) # sticking coefficient = 1.0
 
-class TestElectrochemicalReaction:
+class TestElectronCollisionPlasmaReaction:
 
-    def test_electron_collision_plasma(self):
-        gas1 = ct.Solution('oxygen-plasma.yaml',
-                           'isotropic-electron-energy-plasma',
-                           transport_model=None)
-        gas1.TPX = 300, ct.one_atm, {"O2": 1.0, "E": 1.0}
+    def setup_plasma(self):
+        gas = ct.Solution('oxygen-plasma.yaml',
+                          'isotropic-electron-energy-plasma',
+                          transport_model=None)
+        gas.TPX = 300, ct.one_atm, {"O2": 1.0, "E": 1.0}
+        return gas
+
+    def test_ECPR_electron_energy_level(self):
+        # Consistent test of using different electron energy method
+        # This test compares the rate constants calculated from
+        # the method discretized-electron-energy-plasma to
+        # the method isotropic-electron-energy-plasma
+        gas1 = self.setup_plasma()
         electron_energy_levels = gas1.electron_energy_levels
         electron_energy_dist = gas1.electron_energy_distribution
         k1 = gas1.forward_rate_constants[1]
@@ -1926,3 +1947,16 @@ class TestElectrochemicalReaction:
                                                           electron_energy_dist)
         k2 = gas2.forward_rate_constants[1]
         assert k1 == approx(k2)
+
+    def test_ECPR_rate_of_progress(self):
+        # Test of forward and reverse rate of progress
+        # The reverse rate of progress calculates the super-elastic rate coefficient
+        # which equals to the forward rate coefficient when the threshold energy is
+        # zero. Therefore, the reverse rate of progress equals the forward rate of
+        # progress.
+        gas = self.setup_plasma()
+
+        frop = approx(gas.forward_rates_of_progress[1])
+        rrop = approx(gas.reverse_rates_of_progress[1])
+
+        assert frop == rrop
