@@ -1,6 +1,8 @@
 import numpy as np
 import pytest
 from pytest import approx
+import re
+pd = pytest.importorskip("pandas")
 
 import cantera as ct
 
@@ -32,11 +34,16 @@ class TestOnedim:
     def test_boundaryProperties(self):
         gas1 = ct.Solution("h2o2.yaml")
         gas2 = ct.Solution("h2o2.yaml")
-        inlet = ct.Inlet1D(name='something', phase=gas1)
-        flame = ct.FreeFlow(gas1)
+        inlet = ct.Inlet1D(gas1, name="spam")
+        flame = ct.FreeFlow(gas1, name="eggs")
         sim = ct.Sim1D((inlet, flame))
 
-        assert inlet.name == 'something'
+        assert sim.domain_index("spam") == 0
+        assert sim.domain_index(inlet) == 0
+        assert sim.domain_index("eggs") == 1
+        assert inlet.name == "spam"
+        with pytest.raises(ct.CanteraError, match="Domain 'bacon' not found"):
+            sim.domain_index("bacon")
 
         gas2.TPX = 400, 101325, 'H2:0.3, O2:0.5, AR:0.2'
         Xref = gas2.X
@@ -111,7 +118,7 @@ class TestOnedim:
         # Some things don't work until the domains have been added to a Sim1D
         sim = ct.Sim1D((left, flame, right))
 
-        with pytest.raises(ct.CanteraError, match='no component'):
+        with pytest.raises(ct.CanteraError, match="Component 'foobar' not found"):
             flame.set_steady_tolerances(foobar=(3e-4, 3e-6))
 
         flame.set_steady_tolerances(default=(5e-3, 5e-5),
@@ -195,18 +202,19 @@ class TestFreeFlame:
         self.sim.inlet.T = Tin
         self.sim.inlet.X = reactants
 
-    def solve_fixed_T(self):
+    def solve_fixed_T(self, loglevel=0):
         # Solve with the energy equation disabled
         self.sim.energy_enabled = False
-        self.sim.solve(loglevel=0, refine_grid=False)
+        self.sim.solve(loglevel=loglevel, refine_grid=False)
 
         assert not self.sim.energy_enabled
 
-    def solve_mix(self, ratio=3.0, slope=0.3, curve=0.2, prune=0.0, refine=True):
+    def solve_mix(self, ratio=3.0, slope=0.3, curve=0.2, prune=0.0, refine=True,
+                  auto=False):
         # Solve with the energy equation enabled
         self.sim.set_refine_criteria(ratio=ratio, slope=slope, curve=curve, prune=prune)
         self.sim.energy_enabled = True
-        self.sim.solve(loglevel=0, refine_grid=refine)
+        self.sim.solve(loglevel=0, refine_grid=refine, auto=auto)
 
         assert self.sim.energy_enabled
         assert self.sim.transport_model == 'mixture-averaged'
@@ -217,6 +225,15 @@ class TestFreeFlame:
 
         assert self.sim.transport_model == 'multicomponent'
 
+        data = self.test_work_path / f"multicomponent.yaml"
+        data.unlink(missing_ok=True)
+        group = "multicomponent"
+        self.sim.save(data, group)
+
+        arr = ct.SolutionArray(self.sim.gas)
+        arr.restore(data, "multicomponent/flame")
+        assert arr.transport_model == "multicomponent"
+
     def test_flow_type(self):
         Tin = 300
         p = ct.one_atm
@@ -240,6 +257,30 @@ class TestFreeFlame:
         assert self.sim.fixed_temperature == approx(tfixed)
         assert self.sim.fixed_temperature_location == approx(zfixed)
 
+        # test some alias names
+        assert np.allclose(self.sim.T, self.sim.flame.temperature)
+        zeros = self.sim.T * 0
+        with pytest.raises(ct.CanteraError, match="is not used by 'free-flow'"):
+            self.sim.flame.set_values("spread_rate", zeros)
+        with pytest.raises(ct.CanteraError, match="is not used by 'free-flow'"):
+            self.sim.flame.set_values("spreadRate", zeros)
+        with pytest.raises(ct.CanteraError, match="is not used by 'free-flow'"):
+            self.sim.flame.set_values("radial-pressure-gradient", zeros)
+        with pytest.raises(ct.CanteraError, match="is not used by 'free-flow'"):
+            self.sim.flame.set_values("L", zeros)
+        with pytest.raises(ct.CanteraError, match="is not used by 'free-flow'"):
+            self.sim.flame.set_values("Lambda", zeros)
+        with pytest.raises(ct.CanteraError, match="is not used by 'free-flow'"):
+            self.sim.flame.set_values("electric-field", zeros)
+        with pytest.raises(ct.CanteraError, match="is not used by 'free-flow'"):
+            self.sim.flame.set_values("E", zeros)
+        with pytest.raises(ct.CanteraError, match="is not used by 'free-flow'"):
+            self.sim.flame.set_values("eField", zeros)
+        with pytest.raises(ct.CanteraError, match="is not used by 'free-flow'"):
+            self.sim.flame.set_values("oxidizer-velocity", zeros)
+        with pytest.raises(ct.CanteraError, match="is not used by 'free-flow'"):
+            self.sim.flame.set_values("Uo", zeros)
+
     @pytest.mark.slow_test
     def test_auto_width(self):
         Tin = 300
@@ -306,8 +347,9 @@ class TestFreeFlame:
         assert abs(T3-Tad) < abs(T2-Tad)
 
         for k in range(self.gas.n_species):
-            assert abs(X2[k]-Xad[k]) <= abs(X1[k]-Xad[k])
-            assert abs(X3[k]-Xad[k]) <= abs(X2[k]-Xad[k])
+            if Xad[k] > self.tol_ss[1]:
+                assert abs(X2[k]-Xad[k]) <= abs(X1[k]-Xad[k])
+                assert abs(X3[k]-Xad[k]) <= abs(X2[k]-Xad[k])
 
     def run_mix(self, phi, T, width, p, refine):
         reactants = {'H2': phi, 'O2': 0.5, 'AR': 2}
@@ -357,12 +399,19 @@ class TestFreeFlame:
         # restart from HDF format
         self.run_restart("h5")
 
-    def run_restart(self, mode):
+    @pytest.mark.skipif(not pd, reason="Pandas not installed")
+    def test_restart_pandas(self):
+        # restart from Pandas DataFrame
+        self.run_restart("pandas", auto=True)
+
+    def run_restart(self, mode, auto=False):
         self.run_mix(phi=1.0, T=300, width=2.0, p=1.0, refine=False)
 
         group = "restart"
         if mode == "array":
             data = self.sim.to_array()
+        elif mode == "pandas":
+            data = self.sim.to_pandas()
         else:
             data = self.test_work_path / f"freeflame_restart.{mode}"
             data.unlink(missing_ok=True)
@@ -374,7 +423,7 @@ class TestFreeFlame:
         reactants = {'H2': 0.9, 'O2': 0.5, 'AR': 2}
         self.create_sim(1.1 * ct.one_atm, 500, reactants, 2.0)
         self.sim.set_initial_guess(data=data, group=group)
-        self.solve_mix(refine=False)
+        self.solve_mix(refine=False, auto=auto)
 
         # Check continuity
         rhou = self.sim.inlet.mdot
@@ -419,6 +468,40 @@ class TestFreeFlame:
         assert "fixed-point" in new_settings
         assert "location" in new_settings["fixed-point"]
 
+    def test_log_solution_bounds(self, capsys):
+        self.create_sim(p=ct.one_atm, Tin=300, reactants="H2:1.1, O2:1, AR:5")
+        self.solve_fixed_T(loglevel=4)
+
+        out = capsys.readouterr().out
+        assert "Undamped Newton step takes solution out of bounds" in out
+        m = re.search(r"     ={60,}\n(.*?)\n     ={60,}\n(.*?)\n     ={60,}", out,
+                      re.DOTALL)
+        assert m is not None
+
+        header = m.group(1).splitlines()
+        body = m.group(2).splitlines()
+        assert re.match(" +Value +Min +Max +$", header[0])
+        assert re.match(" +Domain +Pt. Component +Value +Change +Bound +Bound +$",
+                        header[1])
+        assert len(body) > 0
+        for line in body:
+            assert re.match(r" +flame +\d+ +[A-Z0-9]+ +([0-9.e+\-]+ *){4}$", line)
+
+    def test_timestep_jacobian_limits(self, capsys):
+        # Use log output to confirm that maximum timestep count and Jacobian age
+        # limits are active
+        self.create_sim(p=ct.one_atm, Tin=300, reactants="H2:1.1, O2:1, AR:5")
+        self.sim.set_time_step(1e-8, [2, 3, 10])
+        self.sim.set_max_jac_age(3, 5)
+        self.solve_fixed_T(loglevel=3)
+        out = capsys.readouterr().out
+
+        assert "Maximum Jacobian age reached (3)" in out
+        assert "Maximum Jacobian age reached (5)" in out
+        assert "Attempt 2 timesteps" in out
+        assert "Attempt 3 timesteps" in out
+        assert "Attempt 10 timesteps" in out
+
     def test_mixture_averaged_case1(self):
         self.run_mix(phi=0.65, T=300, width=0.03, p=1.0, refine=True)
 
@@ -476,6 +559,18 @@ class TestFreeFlame:
             fwd = (Suplus-Suminus)/(2*Su0*dk)
             assert fwd == approx(dSdk_adj[m], rel=5e-3, abs=1e-7)
 
+    def test_jacobian_options(self):
+        reactants = {'H2': 0.65, 'O2': 0.5, 'AR': 2}
+        self.create_sim(p=ct.one_atm, Tin=300, reactants=reactants, width=0.03)
+        assert isinstance(self.sim.linear_solver, ct.BandedJacobian)
+        self.sim.linear_solver = ct.EigenSparseDirectJacobian()
+
+        self.sim.set_jacobian_perturbation(1e-7, 1e-12, 1e-20)
+        self.solve_mix(refine=True)
+
+        # regression value matching test_mixture_averaged_case1
+        assert self.sim.velocity[0] == approx(1.693407, rel=1e-4)
+
     # @utilities.unittest.skip('sometimes slow')
     def test_multicomponent(self):
         reactants = 'H2:1.1, O2:1, AR:5.3'
@@ -538,16 +633,22 @@ class TestFreeFlame:
         assert sl_mole == approx(sl_mass, rel=0.1)
 
     def test_soret_with_mix(self):
-        # Test that enabling Soret diffusion without
-        # multicomponent transport results in an error
-
-        self.create_sim(101325, 300, 'H2:1.0, O2:1.0')
-        assert not self.sim.soret_enabled
-        assert not self.sim.transport_model == 'multicomponent'
-
-        with pytest.raises(ct.CanteraError, match='requires.*multicomponent'):
-            self.sim.soret_enabled = True
-            self.sim.solve(loglevel=0, auto=False)
+        self.create_sim(ct.one_atm, 300, 'H2:1.1, O2:1, AR:5.3')
+        self.sim.transport_model = 'mixture-averaged'
+        self.sim.set_refine_criteria(ratio=3.0, slope=0.08, curve=0.12)
+        self.sim.solve(loglevel=0, auto=True)
+        sl_without_Soret = self.sim.velocity[0]
+        self.sim.soret_enabled = True
+        self.sim.solve(loglevel=0, auto=True)
+        sl_with_Soret = self.sim.velocity[0]
+        assert sl_with_Soret < sl_without_Soret
+        assert sl_with_Soret > 0
+        self.sim.transport_model = 'multicomponent'
+        self.sim.solve(loglevel=0, auto=False)
+        sl_multi_Soret = self.sim.velocity[0]
+        # flame speeds should not be exactly equal
+        # but they should be close even on a coarse mesh
+        assert abs(sl_multi_Soret-sl_with_Soret) < 0.1
 
     @pytest.mark.slow_test
     def test_soret_with_auto(self):
@@ -629,7 +730,6 @@ class TestFreeFlame:
 
         Y1 = self.sim.Y
         u1 = self.sim.velocity
-        V1 = self.sim.spread_rate
         P1 = self.sim.P
         T1 = self.sim.T
         self.sim.save(filename, "test")
@@ -657,24 +757,20 @@ class TestFreeFlame:
 
         Y2 = self.sim.Y
         u2 = self.sim.velocity
-        V2 = self.sim.spread_rate
         T2 = self.sim.T
 
         assert Y1 == approx(Y2)
         assert u1 == approx(u2)
-        assert V1 == approx(V2)
         assert T1 == approx(T2)
 
         self.solve_fixed_T()
         Y3 = self.sim.Y
         u3 = self.sim.velocity
-        V3 = self.sim.spread_rate
 
         # TODO: These tolerances seem too loose, but the tests fail on some
         # systems with tighter tolerances.
         assert Y1 == approx(Y3, rel=3e-3)
         assert u1 == approx(u3, rel=1e-3)
-        assert V1 == approx(V3, rel=1e-3)
 
         assert not self.sim.radiation_enabled
         assert not self.sim.soret_enabled
@@ -687,9 +783,6 @@ class TestFreeFlame:
 
         return filename, "test"
 
-    # @pytest.mark.filterwarnings("ignore:.*reaction_phase_index.*:DeprecationWarning")
-    # TODO: remove fixture after Cantera 3.1; @pytest.mark.filterwarnings does not work
-    @pytest.mark.usefixtures("allow_deprecated")  # to ignore reaction_phase_index
     def test_array_properties(self):
         self.create_sim(ct.one_atm, 300, 'H2:1.1, O2:1, AR:5')
         grid_shape = self.sim.grid.shape
@@ -732,10 +825,7 @@ class TestFreeFlame:
         Tin = 400
 
         filename = self.test_work_path / "onedim-add-species.yaml"
-        # In Python >= 3.8, this can be replaced by the missing_ok argument
-        if filename.is_file():
-            filename.unlink()
-
+        filename.unlink(missing_ok=True)
         self.create_sim(p, Tin, reactants, mech="h2o2.yaml")
         gas1 = self.gas
         self.sim.max_grid_points = 234
@@ -767,10 +857,7 @@ class TestFreeFlame:
         Tin = 400
 
         filename = self.test_work_path / "onedim-remove-species.yaml"
-        # In Python >= 3.8, this can be replaced by the missing_ok argument
-        if filename.is_file():
-            filename.unlink()
-
+        filename.unlink(missing_ok=True)
         self.create_sim(p, Tin, reactants, mech="h2o2-plus.yaml")
         gas1 = self.gas
         self.solve_fixed_T()
@@ -973,6 +1060,14 @@ class TestDiffusionFlame:
         assert self.sim.energy_enabled
         assert self.sim.transport_model == 'mixture-averaged'
 
+        arr = self.sim.to_array()
+        radial_lambda = np.unique(arr.Lambda)
+        assert len(radial_lambda) == 1
+        assert getattr(arr, "lambda")[0] == radial_lambda[0]
+        assert arr.radial_pressure_gradient[0] == radial_lambda[0]
+        assert arr.radial_pressure_gradient[0] == radial_lambda[0]
+        assert getattr(arr, "radial-pressure-gradient")[0] == radial_lambda[0]
+
     @pytest.mark.slow_test
     def test_mixture_averaged(self, request, test_data_path):
         referenceFile = "DiffusionFlameTest-h2-mix.csv"
@@ -1126,10 +1221,7 @@ class TestDiffusionFlame:
             assert not bad, bad
 
         filename = self.test_work_path / "DiffusionFlameTest-h2-mix-rad.csv"
-        # In Python >= 3.8, this can be replaced by the missing_ok argument
-        if filename.is_file():
-            filename.unlink()
-
+        filename.unlink(missing_ok=True)
         self.sim.save(filename, basis="mole") # check output
         assert filename.is_file()
         csv_data = np.genfromtxt(filename, dtype=float, delimiter=',', names=True)
@@ -1203,6 +1295,45 @@ class TestDiffusionFlame:
         sim.fuel_inlet.X = "H2: 1.0"
         sim.set_initial_guess()
 
+    def run_restore_diffusionflame(self, fname):
+        gas = ct.Solution("h2o2.yaml")
+        sim = ct.CounterflowDiffusionFlame(gas)
+        sim.restore(fname)
+        radial_lambda = sim.flame.radial_pressure_gradient
+        assert np.isclose(np.unique(radial_lambda)[0], -1.355348889404357e+05)
+        assert np.allclose(sim.T, sim.flame.temperature)
+        assert np.allclose(radial_lambda, sim.flame.L)
+        assert np.allclose(radial_lambda, sim.flame.Lambda)
+        assert np.allclose(radial_lambda, getattr(sim.flame, "lambda"))
+        zeros = sim.T * 0
+        with pytest.raises(ct.CanteraError, match="is not used by 'axisymmetric-flow'"):
+            sim.flame.set_values("electric-field", zeros)
+        with pytest.raises(ct.CanteraError, match="is not used by 'axisymmetric-flow'"):
+            sim.flame.set_values("oxidizer-velocity", zeros)
+
+    def run_restore_solutionarray(self, fname):
+        gas = ct.Solution("h2o2.yaml")
+        arr = ct.SolutionArray(gas)
+        arr.restore(fname, "solution/flame")
+
+        radial_lambda = np.unique(arr.radial_pressure_gradient)
+        assert len(radial_lambda) == 1
+        assert radial_lambda[0] == pytest.approx(-1.355348889404357e+05)
+        assert getattr(arr, "lambda")[0] == radial_lambda[0]
+        assert radial_lambda[0] == arr.L[0]
+        assert radial_lambda[0] == arr.Lambda[0]
+        assert getattr(arr, "radial-pressure-gradient")[0] == radial_lambda[0]
+
+    def test_restore_lambda_yaml(self):
+        self.run_restore_diffusionflame("flame_lambda.yaml")
+        self.run_restore_solutionarray("flame_lambda.yaml")
+
+    @pytest.mark.skipif("native" not in ct.hdf_support(),
+                        reason="Cantera compiled without HDF support")
+    def test_restore_lambda_hdf(self):
+        self.run_restore_diffusionflame("flame_lambda.h5")
+        self.run_restore_solutionarray("flame_lambda.h5")
+
     def test_two_point_control(self):
         """
         Computes a solution using a standard counterflow diffusion flame as a
@@ -1271,7 +1402,7 @@ class TestDiffusionFlame:
         sim.right_control_point_temperature += temperature_decrement
         sim.left_control_point_temperature += temperature_decrement
         sim.solve(loglevel=0, refine_grid=False)
-        assert sim.Uo == approx(sim.velocity[-1])
+        assert sim.flame.oxidizer_velocity == approx(sim.velocity[-1])
         temperature_4 = sim.T
 
         # Check the difference between the un-perturbed two-point solution and the
@@ -1290,6 +1421,7 @@ class TestDiffusionFlame:
 
         # Test - Check if the parameters are saved and restored correctly
         filename = self.test_work_path / "two_point_control.yaml"
+        filename.unlink(missing_ok=True)
 
         original_settings = sim.flame.settings['continuation-method']
         sim.save(filename)
@@ -1315,7 +1447,7 @@ class TestDiffusionFlame:
         assert (sim.right_control_point_temperature
                 == approx(original_settings['right-temperature'], 1e-4))
 
-        assert sim.Uo == approx(sim.velocity[-1])
+        assert sim.flame.oxidizer_velocity == approx(sim.velocity[-1])
 
         # Test - Check error conditions
         sim = ct.CounterflowDiffusionFlame(gas, width=width)
@@ -1432,7 +1564,8 @@ class TestCounterflowPremixedFlame:
             sim.solve(loglevel=0, auto=True)
             assert all(sim.T >= T - 1e-3)
             assert all(sim.spread_rate >= -1e-9)
-            assert np.allclose(sim.L, sim.L[0])
+            radial_lambda = sim.flame.radial_pressure_gradient
+            assert np.allclose(radial_lambda, radial_lambda[0])
             return sim
         return _run_case
 
@@ -1549,7 +1682,8 @@ class TestCounterflowPremixedFlameNonIdeal:
             sim.solve(loglevel=0, auto=True)
             assert all(sim.T >= T - 1e-3)
             assert all(sim.spread_rate >= -1e-9)
-            assert np.allclose(sim.L, sim.L[0])
+            radial_lambda = sim.flame.radial_pressure_gradient
+            assert np.allclose(radial_lambda, radial_lambda[0])
             return sim
         return _run_case
 
@@ -1596,7 +1730,6 @@ class TestBurnerFlame:
             sim.burner.mdot = gas.density * 0.15
             sim.solve(loglevel=0, auto=True)
             assert sim.T[1] > T
-            assert np.allclose(sim.L, 0)
         return _run_case
 
     @pytest.mark.parametrize(
@@ -1689,7 +1822,8 @@ class TestStagnationFlame:
         sim.solve(loglevel=0, auto=True)
 
         assert sim.T.max() > tburner + tsurf
-        assert np.allclose(sim.L, sim.L[0])
+        radial_lambda = sim.flame.radial_pressure_gradient
+        assert np.allclose(radial_lambda, radial_lambda[0])
         self.sim = sim
 
     def test_stagnation_case1(self):
@@ -1737,7 +1871,7 @@ class TestStagnationFlame:
                         assert settings[k][kk] == approx(vv)
                     else:
                         assert settings[k][kk] == vv
-            if isinstance(k, float):
+            if isinstance(v, float):
                 assert settings[k] == approx(v)
             else:
                 assert settings[k] == v
@@ -1790,7 +1924,7 @@ class TestImpingingJet:
 
     @pytest.mark.slow_test
     def test_reacting_surface_case3(self):
-        self.run_reacting_surface(xch4=0.2, tsurf=800.0, mdot=0.1, width=0.2)
+        self.run_reacting_surface(xch4=0.2, tsurf=800.0, mdot=0.1, width=0.08)
 
     @pytest.mark.usefixtures("allow_deprecated")
     @pytest.mark.skipif("native" not in ct.hdf_support(),
@@ -1858,9 +1992,9 @@ class TestImpingingJet:
                 assert settings[k] == v
 
         assert list(jet.surface.surface.X) == approx(list(self.sim.surface.surface.X))
-        for i in range(self.sim.surface.n_components):
-            assert self.sim.value("surface", i, 0) == \
-                approx(jet.value("surface", i, 0), tol_X)
+        for k in self.sim.surface.phase.species_names:
+            assert self.sim.surface.value(k) == \
+                approx(jet.surface.value(k), tol_X)
 
         jet.solve(loglevel=0)
 
@@ -1876,7 +2010,8 @@ class TestTwinFlame:
         sim.reactants.mdot = gas.density * axial_velocity
         sim.solve(loglevel=0, auto=True)
         assert sim.T[-1] > T + 100
-        assert np.allclose(sim.L, sim.L[0])
+        radial_lambda = sim.flame.radial_pressure_gradient
+        assert np.allclose(radial_lambda, radial_lambda[0])
         return sim
 
     def test_restart(self):
@@ -1930,8 +2065,6 @@ class TestTwinFlame:
             sim.solve(loglevel=0)
 
 class TestIonFreeFlame:
-
-    @pytest.mark.slow_test
     def test_ion_profile(self):
         reactants = 'CH4:0.216, O2:2'
         p = ct.one_atm
@@ -1948,13 +2081,20 @@ class TestIonFreeFlame:
         self.sim.flame.set_steady_tolerances(Y=(1e-4, 1e-12))
 
         # stage one
+        assert self.sim.electric_field_enabled is False
         self.sim.solve(loglevel=0, auto=True)
+        assert max(np.abs(self.sim.flame.electric_field)) == approx(0.0, abs=1e-3)
 
         #stage two
-        self.sim.solve(loglevel=0, stage=2)
+        self.sim.electric_field_enabled = True
+        self.sim.solve(loglevel=0)
 
         # Regression test
-        assert max(self.sim.E) == approx(149.63179056676853, rel=1e-3)
+        assert max(self.sim.flame.electric_field) == approx(149.6317905667685, rel=1e-3)
+        assert np.allclose(self.sim.E, self.sim.flame.electric_field)
+        zeros = self.sim.T
+        with pytest.raises(ct.CanteraError, match="is not used by 'free-ion-flow'"):
+            self.sim.flame.set_values("oxidizer-velocity", zeros)
 
 
 class TestIonBurnerFlame:
@@ -1972,8 +2112,9 @@ class TestIonBurnerFlame:
         self.sim.set_refine_criteria(ratio=4, slope=0.1, curve=0.1)
         self.sim.burner.mdot = self.gas.density * 0.15
 
-        self.sim.solve(loglevel=0, stage=2, auto=True)
+        self.sim.electric_field_enabled = True
+        self.sim.solve(loglevel=0, auto=True)
 
         # Regression test
-        assert max(self.sim.E) == approx(591.76, rel=1e-2)
+        assert max(self.sim.flame.electric_field) == approx(591.76, rel=1e-2)
         assert max(self.sim.X[self.gas.species_index('E')]) == approx(8.024e-9, rel=1e-2)
