@@ -457,9 +457,9 @@ class FalloffRateTests(ReactionRateTests):
     @pytest.fixture(scope='class', autouse=True)
     def setup_falloff_data(self):
         param = self._input["low-P-rate-constant"]
-        self._parts["low"] = ct.Arrhenius(param["A"], param["b"], param["Ea"])
+        self._parts["low"] = ct.ArrheniusRate(param["A"], param["b"], param["Ea"])
         param = self._input["high-P-rate-constant"]
-        self._parts["high"] = ct.Arrhenius(param["A"], param["b"], param["Ea"])
+        self._parts["high"] = ct.ArrheniusRate(param["A"], param["b"], param["Ea"])
 
     def eval(self, rate):
         concm = self.soln.third_body_concentrations[self._index]
@@ -625,7 +625,7 @@ class TestPlogRate(ReactionRateTests):
     @pytest.fixture(scope='function', autouse=True)
     def setup_plog_data(self):
         self._parts = {
-            "rates": [(rc["P"], ct.Arrhenius(rc["A"], rc["b"], rc["Ea"]))
+            "rates": [(rc["P"], ct.ArrheniusRate(rc["A"], rc["b"], rc["Ea"]))
                       for rc in self._input["rate-constants"]],
             }
 
@@ -648,6 +648,8 @@ class TestPlogRate(ReactionRateTests):
             assert rate.temperature_exponent == approx(other[index]["b"])
             assert rate.activation_energy == approx(other[index]["Ea"])
 
+    # TODO: After Cantera 3.2, replace Arrhenius with ArrheniusRate
+    @pytest.mark.usefixtures("allow_deprecated")
     def test_set_rates(self):
         # test setter for property rates
         other = [
@@ -1432,9 +1434,9 @@ class TestThreeBodyBlowersMasel(TestBlowersMasel):
 @pytest.fixture(scope='class')
 def setup_troe_tests(request, setup_reaction_tests):
     param = request.cls._rate["low_P_rate_constant"]
-    low = ct.Arrhenius(param["A"], param["b"], param["Ea"])
+    low = ct.ArrheniusRate(param["A"], param["b"], param["Ea"])
     param = request.cls._rate["high_P_rate_constant"]
-    high = ct.Arrhenius(param["A"], param["b"], param["Ea"])
+    high = ct.ArrheniusRate(param["A"], param["b"], param["Ea"])
     param = request.cls._rate["Troe"]
     data = [param["A"], param["T3"], param["T1"], param["T2"]]
     request.cls._rate_obj = ct.TroeRate(low=low, high=high, falloff_coeffs=data)
@@ -1472,9 +1474,9 @@ class TestTroe(ReactionTests):
 @pytest.fixture(scope='class')
 def setup_lindemann_tests(request, setup_reaction_tests):
     param = request.cls._rate["low_P_rate_constant"]
-    low = ct.Arrhenius(param["A"], param["b"], param["Ea"])
+    low = ct.ArrheniusRate(param["A"], param["b"], param["Ea"])
     param = request.cls._rate["high_P_rate_constant"]
-    high = ct.Arrhenius(param["A"], param["b"], param["Ea"])
+    high = ct.ArrheniusRate(param["A"], param["b"], param["Ea"])
     request.cls._rate_obj = ct.LindemannRate(low=low, high=high, falloff_coeffs=[])
 
 @pytest.mark.usefixtures("setup_lindemann_tests")
@@ -1509,9 +1511,9 @@ class TestLindemann(ReactionTests):
 @pytest.fixture(scope='class')
 def setup_chemically_activated_tests(request, setup_reaction_tests):
     param = request.cls._rate["low_P_rate_constant"]
-    low = ct.Arrhenius(param["A"], param["b"], param["Ea"])
+    low = ct.ArrheniusRate(param["A"], param["b"], param["Ea"])
     param = request.cls._rate["high_P_rate_constant"]
-    high = ct.Arrhenius(param["A"], param["b"], param["Ea"])
+    high = ct.ArrheniusRate(param["A"], param["b"], param["Ea"])
     request.cls._rate_obj = ct.LindemannRate(low=low, high=high, falloff_coeffs=[])
     request.cls._rate_obj.chemically_activated = True
 
@@ -1909,6 +1911,18 @@ class TestExtensible3:
         assert rxn.rate.length == 2
         assert rxn.rate.Ta == approx(1000 / ct.gas_constant)
 
+    def test_explicit_unicode_units(self):
+        rxn = """
+        equation: H2 + OH = H2O + H
+        type: user-rate-2
+        A: 1000 cm³/kmol/s
+        L: 200 cm
+        Ea: 1000
+        """
+        rxn = ct.Reaction.from_yaml(rxn, kinetics=self.gas)
+        assert rxn.rate.length == 2
+        assert rxn.rate.Ta == approx(1000 / ct.gas_constant)
+
     def test_implicit_units(self):
         rxn = """
         equation: H2 + OH = H2O + H
@@ -2284,9 +2298,9 @@ class TestElectronCollisionPlasmaReaction(ReactionTests):
     # reaction rate is much complicated and depends on electron energy distribution
     # function.
     _rate_cls = ct.ElectronCollisionPlasmaRate
-    _equation = "O2 + E => E + O2"
+    _equation = "O2 + E <=> E + O2"
     _rate = {
-        "equation": "O2 + E => E + O2",
+        "equation": "O2 + E <=> E + O2",
         "type": "electron-collision-plasma",
         "energy-levels": [0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0],
         "cross-sections": [0.0, 5.97e-20, 6.45e-20, 6.74e-20, 6.93e-20, 7.2e-20,
@@ -2295,7 +2309,7 @@ class TestElectronCollisionPlasmaReaction(ReactionTests):
     _index = 1
     _rate_type = "electron-collision-plasma"
     _yaml = """
-        equation: O2 + E => E + O2
+        equation: O2 + E <=> E + O2
         type: electron-collision-plasma
         energy-levels: [0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0]
         cross-sections: [0.0, 5.97e-20, 6.45e-20, 6.74e-20, 6.93e-20, 7.2e-20,
