@@ -4,7 +4,7 @@ import pytest
 from pytest import approx
 
 import cantera as ct
-
+from .utilities import compareProfiles
 
 class TestTransport:
 
@@ -38,6 +38,8 @@ class TestTransport:
         Dkm1b = phase.mix_diff_coeffs_mole
         Dkm1c = phase.mix_diff_coeffs_mass
         Dbin1 = phase.binary_diff_coeffs
+        assert all(phase.thermal_diff_coeffs.flat != 0.0)
+        assert np.sum(phase.thermal_diff_coeffs) == approx(0.0)
 
         phase.transport_model = 'multicomponent'
         Dkm2 = phase.mix_diff_coeffs
@@ -50,6 +52,32 @@ class TestTransport:
         assert Dbin1 == approx(Dbin2)
         assert Dbin1 == approx(Dbin1.T)
 
+    def test_multicomponent(self, phase):
+        phase.transport_model = 'multicomponent'
+        Dmulti = phase.multi_diff_coeffs
+
+        assert Dmulti.shape == (phase.n_species, phase.n_species)
+        assert all(Dmulti.diagonal() == 0)
+
+        # The sum of mass fluxes should equal zero for any consistent vector of mole
+        # fraction gradients (that is, where the sum of mole fraction gradients is zero)
+        W = phase.molecular_weights
+        W_mean = phase.mean_molecular_weight
+        rho = phase.density
+
+        net_flux = 0.0
+        flux_scale = 0.0
+        grad_X = np.array([0.1, 0.2, -0.3, 0.4, -0.6, 0.2, 0.1, -0.2, 0.5, -0.4])
+        rng = np.random.default_rng(123)
+        for _ in range(10):
+            rng.shuffle(grad_X)
+            for k in range(phase.n_species):
+                flux_k = rho * W[k] / W_mean**2 * sum(W * Dmulti[k,:] * grad_X)
+                net_flux += flux_k
+                flux_scale += abs(flux_k)
+
+            assert net_flux == approx(0.0, abs=1e-14 * flux_scale)
+
     def test_mixDiffCoeffsChange(self, phase):
         # This test is mainly to make code coverage in GasTransport.cpp
         # consistent by always covering the path where the binary diffusion
@@ -124,8 +152,6 @@ class TestTransport:
         with pytest.raises(NotImplementedError):
             phase.multi_diff_coeffs
 
-        assert phase.thermal_diff_coeffs == approx(np.zeros(phase.n_species))
-
         phase.transport_model = 'multicomponent'
         assert all(phase.multi_diff_coeffs.flat >= 0.0)
         assert all(phase.thermal_diff_coeffs.flat != 0.0)
@@ -176,7 +202,7 @@ class TestTransport:
         assert gas1.thermal_conductivity == approx(gas2.thermal_conductivity)
         assert gas1.multi_diff_coeffs == approx(gas2.multi_diff_coeffs)
 
-    def test_species_viscosities(self, phase):
+    def test_species_visosities(self, phase):
         for species_name in phase.species_names:
             # check that species viscosity matches overall for single-species
             # state
@@ -389,6 +415,21 @@ def test_bad_transport_input(key, value, message):
     with pytest.raises(ct.CanteraError, match=message):
         ct.Species.list_from_yaml(species_data)
 
+
+def test_bad_transport_from_dict():
+    H2 = ct.Species.list_from_file("h2o2.yaml")[0]
+    spec = H2.input_data
+
+    spec["transport"]["well-depth"] = "three"
+    with pytest.raises(ct.CanteraError, match="Key 'well-depth' contains a 'string'"):
+        ct.Species.from_dict(spec)
+
+    spec["transport"]["well-depth"] = None
+    with pytest.raises(ct.CanteraError,
+                       match="Key 'well-depth' not found or contains no value"):
+        ct.Species.from_dict(spec)
+
+
 @pytest.mark.parametrize(
     "model",
     [
@@ -659,3 +700,119 @@ class TestIonGasTransportData:
         assert data['quadrupole-polarizability'] == approx(3.602)
 
         assert 'dispersion-coefficient' not in gas.species('CO2').transport.input_data
+
+
+class TestHighPressureGasTransport:
+    """
+    Note: to re-create the reference file:
+    (1) Set PYTHONPATH to build/python.
+    (2) Go into test/python directory and run:
+        pytest --save-reference=high_pressure_transport test_transport.py::TestHighPressureGasTransport::test_high_pressure_transport
+        pytest --save-reference=high_pressure_chung_transport test_transport.py::TestHighPressureGasTransport::test_high_pressure_chung_transport
+    (3) Compare the reference files created in the current working directory with
+        the ones in test/data and replace them if needed.
+    """
+
+    def test_failure_for_species_with_no_properties(self):
+        """
+        All species must have critical properties defined to use the high pressure
+        transport model. This test uses a YAML file with a specified value of the
+        a and b parameters for the Peng-Robinson equation of state, which should
+        be parsed by the thermo model and will set the critical properties to
+        non-physical values. These non-physical values should trigger an error
+        in the high-pressure transport model.
+        """
+        gas = ct.Solution('methane_co2_noCritProp.yaml')
+
+        with pytest.raises(ct.CanteraError, match="must have critical properties defined"):
+            gas.transport_model = 'high-pressure-Chung'
+
+        with pytest.raises(ct.CanteraError, match="must have critical properties defined"):
+            gas.transport_model = 'high-pressure'
+
+    def test_high_pressure_transport(self, request, test_data_path):
+        """
+        This test compares the viscosity and thermal conductivities of a mixture of
+        CH4 and CO2 over a range of pressures using the high-pressure transport
+        model and compares the results to a reference file. This is a regression test.
+        """
+        referenceFile = "HighPressureTest.csv"
+
+        phasedef = """
+        phases:
+        - name: methane_co2
+          species:
+          - gri30.yaml/species: [CH4, CO2]
+          thermo: Peng-Robinson
+          transport: mixture-averaged
+          state: {T: 300, P: 1 atm}
+        """
+        gas = ct.Solution(yaml=phasedef)
+        gas.transport_model = 'high-pressure'
+
+        pressures = np.linspace(101325, 6e7, 100)
+        # Collect viscosities and thermal conductivities
+        viscosities = []
+        thermal_conductivities = []
+        diffusion_coefficients = []
+        for pressure in pressures:
+            gas.TPX = 350, pressure, 'CH4:0.755, CO2:0.245'
+            viscosities.append(gas.viscosity)
+            thermal_conductivities.append(gas.thermal_conductivity)
+            diffusion_coefficients.append(gas.mix_diff_coeffs)
+
+        data = np.empty((len(viscosities), 3+ len(diffusion_coefficients[0])))
+        data[:,0] = pressures
+        data[:,1] = viscosities
+        data[:,2] = thermal_conductivities
+        for i in range(len(diffusion_coefficients[0])):
+            data[:,3+i] = [d[i] for d in diffusion_coefficients]
+
+        saveReference = request.config.getoption("--save-reference")
+        if saveReference == 'high_pressure_transport':
+            np.savetxt(referenceFile, data, '%11.6e', ', ')
+        else:
+            bad = compareProfiles(test_data_path / referenceFile, data,
+                                  rtol=1e-2, atol=1e-8, xtol=1e-2)
+            assert not bad, bad
+
+    def test_high_pressure_chung_transport(self, request, test_data_path):
+        referenceFile = "HighPressureChungTest.csv"
+
+        phasedef = """
+        phases:
+        - name: methane_co2
+          species:
+          - gri30.yaml/species: [CH4, CO2]
+          thermo: Peng-Robinson
+          transport: mixture-averaged
+          state: {T: 300, P: 1 atm}
+        """
+        gas = ct.Solution(yaml=phasedef)
+        gas.transport_model = 'high-pressure-Chung'
+
+        pressures = np.linspace(101325, 6e7, 100)
+        # Collect viscosities and thermal conductivities
+        viscosities = []
+        thermal_conductivities = []
+        diffusion_coefficients = []
+        for pressure in pressures:
+            gas.TPX = 350, pressure, 'CH4:0.755, CO2:0.245'
+            viscosities.append(gas.viscosity)
+            thermal_conductivities.append(gas.thermal_conductivity)
+            diffusion_coefficients.append(gas.mix_diff_coeffs)
+
+        data = np.empty((len(viscosities), 3+gas.n_species))
+        data[:,0] = pressures
+        data[:,1] = viscosities
+        data[:,2] = thermal_conductivities
+        for i in range(len(diffusion_coefficients[0])):
+            data[:,3+i] = [d[i] for d in diffusion_coefficients]
+
+        saveReference = request.config.getoption("--save-reference")
+        if saveReference == 'high_pressure_chung_transport':
+            np.savetxt(referenceFile, data, '%11.6e', ', ')
+        else:
+            bad = compareProfiles(test_data_path / referenceFile, data,
+                                  rtol=1e-2, atol=1e-8, xtol=1e-2)
+            assert not bad, bad
