@@ -2,6 +2,7 @@ import numpy as np
 from pathlib import Path
 import pytest
 from pytest import approx
+from types import ModuleType
 
 import cantera as ct
 from cantera._utils import _py_to_any_to_py, _py_to_anymap_to_py
@@ -62,6 +63,21 @@ class TestUnitSystem:
         with pytest.raises(ct.CanteraError, match="non-unity conversion factor"):
             ct.UnitSystem({"current": "2 A"})
 
+    def test_defaults_types(self):
+        """Ensure UnitSystem.defaults() and the units property return str keys/values."""
+        system = ct.UnitSystem()
+        d = system.defaults()
+        assert isinstance(d, dict)
+        for k, v in d.items():
+            assert isinstance(k, str), f"key {k!r} is not str"
+            assert isinstance(v, str), f"value {v!r} is not str"
+
+        # also check the property accessor
+        u = system.units
+        for k, v in u.items():
+            assert isinstance(k, str), f"units key {k!r} is not str"
+            assert isinstance(v, str), f"units value {v!r} is not str"
+
     def test_convert_to_default(self):
         system = ct.UnitSystem()
         assert system.convert_to("3 cm", "m") == 0.03
@@ -77,7 +93,9 @@ class TestUnitSystem:
     def test_convert_rate_coeff(self):
         system = ct.UnitSystem({"length": "cm"})
         assert system.convert_rate_coeff_to(11, ct.Units("m^3/kmol/s")) == approx(11e-6)
+        assert system.convert_rate_coeff_to(11, ct.Units("m³/kmol/s")) == approx(11e-6)
         assert system.convert_rate_coeff_to("22 m^3/mol/s", "m^3/kmol/s") == approx(22e3)
+        assert system.convert_rate_coeff_to("22 m³/mol/s", "m³/kmol/s") == approx(22e3)
 
     def test_convert_to_custom(self):
         system = ct.UnitSystem({"length": "cm", "mass": "g"})
@@ -119,6 +137,7 @@ class TestUnitSystem:
         system = ct.UnitSystem({"length": "cm"})
         x = [("3000 mm^3/kmol/s", 4), (0.5, 2.0), 1.0]
         x_m = system.convert_rate_coeff_to(x, ct.Units("m^3/kmol/s"))
+        x_m = system.convert_rate_coeff_to(x, ct.Units("m³/kmol/s"))
         assert x_m[0][0] == approx(3000 / 1e9)
         assert x_m[1][1] == approx(2 / 1e6)
         assert x_m[2] == approx(1e-6)
@@ -140,6 +159,9 @@ class TestUnitSystem:
         with pytest.raises(ct.CanteraError):
             system.convert_activation_energy_to(4, "m^3/s")
 
+        with pytest.raises(ct.CanteraError):
+            system.convert_activation_energy_to(4, "m³/s")
+
         with pytest.raises(TypeError):
             system.convert_activation_energy_to(5, True)
 
@@ -152,6 +174,9 @@ class TestUnitSystem:
         with pytest.raises(TypeError):
             system.convert_rate_coeff_to(11, ["m^3"])
 
+        with pytest.raises(TypeError):
+            system.convert_rate_coeff_to(11, ["m³"])
+
         with pytest.raises(TypeError):
             system.convert_rate_coeff_to({"spam": 13}, "m^6/kmol^2/s")
 
@@ -300,6 +325,7 @@ class TestAnyMap:
         params = ct.AnyMap()
         params.set_quantity('spam', [2, 3, 4], 'Gg')
         params.set_quantity('eggs', 10, ct.Units('kg/m^3'))
+        params.set_quantity('eggs', 10, ct.Units('kg/m³'))
         params.set_activation_energy('beans', 5, 'K')
 
         converted = _py_to_anymap_to_py(params)
@@ -330,3 +356,14 @@ class TestListDataFiles:
         data_files = ct.list_data_files()
         assert "gri30.yaml" in data_files
         assert str(Path("example_data/oxygen-plasma-itikawa.yaml")) in data_files
+
+
+def test_namespace_cleanliness():
+    for name in dir(ct):
+        if name.startswith('_'):
+            continue
+        var = getattr(ct, name)
+        if hasattr(var, "__module__") and not var.__module__.startswith("cantera"):
+            pytest.fail(f"cantera module is exporting external class/function '{name}'")
+        elif isinstance(var, ModuleType) and not var.__name__.startswith("cantera"):
+            pytest.fail(f"cantera module is exporting external module '{name}'")
