@@ -99,6 +99,11 @@ TEST_F(ConstructFromScratch, AddElements)
     ASSERT_EQ((size_t) 2, p.nElements());
     ASSERT_EQ("H", p.elementName(0));
     ASSERT_EQ((size_t) 1, p.elementIndex("O"));
+
+    ASSERT_THROW(p.elementName(200), IndexError);
+    ASSERT_THROW(p.elementIndex("spam"), CanteraError);
+    ASSERT_EQ(p.elementIndex("spam", false), npos);
+    ASSERT_THROW(p.elementIndex("spam", true), CanteraError);
 }
 
 TEST_F(ConstructFromScratch, throwUndefindElements)
@@ -120,6 +125,11 @@ TEST_F(ConstructFromScratch, throwUndefindElements)
     ASSERT_EQ(2, p.nAtoms(2, 1)); // O in O2
     ASSERT_EQ(2, p.nAtoms(0, 0)); // H in H2O
     ASSERT_THROW(p.addSpecies(sCO), CanteraError);
+
+    ASSERT_THROW(p.speciesName(200), IndexError);
+    ASSERT_THROW(p.speciesIndex("spam"), CanteraError);
+    ASSERT_EQ(p.speciesIndex("spam", false), npos);
+    ASSERT_THROW(p.speciesIndex("spam", true), CanteraError);
 }
 
 TEST_F(ConstructFromScratch, ignoreUndefinedElements)
@@ -137,7 +147,8 @@ TEST_F(ConstructFromScratch, ignoreUndefinedElements)
     p.addSpecies(sCO2);
     ASSERT_EQ((size_t) 2, p.nSpecies());
     ASSERT_EQ((size_t) 2, p.nElements());
-    ASSERT_EQ(npos, p.speciesIndex("CO2"));
+    ASSERT_EQ(npos, p.speciesIndex("CO2", false));
+    ASSERT_THROW(p.speciesIndex("CO2", true), CanteraError);
 }
 
 TEST_F(ConstructFromScratch, addUndefinedElements)
@@ -342,6 +353,7 @@ TEST(MargulesVPSSTP, fromScratch)
 
 TEST(LatticeSolidPhase, fromScratch)
 {
+    suppress_deprecation_warnings();
     auto base = make_shared<StoichSubstance>();
     base->setName("Li7Si3(S)");
     auto sLi7Si3 = make_shomate2_species("Li7Si3(S)", "Li:7 Si:3", li7si3_shomate_coeffs);
@@ -382,6 +394,7 @@ TEST(LatticeSolidPhase, fromScratch)
         EXPECT_NEAR(mu[k], mu_ref[k], 1e-7*fabs(mu_ref[k]));
         EXPECT_NEAR(vol[k], vol_ref[k], 1e-7);
     }
+    make_deprecation_warnings_fatal();
 }
 
 TEST(IdealSolidSolnPhase, fromScratch)
