@@ -886,18 +886,6 @@ INSTANTIATE_TEST_SUITE_P(RedlichKister_complex, TestConsistency,
         testing::ValuesIn(getStates("Redlich-Kister-complex")))
 );
 
-INSTANTIATE_TEST_SUITE_P(MaskellSolidSolution, TestConsistency,
-    testing::Combine(
-        testing::Values(getSetup("Maskell-solid-solution")),
-        testing::ValuesIn(getStates("Maskell-solid-solution")))
-);
-
-INSTANTIATE_TEST_SUITE_P(IonsFromNeutralMolecule, TestConsistency,
-    testing::Combine(
-        testing::Values(getSetup("ions-from-neutral-molecule")),
-        testing::ValuesIn(getStates("ions-from-neutral-molecule")))
-);
-
 INSTANTIATE_TEST_SUITE_P(HMWSoln, TestConsistency,
     testing::Combine(
         testing::Values(getSetup("HMW-electrolyte")),
@@ -909,6 +897,7 @@ int main(int argc, char** argv)
     printf("Running main() from consistency.cpp\n");
     testing::InitGoogleTest(&argc, argv);
     Cantera::make_deprecation_warnings_fatal();
+    Cantera::CanteraError::setStackTraceDepth(0);
     int result = RUN_ALL_TESTS();
     Cantera::appdelete();
     return result;
