@@ -177,11 +177,32 @@ TEST_F(GasTransportTest, thermalDiffCoeffs)
          -1.400893e-22,  1.968555e-22,  4.414863e-21
     };
 
+    const double thermalDiffMixRef[] = {
+        -1.97226421719082e-06, -6.04696504247212e-10, -9.90802378755412e-15,
+        3.14480069520489e-15, -2.96155643142378e-11, -6.82205028945992e-07,
+        2.92077699110767e-18, 2.49573967024886e-17, -3.02014062767274e-23,
+        -3.43728222424916e-22, -8.19843353222891e-20, -2.84275400736814e-21,
+        -1.64208862608778e-16, -1.80369284235688e-14, 8.24896551635327e-07,
+        7.04151357884373e-07, 9.34047159936078e-14, 1.54627741091289e-13,
+        1.09208834358759e-18, 1.10900054077964e-20, 1.68248638493913e-17,
+        4.05329445771533e-24, 1.7718934165487e-18, 5.01179394798185e-23,
+        2.16210022278212e-20, 9.85061024456701e-25, 1.50682299818537e-23,
+        1.35163391781345e-20, 9.31081556209504e-18, 1.22537421912008e-21,
+        -3.60737893615715e-17, -4.86699553776885e-16, -2.10048949693204e-14,
+        -8.80399546006993e-12, 3.98149356084823e-16, 5.99167005188409e-13,
+        2.51475683431014e-19, 6.8424918923382e-17, 8.00157517467182e-17,
+        2.85203772258056e-18, 9.4009635515829e-13, 4.74141387733766e-19,
+        4.60157223656553e-25, 2.88317189129165e-21, 5.73575815122357e-16,
+        9.20926220995577e-13, 8.61597096394322e-17, 1.12606178968437e-06,
+        0, 2.00216138684567e-33, 2.79494070813552e-32,
+        1.26003408367763e-22, 4.26137699636566e-21
+    };
+
     vector<double> thermalDiff(nsp, -1);
-    // Thermal diffusion coefficients are zero for the mixture averaged model
     s_mix->getThermalDiffCoeffs(thermalDiff.data());
     for (size_t k = 0; k < nsp; k++) {
-        EXPECT_DOUBLE_EQ(thermalDiff[k], 0.0) << k;
+        double tol = std::max(1e-16, 1e-5 * fabs(thermalDiffMixRef[k]));
+        EXPECT_NEAR(thermalDiff[k], thermalDiffMixRef[k], tol) << k;
     }
 
     s_multi->getThermalDiffCoeffs(thermalDiff.data());
