@@ -1,10 +1,7 @@
 #include "gtest/gtest.h"
-#include "cantera/thermo.h"
-#include "cantera/kinetics.h"
 #include "cantera/zerodim.h"
-#include "cantera/base/Interface.h"
 #include "cantera/numerics/eigen_sparse.h"
-#include "cantera/numerics/PreconditionerFactory.h"
+#include "cantera/numerics/SystemJacobianFactory.h"
 #include "cantera/numerics/AdaptivePreconditioner.h"
 
 using namespace Cantera;
@@ -19,16 +16,15 @@ TEST(zerodim, simple)
 
     auto sol = newSolution("gri30.yaml", "gri30", "none");
     sol->thermo()->setState_TPX(T, P, X);
-    auto cppReactor = newReactor("IdealGasReactor", sol, "simple");
-    ASSERT_EQ(cppReactor->name(), "simple");
-    cppReactor->initialize();
-    ReactorNet network;
-    network.addReactor(dynamic_cast<IdealGasReactor&>(*cppReactor));
+    auto reactor = newReactor4("IdealGasReactor", sol, true, "simple");
+    ASSERT_EQ(reactor->name(), "simple");
+    reactor->initialize();
+    ReactorNet network(reactor);
     network.initialize();
 
     double t = 0.0;
     while (t < 0.1) {
-        ASSERT_GE(cppReactor->temperature(), T);
+        ASSERT_GE(reactor->temperature(), T);
         t = network.time() + 5e-3;
         network.advance(t);
     }
@@ -56,6 +52,111 @@ TEST(zerodim, test_guards)
     EXPECT_THROW(Valve().updateMassFlowRate(0.), CanteraError);
 }
 
+TEST(zerodim, reactor)
+{
+    auto gas = newSolution("h2o2.yaml", "ohmech", "none");
+    auto reactor = newReactor4("Reactor", gas, true, "my-reactor");
+
+    ASSERT_THROW(reactor->componentName(200), IndexError);
+    ASSERT_THROW(reactor->componentIndex("spam"), CanteraError);
+}
+
+TEST(zerodim, reservoir)
+{
+    auto gas = newSolution("gri30.yaml", "gri30", "none");
+    auto res = newReservoir(gas, true, "my-reservoir");
+    ASSERT_EQ(res->type(), "Reservoir");
+    ASSERT_EQ(res->name(), "my-reservoir");
+}
+
+TEST(zerodim, flowdevice)
+{
+    auto gas = newSolution("gri30.yaml", "gri30", "none");
+
+    auto node0 = newReactor4("IdealGasReactor", gas, true, "upstream");
+    auto node1 = newReactor4("IdealGasReactor", gas, true, "downstream");
+
+    auto valve = newFlowDevice("Valve", node0, node1, "valve");
+    ASSERT_EQ(valve->name(), "valve");
+    ASSERT_EQ(valve->in().name(), "upstream");
+    ASSERT_EQ(valve->out().name(), "downstream");
+
+    ASSERT_EQ(node0->nInlets(), 0U);
+    ASSERT_EQ(node0->nOutlets(), 1U);
+    ASSERT_EQ(node1->nInlets(), 1U);
+    ASSERT_EQ(node1->nOutlets(), 0U);
+}
+
+TEST(zerodim, wall)
+{
+    auto gas = newSolution("gri30.yaml", "gri30", "none");
+
+    auto node0 = newReactor4("IdealGasReactor", gas, true, "left");
+    auto node1 = newReactor4("IdealGasReactor", gas, true, "right");
+
+    auto wall = newWall("Wall", node0, node1, "wall");
+    ASSERT_EQ(wall->name(), "wall");
+    ASSERT_EQ(wall->left().name(), "left");
+    ASSERT_EQ(wall->right().name(), "right");
+
+    ASSERT_EQ(node0->nWalls(), 1U);
+    ASSERT_EQ(node1->nWalls(), 1U);
+}
+
+TEST(zerodim, mole_reactor)
+{
+    // simplified version of continuous_reactor.py
+    auto gas = newSolution("h2o2.yaml", "ohmech", "none");
+
+    auto tank = make_shared<Reservoir>(gas, true, "fuel-air-tank");
+    auto exhaust = make_shared<Reservoir>(gas, true, "exhaust");
+
+    auto stirred = make_shared<IdealGasMoleReactor>(gas, true, "stirred-reactor");
+    stirred->setEnergyEnabled(false);
+    stirred->setInitialVolume(30.5 * 1e-6);
+
+    auto mfc = make_shared<MassFlowController>(tank, stirred, "mass-flow-controller");
+    double residenceTime = 2.;
+    double mass = stirred->mass();
+    mfc->setMassFlowRate(mass/residenceTime);
+
+    auto preg = make_shared<PressureController>(stirred, exhaust, "pressure-regulator");
+    preg->setPrimary(mfc);
+    preg->setDeviceCoefficient(1e-3);
+
+    auto net = ReactorNet(stirred);
+    net.initialize();
+}
+
+TEST(zerodim, mole_reactor_2)
+{
+    // simplified version of continuous_reactor.py
+    auto gas = newSolution("h2o2.yaml", "ohmech", "none");
+
+    auto tank = newReservoir(gas, true, "fuel-air-tank");
+    auto exhaust = newReservoir(gas, true, "exhaust");
+
+    auto stirred = newReactor4(
+        "IdealGasMoleReactor", gas, true, "stirred-reactor");
+    stirred->setEnergyEnabled(false);
+    stirred->setInitialVolume(30.5 * 1e-6);
+
+    auto mfc = newFlowDevice(
+        "MassFlowController", tank, stirred, "mass-flow-controller");
+    double residenceTime = 2.;
+    double mass = stirred->mass();
+    mfc->setMassFlowRate(mass/residenceTime);
+
+    auto preg = newFlowDevice(
+        "PressureController", stirred, exhaust, "pressure-regulator");
+    preg->setPrimary(mfc);
+    preg->setDeviceCoefficient(1e-3);
+
+    vector<shared_ptr<ReactorBase>> reactors{stirred};
+    auto net = newReactorNet(reactors);
+    net->initialize();
+}
+
 // This test ensures that prior reactor initialization of a reactor does
 // not affect later integration within a network. This example was
 // adapted from test_reactor.py::test_equilibrium_HP.
@@ -70,12 +171,11 @@ TEST(zerodim, test_individual_reactor_initialization)
     shared_ptr<Solution> sol1 = newSolution("h2o2.yaml");
     sol1->thermo()->setState_TPX(T0, P0, X0);
     // set up reactor object
-    Reactor reactor1(sol1);
+    auto reactor1 = newReactor4("Reactor", sol1, true);
     // initialize reactor prior to integration to ensure no impact
-    reactor1.initialize();
+    reactor1->initialize();
     // setup reactor network and integrate
-    ReactorNet network;
-    network.addReactor(reactor1);
+    ReactorNet network(reactor1);
     network.initialize();
     network.advance(1.0);
     // secondary gas for comparison
@@ -83,16 +183,16 @@ TEST(zerodim, test_individual_reactor_initialization)
     sol2->thermo()->setState_TPX(T0, P0, X0);
     sol2->thermo()->equilibrate("UV");
     // secondary reactor for comparison
-    Reactor reactor2(sol2);
-    reactor2.initialize(0.0);
+    auto reactor2 = newReactor4("Reactor", sol2, true);
+    reactor2->initialize(0.0);
     // get state of reactors
-    vector<double> state1(reactor1.neq());
-    vector<double> state2(reactor2.neq());
-    reactor1.getState(state1.data());
-    reactor2.getState(state2.data());
+    vector<double> state1(reactor1->neq());
+    vector<double> state2(reactor2->neq());
+    reactor1->getState(state1.data());
+    reactor2->getState(state2.data());
     // compare the reactors.
-    EXPECT_EQ(reactor1.neq(), reactor2.neq());
-    for (size_t i = 0; i < reactor1.neq(); i++) {
+    EXPECT_EQ(reactor1->neq(), reactor2->neq());
+    for (size_t i = 0; i < reactor1->neq(); i++) {
         EXPECT_NEAR(state1[i], state2[i], tol);
     }
 }
@@ -103,13 +203,13 @@ TEST(MoleReactorTestSet, test_mole_reactor_get_state)
     double tol = 1e-8;
     auto sol = newSolution("h2o2.yaml");
     sol->thermo()->setState_TPY(1000.0, OneAtm, "H2:0.5, O2:0.5");
-    IdealGasConstPressureMoleReactor reactor(sol);
+    IdealGasConstPressureMoleReactor reactor(sol, true);
     reactor.setInitialVolume(0.5);
-    reactor.setEnergy(false);
+    reactor.setEnergyEnabled(false);
     reactor.initialize();
     vector<double> state(reactor.neq());
     // test get state
-    const ThermoPhase& thermo = reactor.contents();
+    const ThermoPhase& thermo = *reactor.phase()->thermo();
     const vector<double>& imw = thermo.inverseMolecularWeights();
     // prescribed state
     double mass = reactor.volume() * thermo.density();
@@ -145,7 +245,7 @@ TEST(AdaptivePreconditionerTests, test_adaptive_precon_utils)
     precon.setGamma(gamma);
     EXPECT_NEAR(precon.gamma(), gamma, tol);
     // test setup and getting the matrix
-    precon.setup();
+    precon.updatePreconditioner();
     Eigen::SparseMatrix<double> identity(testSize, testSize);
     identity.setIdentity();
     EXPECT_TRUE(precon.matrix().isApprox(identity));
@@ -169,11 +269,11 @@ TEST(AdaptivePreconditionerTests, test_adaptive_precon_utils)
     testMat.setIdentity();
     testMat.fill(thresh * 0.9);
     EXPECT_TRUE(precon.jacobian().isApprox(testMat));
-    precon.setup();
+    precon.updatePreconditioner();
     EXPECT_TRUE(precon.matrix().isApprox(identity * (thresh * 1.1)));
     // reset and setup then test again
     precon.reset();
-    precon.setup();
+    precon.updatePreconditioner();
     EXPECT_TRUE(precon.matrix().isApprox(identity));
 }
 
@@ -182,13 +282,12 @@ TEST(AdaptivePreconditionerTests, test_precon_solver_stats)
     // setting up solution object and thermo/kinetics pointers
     auto sol = newSolution("h2o2.yaml");
     sol->thermo()->setState_TPY(1000.0, OneAtm, "H2:0.5, O2:0.5");
-    IdealGasMoleReactor reactor(sol);
-    reactor.setInitialVolume(0.5);
+    auto reactor = newReactor4("IdealGasMoleReactor", sol, true);
+    reactor->setInitialVolume(0.5);
     // setup reactor network and integrate
-    ReactorNet network;
-    network.addReactor(reactor);
+    ReactorNet network(reactor);
     // setup preconditioner
-    shared_ptr<PreconditionerBase> precon_ptr = newPreconditioner("Adaptive");
+    shared_ptr<SystemJacobian> precon_ptr = newSystemJacobian("Adaptive");
     network.setPreconditioner(precon_ptr);
     EXPECT_THROW(network.step(), CanteraError);
     // take a step
